@@ -22,8 +22,7 @@ void RunIntStringCallbackAndroid(const JavaRef<jobject>& callback,
                                  int int_arg,
                                  const std::string& str_arg) {
   JNIEnv* env = jni_zero::AttachCurrentThread();
-  Java_IntStringCallback_onResult(env, callback, int_arg,
-                                  ConvertUTF8ToJavaString(env, str_arg));
+  Java_IntStringCallback_onResult(env, callback, int_arg, str_arg);
 }
 
 }  // namespace android
