@@ -58,6 +58,7 @@ public class ChildConnectionAllocatorTest {
 
     static class TestConnectionFactory implements ChildConnectionAllocator.ConnectionFactory {
         private ComponentName mLastServiceName;
+        private ComponentName mLastFallbackServiceName;
         private String mLastInstanceName;
 
         private ChildProcessConnection mConnection;
@@ -72,8 +73,11 @@ public class ChildConnectionAllocatorTest {
                 boolean bindToCaller,
                 boolean bindAsExternalService,
                 Bundle serviceBundle,
-                String instanceName) {
+                String instanceName,
+                boolean independentFallback,
+                boolean isSandboxedForHistograms) {
             mLastServiceName = serviceName;
+            mLastFallbackServiceName = fallbackServiceName;
             mLastInstanceName = instanceName;
             if (mConnection == null) {
                 mConnection = mock(ChildProcessConnection.class);
@@ -100,6 +104,12 @@ public class ChildConnectionAllocatorTest {
             return serviceName;
         }
 
+        public ComponentName getAndResetLastFallbackServiceName() {
+            ComponentName fallbackServiceName = mLastFallbackServiceName;
+            mLastFallbackServiceName = null;
+            return fallbackServiceName;
+        }
+
         public String getAndResetLastInstanceName() {
             String instanceName = mLastInstanceName;
             mLastInstanceName = null;
@@ -164,7 +174,9 @@ public class ChildConnectionAllocatorTest {
                         MAX_CONNECTION_NUMBER,
                         /* bindToCaller= */ true,
                         /* bindAsExternalService= */ false,
-                        /* useStrongBinding= */ false);
+                        /* useStrongBinding= */ false,
+                        /* fallbackToNextSlot= */ false,
+                        /* isSandboxedForHistograms= */ false);
         mAllocator.setConnectionFactoryForTesting(mTestConnectionFactory);
 
         mVariableSizeAllocator =
@@ -173,7 +185,7 @@ public class ChildConnectionAllocatorTest {
                         TEST_PACKAGE_NAME,
                         /* freeSlotCallback= */ null,
                         "AllocatorTest",
-                        /* bindTocall= */ true,
+                        /* bindToCaller= */ true,
                         /* bindAsExternalService= */ false,
                         /* useStrongBinding= */ false,
                         10);
@@ -185,7 +197,7 @@ public class ChildConnectionAllocatorTest {
                         TEST_PACKAGE_NAME,
                         /* freeSlotCallback= */ null,
                         "AllocatorTest",
-                        /* bindTocall= */ true,
+                        /* bindToCaller= */ true,
                         /* bindAsExternalService= */ false,
                         /* useStrongBinding= */ false,
                         10);
@@ -196,7 +208,7 @@ public class ChildConnectionAllocatorTest {
     @Feature({"ProcessManagement"})
     public void testPlainAllocate() {
         assertFalse(mAllocator.anyConnectionAllocated());
-        assertEquals(MAX_CONNECTION_NUMBER, mAllocator.getNumberOfServices());
+        assertEquals(MAX_CONNECTION_NUMBER, mAllocator.getMaxNumberOfAllocations());
 
         ChildProcessConnection connection =
                 mAllocator.allocate(
@@ -244,7 +256,9 @@ public class ChildConnectionAllocatorTest {
                         1,
                         /* bindToCaller= */ true,
                         /* bindAsExternalService= */ false,
-                        /* useStrongBinding= */ false);
+                        /* useStrongBinding= */ false,
+                        /* fallbackToNextSlot= */ false,
+                        /* isSandboxedForHistograms= */ false);
         doTestQueueAllocation(mAllocator, freeConnectionCallback);
     }
 
@@ -340,7 +354,9 @@ public class ChildConnectionAllocatorTest {
                             MAX_CONNECTION_NUMBER,
                             /* bindToCaller= */ true,
                             /* bindAsExternalService= */ false,
-                            useStrongBinding);
+                            useStrongBinding,
+                            /* fallbackToNextSlot= */ false,
+                            /* isSandboxedForHistograms= */ false);
             allocator.setConnectionFactoryForTesting(mTestConnectionFactory);
             ChildProcessConnection connection =
                     allocator.allocate(
@@ -349,6 +365,62 @@ public class ChildConnectionAllocatorTest {
         }
     }
 
+    @Test
+    @Feature({"ProcessManagement"})
+    public void testFixedSizeAllocatorFallback() {
+        ChildConnectionAllocator.FixedSizeAllocatorImpl allocator =
+                ChildConnectionAllocator.createFixedForTesting(
+                        null,
+                        TEST_PACKAGE_NAME,
+                        "AllocatorTest",
+                        /* serviceCount= */ 4,
+                        /* bindToCaller= */ true,
+                        /* bindAsExternalService= */ false,
+                        /* useStrongBinding= */ true,
+                        /* fallbackToNextSlot= */ true,
+                        /* isSandboxedForHistograms= */ false);
+
+        assertEquals(2, allocator.getMaxNumberOfAllocations());
+        assertEquals(0, allocator.allocatedConnectionsCountForTesting());
+        assertEquals(true, allocator.isFreeConnectionAvailable());
+        assertEquals(false, allocator.anyConnectionAllocated());
+
+        TestConnectionFactory connection1Factory = new TestConnectionFactory();
+        allocator.setConnectionFactoryForTesting(connection1Factory);
+        ChildProcessConnection connection1 =
+                allocator.allocate(
+                        /* context= */ null, /* serviceBundle= */ null, mServiceCallback);
+        assertEquals(1, allocator.allocatedConnectionsCountForTesting());
+        assertEquals(true, allocator.isFreeConnectionAvailable());
+        assertEquals(true, allocator.anyConnectionAllocated());
+        assertEquals(connection1, allocator.getChildProcessConnectionAtSlotForTesting(0));
+        assertNotNull(connection1Factory.getAndResetLastFallbackServiceName());
+
+        TestConnectionFactory connection2Factory = new TestConnectionFactory();
+        allocator.setConnectionFactoryForTesting(connection2Factory);
+        ChildProcessConnection connection2 =
+                allocator.allocate(
+                        /* context= */ null, /* serviceBundle= */ null, mServiceCallback);
+        assertEquals(2, allocator.allocatedConnectionsCountForTesting());
+        assertEquals(false, allocator.isFreeConnectionAvailable());
+        assertEquals(true, allocator.anyConnectionAllocated());
+        assertEquals(connection2, allocator.getChildProcessConnectionAtSlotForTesting(2));
+        assertNotNull(connection2Factory.getAndResetLastFallbackServiceName());
+
+        connection2Factory.simulateServiceProcessDying();
+        ShadowLooper.runUiThreadTasksIncludingDelayedTasks();
+        assertEquals(1, allocator.allocatedConnectionsCountForTesting());
+        assertEquals(true, allocator.isFreeConnectionAvailable());
+        assertEquals(true, allocator.anyConnectionAllocated());
+
+        connection1Factory.simulateServiceProcessDying();
+        ShadowLooper.runUiThreadTasksIncludingDelayedTasks();
+        assertEquals(2, allocator.getMaxNumberOfAllocations());
+        assertEquals(0, allocator.allocatedConnectionsCountForTesting());
+        assertEquals(true, allocator.isFreeConnectionAvailable());
+        assertEquals(false, allocator.anyConnectionAllocated());
+    }
+
     /**
      * Tests that the various ServiceCallbacks are propagated and posted, so they happen after the
      * ChildProcessAllocator,allocate() method has returned.
