@@ -33,8 +33,9 @@ void TestLogListenerSafe::set_on_log_message(
 void TestLogListenerSafe::Log(
     TestLogListenerSafe::LogRequest& request,
     TestLogListenerSafe::LogCompleter::Sync& completer) {
-  if (on_log_message_)
+  if (on_log_message_) {
     on_log_message_.Run(request.log());
+  }
   completer.Reply();
 }
 
@@ -66,7 +67,7 @@ void SimpleTestLogListener::ListenToLog(
         ZX_LOG(ERROR, info.status()) << "LogListenerSafe disconnected";
       });
 
-  ignore_before_ = zx::clock::get_monotonic();
+  ignore_before_ = zx::clock::get_boot();
   listener_.set_on_log_message(base::BindRepeating(
       &SimpleTestLogListener::PushLoggedMessage, base::Unretained(this)));
   auto listen_safe_result =
@@ -97,7 +98,7 @@ SimpleTestLogListener::RunUntilMessageReceived(
        expected_string = std::string(expected_string),
        quit_loop =
            loop.QuitClosure()](const fuchsia_logger::LogMessage& message) {
-        if (zx::time(message.time()) < ignore_before) {
+        if (message.time() < ignore_before) {
           return;
         }
         if (message.msg().find(expected_string) == std::string::npos) {
@@ -117,7 +118,7 @@ SimpleTestLogListener::RunUntilMessageReceived(
 void SimpleTestLogListener::PushLoggedMessage(
     const fuchsia_logger::LogMessage& message) {
   DVLOG(1) << "TestLogListener received: " << message.msg();
-  if (zx::time(message.time()) < ignore_before_) {
+  if (message.time() < ignore_before_) {
     return;
   }
   if (on_log_message_) {
