@@ -28,8 +28,9 @@ ScopedClosureRunner::~ScopedClosureRunner() {
 }
 
 void ScopedClosureRunner::RunAndReset() {
-  if (closure_)
+  if (closure_) {
     std::move(closure_).Run();
+  }
 }
 
 void ScopedClosureRunner::ReplaceClosure(OnceClosure closure) {
