@@ -2,33 +2,42 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+#ifdef UNSAFE_BUFFERS_BUILD
+// TODO(crbug.com/40284755): Remove this and spanify to fix the errors.
+#pragma allow_unsafe_buffers
+#endif
+
+#include "base/logging.h"
+
 #include <sstream>
 #include <string>
+#include <string_view>
 
 #include "base/command_line.h"
 #include "base/files/file_util.h"
 #include "base/files/scoped_temp_dir.h"
 #include "base/functional/bind.h"
 #include "base/functional/callback.h"
-#include "base/logging.h"
 #include "base/no_destructor.h"
 #include "base/process/process.h"
 #include "base/run_loop.h"
 #include "base/sanitizer_buildflags.h"
-#include "base/strings/string_piece.h"
+#include "base/strings/strcat.h"
+#include "base/strings/string_number_conversions.h"
 #include "base/strings/utf_string_conversions.h"
 #include "base/test/bind.h"
 #include "base/test/scoped_logging_settings.h"
 #include "base/test/task_environment.h"
 #include "build/build_config.h"
 #include "build/chromeos_buildflags.h"
-
 #include "testing/gmock/include/gmock/gmock.h"
 #include "testing/gtest/include/gtest/gtest.h"
 
 #if BUILDFLAG(IS_POSIX)
+#include <errno.h>
 #include <signal.h>
 #include <unistd.h>
+
 #include "base/posix/eintr_wrapper.h"
 #endif  // BUILDFLAG(IS_POSIX)
 
@@ -52,14 +61,14 @@
 #include <zircon/types.h>
 #endif  // BUILDFLAG(IS_FUCHSIA)
 
-#include "third_party/abseil-cpp/absl/types/optional.h"
+#include <optional>
 
 namespace logging {
 
 namespace {
 
-using ::testing::Return;
 using ::testing::_;
+using ::testing::Return;
 
 class LoggingTest : public testing::Test {
  protected:
@@ -82,7 +91,7 @@ class MockLogAssertHandler {
  public:
   MOCK_METHOD4(
       HandleLogAssert,
-      void(const char*, int, const base::StringPiece, const base::StringPiece));
+      void(const char*, int, const std::string_view, const std::string_view));
 };
 
 TEST_F(LoggingTest, BasicLogging) {
@@ -92,16 +101,19 @@ TEST_F(LoggingTest, BasicLogging) {
   int expected_logs = 4;
 
   // 4 verbose logs: VLOG, VLOG_IF, VPLOG, VPLOG_IF.
-  if (VLOG_IS_ON(0))
+  if (VLOG_IS_ON(0)) {
     expected_logs += 4;
+  }
 
   // 4 debug logs: DLOG, DLOG_IF, DPLOG, DPLOG_IF.
-  if (DCHECK_IS_ON())
+  if (DCHECK_IS_ON()) {
     expected_logs += 4;
+  }
 
   // 4 verbose debug logs: DVLOG, DVLOG_IF, DVPLOG, DVPLOG_IF
-  if (VLOG_IS_ON(0) && DCHECK_IS_ON())
+  if (VLOG_IS_ON(0) && DCHECK_IS_ON()) {
     expected_logs += 4;
+  }
 
   EXPECT_CALL(mock_log_source, Log())
       .Times(expected_logs)
@@ -200,8 +212,9 @@ TEST_F(LoggingTest, LoggingIsLazyByDestination) {
   EXPECT_CALL(mock_log_source, Log()).Times(0);
 
   // Severity >= ERROR is always printed to stderr.
-  EXPECT_CALL(mock_log_source_error, Log()).Times(1).
-      WillRepeatedly(Return("log message"));
+  EXPECT_CALL(mock_log_source_error, Log())
+      .Times(1)
+      .WillRepeatedly(Return("log message"));
 
   LoggingSettings settings;
   settings.logging_dest = LOG_NONE;
@@ -365,7 +378,8 @@ TEST_F(LoggingTest, DuplicateLogFile) {
 #endif  // BUILDFLAG(IS_CHROMEOS_ASH)
 
 #if !CHECK_WILL_STREAM() && BUILDFLAG(IS_WIN)
-NOINLINE void CheckContainingFunc(int death_location) {
+// Tell clang to not optimize this function or else it will remove the CHECKs.
+[[clang::optnone]] NOINLINE void CheckContainingFunc(int death_location) {
   CHECK(death_location != 1);
   CHECK(death_location != 2);
   CHECK(death_location != 3);
@@ -555,9 +569,14 @@ TEST_F(LoggingTest, CheckCausesDistinctBreakpoints) {
   ASSERT_NE(0u, child_crash_addr_1);
   ASSERT_NE(0u, child_crash_addr_2);
   ASSERT_NE(0u, child_crash_addr_3);
+#if defined(OFFICIAL_BUILD)
+  // In unofficial builds, we'll end up in std::abort
+  // for each crash. In official builds, we should get a different
+  // crash address for each location.
   ASSERT_NE(child_crash_addr_1, child_crash_addr_2);
   ASSERT_NE(child_crash_addr_1, child_crash_addr_3);
   ASSERT_NE(child_crash_addr_2, child_crash_addr_3);
+#endif  // defined(OFFICIAL_BUILD)
 }
 #elif BUILDFLAG(IS_POSIX) && !BUILDFLAG(IS_NACL) && !BUILDFLAG(IS_IOS) && \
     (defined(ARCH_CPU_X86_FAMILY) || defined(ARCH_CPU_ARM_FAMILY))
@@ -608,6 +627,7 @@ void CrashChildMain(int death_location) {
   ASSERT_EQ(0, sigaction(SIGTRAP, &act, nullptr));
   ASSERT_EQ(0, sigaction(SIGBUS, &act, nullptr));
   ASSERT_EQ(0, sigaction(SIGILL, &act, nullptr));
+  ASSERT_EQ(0, sigaction(SIGABRT, &act, nullptr));
   DO_CHECK(death_location != 1);
   DO_CHECK(death_location != 2);
   printf("\n");
@@ -650,9 +670,15 @@ TEST_F(LoggingTest, CheckCausesDistinctBreakpoints) {
   ASSERT_NE(0u, child_crash_addr_1);
   ASSERT_NE(0u, child_crash_addr_2);
   ASSERT_NE(0u, child_crash_addr_3);
+
+#if defined(OFFICIAL_BUILD)
+  // In unofficial builds, we'll end up in std::abort
+  // for each crash. In official builds, we should get a different
+  // crash address for each location.
   ASSERT_NE(child_crash_addr_1, child_crash_addr_2);
   ASSERT_NE(child_crash_addr_1, child_crash_addr_3);
   ASSERT_NE(child_crash_addr_2, child_crash_addr_3);
+#endif
 }
 #endif  // BUILDFLAG(IS_POSIX)
 
@@ -680,18 +706,18 @@ TEST_F(LoggingTest, NestedLogAssertHandlers) {
   EXPECT_CALL(
       handler_a,
       HandleLogAssert(
-          _, _, base::StringPiece("First assert must be caught by handler_a"),
+          _, _, std::string_view("First assert must be caught by handler_a"),
           _));
   EXPECT_CALL(
       handler_b,
       HandleLogAssert(
-          _, _, base::StringPiece("Second assert must be caught by handler_b"),
+          _, _, std::string_view("Second assert must be caught by handler_b"),
           _));
   EXPECT_CALL(
       handler_a,
       HandleLogAssert(
           _, _,
-          base::StringPiece("Last assert must be caught by handler_a again"),
+          std::string_view("Last assert must be caught by handler_a again"),
           _));
 
   logging::ScopedLogAssertHandler scoped_handler_a(base::BindRepeating(
@@ -715,17 +741,17 @@ TEST_F(LoggingTest, NestedLogAssertHandlers) {
 // found by ADL, since defining another operator<< prevents name lookup from
 // looking in the global namespace.
 namespace nested_test {
-  class Streamable {};
-  [[maybe_unused]] std::ostream& operator<<(std::ostream& out,
-                                            const Streamable&) {
-    return out << "Streamable";
-  }
-  TEST_F(LoggingTest, StreamingWstringFindsCorrectOperator) {
-    std::wstring wstr = L"Hello World";
-    std::ostringstream ostr;
-    ostr << wstr;
-    EXPECT_EQ("Hello World", ostr.str());
-  }
+class Streamable {};
+[[maybe_unused]] std::ostream& operator<<(std::ostream& out,
+                                          const Streamable&) {
+  return out << "Streamable";
+}
+TEST_F(LoggingTest, StreamingWstringFindsCorrectOperator) {
+  std::wstring wstr = L"Hello World";
+  std::ostringstream ostr;
+  ostr << wstr;
+  EXPECT_EQ("Hello World", ostr.str());
+}
 }  // namespace nested_test
 
 TEST_F(LoggingTest, LogPrefix) {
@@ -870,8 +896,9 @@ TEST_F(LoggingTest, ScopedVmoduleSwitches) {
 
   // To avoid unreachable-code warnings when VLOG is disabled at compile-time.
   int expected_logs = 0;
-  if (VLOG_IS_ON(0))
+  if (VLOG_IS_ON(0)) {
     expected_logs += 1;
+  }
 
   SetMinLogLevel(LOGGING_FATAL);
 
@@ -917,6 +944,81 @@ TEST_F(LoggingTest, BuildCrashString) {
   EXPECT_EQ("file.cc:42: Hello", msg.BuildCrashString());
 }
 
+TEST_F(LoggingTest, SystemErrorNotChanged) {
+  auto set_last_error = [](logging::SystemErrorCode error) {
+#if BUILDFLAG(IS_WIN)
+    ::SetLastError(error);
+#else
+    errno = error;
+#endif
+  };
+
+  SystemErrorCode during_streaming = 0;
+  SystemErrorCode set_during_streaming = 0;
+
+  set_last_error(SystemErrorCode(123));
+  LOG(WARNING) << (during_streaming = GetLastSystemErrorCode())
+               << (set_last_error(SystemErrorCode(42)),
+                   set_during_streaming = GetLastSystemErrorCode());
+
+  // Initializing the LogMessage shouldn't change the observable error code.
+  EXPECT_EQ(SystemErrorCode(123), during_streaming);
+  // Verify that we can set and get the error code during streaming.
+  EXPECT_EQ(SystemErrorCode(42), set_during_streaming);
+  // Verify that the last set error code (during streaming) is preserved after
+  // logging as well.
+  EXPECT_EQ(SystemErrorCode(42), GetLastSystemErrorCode());
+
+  // Repeat the test above but using PLOG.
+  during_streaming = 0;
+  set_during_streaming = 0;
+  set_last_error(SystemErrorCode(123));
+  PLOG(ERROR) << (during_streaming = GetLastSystemErrorCode())
+              << (set_last_error(SystemErrorCode(42)),
+                  set_during_streaming = GetLastSystemErrorCode());
+
+  EXPECT_EQ(SystemErrorCode(123), during_streaming);
+  EXPECT_EQ(SystemErrorCode(42), set_during_streaming);
+  EXPECT_EQ(SystemErrorCode(42), GetLastSystemErrorCode());
+}
+
+TEST_F(LoggingTest, CorrectSystemErrorUsed) {
+  auto set_last_error = [](logging::SystemErrorCode error) {
+#if BUILDFLAG(IS_WIN)
+    ::SetLastError(error);
+#else
+    errno = error;
+#endif
+  };
+
+  // Use a static because only captureless lambdas can be converted to a
+  // function pointer for SetLogMessageHandler().
+  static base::NoDestructor<std::string> log_string;
+  SetLogMessageHandler([](int severity, const char* file, int line,
+                          size_t start, const std::string& str) -> bool {
+    *log_string = str;
+    return true;
+  });
+
+  const SystemErrorCode kTestError = 28;
+  const std::string kExpectedSystemErrorMsg =
+      SystemErrorCodeToString(kTestError);
+
+  set_last_error(kTestError);
+  PLOG(ERROR);
+
+  // Test that the last system error code got printed as expected.
+  EXPECT_NE(std::string::npos, log_string->find(kExpectedSystemErrorMsg));
+
+  if (DCHECK_IS_ON()) {
+    *log_string = "";
+    set_last_error(kTestError);
+    DPLOG(ERROR);
+
+    EXPECT_NE(std::string::npos, log_string->find(kExpectedSystemErrorMsg));
+  }
+}
+
 TEST_F(LoggingTest, BuildTimeVLOG) {
   // Use a static because only captureless lambdas can be converted to a
   // function pointer for SetLogMessageHandler().
