@@ -9,10 +9,10 @@
 
 #include "base/memory/platform_shared_memory_mapper.h"
 
-#include "base/logging.h"
-
 #include <lib/zx/vmar.h>
+
 #include "base/fuchsia/fuchsia_logging.h"
+#include "base/logging.h"
 
 namespace base {
 
@@ -23,8 +23,9 @@ std::optional<span<uint8_t>> PlatformSharedMemoryMapper::Map(
     size_t size) {
   uintptr_t addr;
   zx_vm_option_t options = ZX_VM_REQUIRE_NON_RESIZABLE | ZX_VM_PERM_READ;
-  if (write_allowed)
+  if (write_allowed) {
     options |= ZX_VM_PERM_WRITE;
+  }
   zx_status_t status = zx::vmar::root_self()->map(options, /*vmar_offset=*/0,
                                                   *handle, offset, size, &addr);
   if (status != ZX_OK) {
@@ -32,14 +33,15 @@ std::optional<span<uint8_t>> PlatformSharedMemoryMapper::Map(
     return std::nullopt;
   }
 
-  return make_span(reinterpret_cast<uint8_t*>(addr), size);
+  return span(reinterpret_cast<uint8_t*>(addr), size);
 }
 
 void PlatformSharedMemoryMapper::Unmap(span<uint8_t> mapping) {
   uintptr_t addr = reinterpret_cast<uintptr_t>(mapping.data());
   zx_status_t status = zx::vmar::root_self()->unmap(addr, mapping.size());
-  if (status != ZX_OK)
+  if (status != ZX_OK) {
     ZX_DLOG(ERROR, status) << "zx_vmar_unmap";
+  }
 }
 
 }  // namespace base
