@@ -9,19 +9,20 @@
 
 #include "base/memory/platform_shared_memory_mapper.h"
 
+#include <aclapi.h>
+
 #include "base/logging.h"
 #include "partition_alloc/page_allocator.h"
 
-#include <aclapi.h>
-
 namespace base {
 
 namespace {
 // Returns the length of the memory section starting at the supplied address.
 size_t GetMemorySectionSize(void* address) {
   MEMORY_BASIC_INFORMATION memory_info;
-  if (!::VirtualQuery(address, &memory_info, sizeof(memory_info)))
+  if (!::VirtualQuery(address, &memory_info, sizeof(memory_info))) {
     return 0;
+  }
   return memory_info.RegionSize -
          static_cast<size_t>(static_cast<char*>(address) -
                              static_cast<char*>(memory_info.AllocationBase));
@@ -40,8 +41,9 @@ std::optional<span<uint8_t>> PlatformSharedMemoryMapper::Map(
     address = MapViewOfFile(
         handle, FILE_MAP_READ | (write_allowed ? FILE_MAP_WRITE : 0),
         static_cast<DWORD>(offset >> 32), static_cast<DWORD>(offset), size);
-    if (address)
+    if (address) {
       break;
+    }
     partition_alloc::ReleaseReservation();
   }
   if (!address) {
@@ -49,13 +51,13 @@ std::optional<span<uint8_t>> PlatformSharedMemoryMapper::Map(
     return std::nullopt;
   }
 
-  return make_span(static_cast<uint8_t*>(address),
-                   GetMemorySectionSize(address));
+  return span(static_cast<uint8_t*>(address), GetMemorySectionSize(address));
 }
 
 void PlatformSharedMemoryMapper::Unmap(span<uint8_t> mapping) {
-  if (!UnmapViewOfFile(mapping.data()))
+  if (!UnmapViewOfFile(mapping.data())) {
     DPLOG(ERROR) << "UnmapViewOfFile";
+  }
 }
 
 }  // namespace base
