@@ -2,13 +2,17 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+#ifdef UNSAFE_BUFFERS_BUILD
+// TODO(crbug.com/390223051): Remove C-library calls to fix the errors.
+#pragma allow_unsafe_libc_calls
+#endif
+
 #include "base/metrics/field_trial.h"
 
 #include <algorithm>
 #include <string_view>
 #include <utility>
 
-#include "base/auto_reset.h"
 #include "base/base_switches.h"
 #include "base/command_line.h"
 #include "base/containers/span.h"
@@ -27,7 +31,6 @@
 #include "base/rand_util.h"
 #include "base/strings/strcat.h"
 #include "base/strings/string_number_conversions.h"
-
 #include "base/strings/string_split.h"
 #include "base/strings/string_util.h"
 #include "base/strings/stringprintf.h"
@@ -41,11 +44,12 @@
 #endif
 
 #if BUILDFLAG(IS_APPLE) && BUILDFLAG(USE_BLINK)
-#include "base/mac/mach_port_rendezvous.h"
+#include "base/apple/mach_port_rendezvous.h"
 #endif
 
 #if BUILDFLAG(IS_POSIX) && BUILDFLAG(USE_BLINK)
 #include <unistd.h>  // For getppid().
+
 #include "base/threading/platform_thread.h"
 // On POSIX, the fd is shared using the mapping in GlobalDescriptors.
 #include "base/posix/global_descriptors.h"
@@ -119,15 +123,15 @@ void PickleFieldTrial(const FieldTrial::PickleState& trial_state,
       *trial_state.trial_name, *trial_state.group_name, &params);
 
   // Write params to pickle.
-  for (const auto& param : params)
+  for (const auto& param : params) {
     WriteStringPair(pickle, param.first, param.second);
+  }
 }
 
 // Returns the boundary value for comparing against the FieldTrial's added
 // groups for a given `divisor` (total probability) and `entropy_value`.
-FieldTrial::Probability GetGroupBoundaryValue(
-    FieldTrial::Probability divisor,
-    double entropy_value) {
+FieldTrial::Probability GetGroupBoundaryValue(FieldTrial::Probability divisor,
+                                              double entropy_value) {
   // Add a tiny epsilon value to get consistent results when converting floating
   // points to int. Without it, boundary values have inconsistent results, e.g.:
   //
@@ -218,8 +222,9 @@ bool FieldTrial::FieldTrialEntry::GetParams(
   while (true) {
     std::string_view key;
     std::string_view value;
-    if (!ReadStringPair(&iter, &key, &value))
+    if (!ReadStringPair(&iter, &key, &value)) {
       return key.empty();  // Non-empty is bad: got one of a pair.
+    }
     (*params)[std::string(key)] = std::string(value);
   }
 }
@@ -245,10 +250,12 @@ bool FieldTrial::FieldTrialEntry::ReadStringPair(
     PickleIterator* iter,
     std::string_view* trial_name,
     std::string_view* group_name) const {
-  if (!iter->ReadStringPiece(trial_name))
+  if (!iter->ReadStringPiece(trial_name)) {
     return false;
-  if (!iter->ReadStringPiece(group_name))
+  }
+  if (!iter->ReadStringPiece(group_name)) {
     return false;
+  }
   return true;
 }
 
@@ -275,8 +282,9 @@ void FieldTrial::AppendGroup(const std::string& name,
   DCHECK_LE(group_probability, divisor_);
   DCHECK_GE(group_probability, 0);
 
-  if (enable_benchmarking_)
+  if (enable_benchmarking_) {
     group_probability = 0;
+  }
 
   accumulated_group_probability_ += group_probability;
 
@@ -291,8 +299,9 @@ void FieldTrial::AppendGroup(const std::string& name,
 
 void FieldTrial::Activate() {
   FinalizeGroupChoice();
-  if (trial_registered_)
+  if (trial_registered_) {
     FieldTrialList::NotifyFieldTrialGroupSelection(this);
+  }
 }
 
 const std::string& FieldTrial::group_name() {
@@ -310,8 +319,9 @@ const std::string& FieldTrial::GetGroupNameWithoutActivation() {
 void FieldTrial::SetForced() {
   // We might have been forced before (e.g., by CreateFieldTrial) and it's
   // first come first served, e.g., command line switch has precedence.
-  if (forced_)
+  if (forced_) {
     return;
+  }
 
   // And we must finalize the group choice before we mark ourselves as forced.
   FinalizeGroupChoice();
@@ -442,16 +452,18 @@ void FieldTrial::SetTrialRegistered() {
 
 void FieldTrial::SetGroupChoice(const std::string& group_name, int number) {
   group_ = number;
-  if (group_name.empty())
+  if (group_name.empty()) {
     StringAppendF(&group_name_, "%d", group_);
-  else
+  } else {
     group_name_ = group_name;
+  }
   DVLOG(1) << "Field trial: " << trial_name_ << " Group choice:" << group_name_;
 }
 
 void FieldTrial::FinalizeGroupChoice() {
-  if (group_ != kNotFinalized)
+  if (group_ != kNotFinalized) {
     return;
+  }
   accumulated_group_probability_ = divisor_;
   // Here it's OK to use `kDefaultGroupNumber` since we can't be forced and not
   // finalized.
@@ -460,8 +472,9 @@ void FieldTrial::FinalizeGroupChoice() {
 }
 
 bool FieldTrial::GetActiveGroup(ActiveGroup* active_group) const {
-  if (!group_reported_)
+  if (!group_reported_) {
     return false;
+  }
   DCHECK_NE(group_, kNotFinalized);
   active_group->trial_name = trial_name_;
   active_group->group_name = group_name_;
@@ -534,8 +547,9 @@ FieldTrial* FieldTrialList::FactoryGetFieldTrial(
 
 // static
 FieldTrial* FieldTrialList::Find(std::string_view trial_name) {
-  if (!global_)
+  if (!global_) {
     return nullptr;
+  }
   AutoLock auto_lock(global_->lock_);
   return global_->PreLockedFind(trial_name);
 }
@@ -543,8 +557,9 @@ FieldTrial* FieldTrialList::Find(std::string_view trial_name) {
 // static
 std::string FieldTrialList::FindFullName(std::string_view trial_name) {
   FieldTrial* field_trial = Find(trial_name);
-  if (field_trial)
+  if (field_trial) {
     return field_trial->group_name();
+  }
   return std::string();
 }
 
@@ -564,8 +579,9 @@ std::vector<FieldTrial::State> FieldTrialList::GetAllFieldTrialStates(
     PassKey<test::ScopedFeatureList>) {
   std::vector<FieldTrial::State> states;
 
-  if (!global_)
+  if (!global_) {
     return states;
+  }
 
   AutoLock auto_lock(global_->lock_);
   for (const auto& registered : global_->registered_) {
@@ -586,8 +602,9 @@ std::vector<FieldTrial::State> FieldTrialList::GetAllFieldTrialStates(
 
 // static
 void FieldTrialList::AllStatesToString(std::string* output) {
-  if (!global_)
+  if (!global_) {
     return;
+  }
   AutoLock auto_lock(global_->lock_);
 
   for (const auto& registered : global_->registered_) {
@@ -614,9 +631,10 @@ std::string FieldTrialList::AllParamsToString(EscapeDataFunc encode_data_func) {
     if (params_associator->GetFieldTrialParamsWithoutFallback(
             *trial.trial_name, *trial.group_name, &params)) {
       if (params.size() > 0) {
-        // Add comma to seprate from previous entry if it exists.
-        if (!output.empty())
+        // Add comma to separate from previous entry if it exists.
+        if (!output.empty()) {
           output.append(1, ',');
+        }
 
         output.append(encode_data_func(*trial.trial_name));
         output.append(1, '.');
@@ -680,8 +698,9 @@ std::set<std::string> FieldTrialList::GetActiveTrialsOfParentProcess() {
 bool FieldTrialList::CreateTrialsFromString(const std::string& trials_string,
                                             bool override_trials) {
   DCHECK(global_);
-  if (trials_string.empty() || !global_)
+  if (trials_string.empty() || !global_) {
     return true;
+  }
 
   std::vector<FieldTrial::State> entries;
   if (!FieldTrial::ParseFieldTrialsString(trials_string, override_trials,
@@ -747,15 +766,14 @@ void FieldTrialList::PopulateLaunchOptionsWithFieldTrialState(
   CHECK(global_->readonly_allocator_region_.IsValid());
 
   global_->field_trial_allocator_->UpdateTrackingHistograms();
-  shared_memory::AddToLaunchParameters(
-      switches::kFieldTrialHandle,
-      global_->readonly_allocator_region_.Duplicate(),
+  shared_memory::AddToLaunchParameters(switches::kFieldTrialHandle,
+                                       global_->readonly_allocator_region_,
 #if BUILDFLAG(IS_APPLE)
-      kFieldTrialRendezvousKey,
+                                       kFieldTrialRendezvousKey,
 #elif BUILDFLAG(IS_POSIX)
-      descriptor_key, descriptor_to_share,
+                                       descriptor_key, descriptor_to_share,
 #endif
-      command_line, launch_options);
+                                       command_line, launch_options);
 
   // Append --enable-features and --disable-features switches corresponding
   // to the features enabled on the command-line, so that child and browser
@@ -780,8 +798,9 @@ void FieldTrialList::PopulateLaunchOptionsWithFieldTrialState(
 // static
 ReadOnlySharedMemoryRegion
 FieldTrialList::DuplicateFieldTrialSharedMemoryForTesting() {
-  if (!global_)
+  if (!global_) {
     return ReadOnlySharedMemoryRegion();
+  }
 
   return global_->readonly_allocator_region_.Duplicate();
 }
@@ -794,15 +813,17 @@ FieldTrial* FieldTrialList::CreateFieldTrial(std::string_view name,
   DCHECK(global_);
   DCHECK_GE(name.size(), 0u);
   DCHECK_GE(group_name.size(), 0u);
-  if (name.empty() || group_name.empty() || !global_)
+  if (name.empty() || group_name.empty() || !global_) {
     return nullptr;
+  }
 
   FieldTrial* field_trial = FieldTrialList::Find(name);
   if (field_trial) {
     // In single process mode, or when we force them from the command line,
     // we may have already created the field trial.
-    if (field_trial->group_name_internal() != group_name)
+    if (field_trial->group_name_internal() != group_name) {
       return nullptr;
+    }
     return field_trial;
   }
   const int kTotalProbability = 100;
@@ -830,8 +851,9 @@ void FieldTrialList::RemoveObserver(Observer* observer) {
 
 // static
 void FieldTrialList::NotifyFieldTrialGroupSelection(FieldTrial* field_trial) {
-  if (!global_)
+  if (!global_) {
     return;
+  }
 
   std::vector<raw_ptr<Observer, VectorExperimental>> local_observers;
   std::vector<raw_ptr<Observer, VectorExperimental>>
@@ -839,8 +861,9 @@ void FieldTrialList::NotifyFieldTrialGroupSelection(FieldTrial* field_trial) {
 
   {
     AutoLock auto_lock(global_->lock_);
-    if (field_trial->group_reported_)
+    if (field_trial->group_reported_) {
       return;
+    }
     field_trial->group_reported_ = true;
 
     ++global_->num_ongoing_notify_field_trial_group_selection_calls_;
@@ -874,16 +897,18 @@ void FieldTrialList::NotifyFieldTrialGroupSelection(FieldTrial* field_trial) {
 
 // static
 size_t FieldTrialList::GetFieldTrialCount() {
-  if (!global_)
+  if (!global_) {
     return 0;
+  }
   AutoLock auto_lock(global_->lock_);
   return global_->registered_.size();
 }
 
 // static
 size_t FieldTrialList::GetRandomizedFieldTrialCount() {
-  if (!global_)
+  if (!global_) {
     return 0;
+  }
   AutoLock auto_lock(global_->lock_);
   return global_->num_registered_randomized_trials_;
 }
@@ -905,12 +930,14 @@ bool FieldTrialList::GetParamsFromSharedMemory(
   //   allocator should get set up very early in the lifecycle. Try to see if
   //   you can call it after it's been set up.
   AutoLock auto_lock(global_->lock_);
-  if (!global_->field_trial_allocator_)
+  if (!global_->field_trial_allocator_) {
     return false;
+  }
 
   // If ref_ isn't set, then the field trial data can't be in shared memory.
-  if (!field_trial->ref_)
+  if (!field_trial->ref_) {
     return false;
+  }
 
   size_t allocated_size = 0;
   const FieldTrial::FieldTrialEntry* entry =
@@ -920,20 +947,23 @@ bool FieldTrialList::GetParamsFromSharedMemory(
 
   uint64_t actual_size =
       sizeof(FieldTrial::FieldTrialEntry) + entry->pickle_size;
-  if (allocated_size < actual_size)
+  if (allocated_size < actual_size) {
     return false;
+  }
 
   return entry->GetParams(params);
 }
 
 // static
 void FieldTrialList::ClearParamsFromSharedMemoryForTesting() {
-  if (!global_)
+  if (!global_) {
     return;
+  }
 
   AutoLock auto_lock(global_->lock_);
-  if (!global_->field_trial_allocator_)
+  if (!global_->field_trial_allocator_) {
     return;
+  }
 
   // To clear the params, we iterate through every item in the allocator, copy
   // just the trial and group name into a newly-allocated segment and then clear
@@ -1011,8 +1041,9 @@ void FieldTrialList::ClearParamsFromSharedMemoryForTesting() {
 // static
 void FieldTrialList::DumpAllFieldTrialsToPersistentAllocator(
     PersistentMemoryAllocator* allocator) {
-  if (!global_)
+  if (!global_) {
     return;
+  }
   AutoLock auto_lock(global_->lock_);
   for (const auto& registered : global_->registered_) {
     AddToAllocatorWhileLocked(allocator, registered.second);
@@ -1080,8 +1111,9 @@ bool FieldTrialList::CreateTrialsFromSharedMemoryRegion(
     const ReadOnlySharedMemoryRegion& shm_region) {
   ReadOnlySharedMemoryMapping shm_mapping =
       shm_region.MapAt(0, kFieldTrialAllocationSize);
-  if (!shm_mapping.IsValid())
+  if (!shm_mapping.IsValid()) {
     OnOutOfMemory(kFieldTrialAllocationSize);
+  }
 
   return FieldTrialList::CreateTrialsFromSharedMemoryMapping(
       std::move(shm_mapping));
@@ -1122,19 +1154,22 @@ bool FieldTrialList::CreateTrialsFromSharedMemoryMapping(
 
 // static
 void FieldTrialList::InstantiateFieldTrialAllocatorIfNeeded() {
-  if (!global_)
+  if (!global_) {
     return;
+  }
 
   AutoLock auto_lock(global_->lock_);
   // Create the allocator if not already created and add all existing trials.
-  if (global_->field_trial_allocator_ != nullptr)
+  if (global_->field_trial_allocator_ != nullptr) {
     return;
+  }
 
   MappedReadOnlyRegion shm =
       ReadOnlySharedMemoryRegion::Create(kFieldTrialAllocationSize);
 
-  if (!shm.IsValid())
+  if (!shm.IsValid()) {
     OnOutOfMemory(kFieldTrialAllocationSize);
+  }
 
   global_->field_trial_allocator_ =
       std::make_unique<WritableSharedPersistentMemoryAllocator>(
@@ -1159,21 +1194,24 @@ void FieldTrialList::AddToAllocatorWhileLocked(
     PersistentMemoryAllocator* allocator,
     FieldTrial* field_trial) {
   // Don't do anything if the allocator hasn't been instantiated yet.
-  if (allocator == nullptr)
+  if (allocator == nullptr) {
     return;
+  }
 
   // Or if the allocator is read only, which means we are in a child process and
   // shouldn't be writing to it.
-  if (allocator->IsReadonly())
+  if (allocator->IsReadonly()) {
     return;
+  }
 
   FieldTrial::PickleState trial_state;
   field_trial->GetStateWhileLocked(&trial_state);
 
   // Or if we've already added it. We must check after GetState since it can
   // also add to the allocator.
-  if (field_trial->ref_)
+  if (field_trial->ref_) {
     return;
+  }
 
   Pickle pickle;
   PickleFieldTrial(trial_state, &pickle);
@@ -1204,8 +1242,9 @@ void FieldTrialList::ActivateFieldTrialEntryWhileLocked(
   FieldTrialAllocator* allocator = global_->field_trial_allocator_.get();
 
   // Check if we're in the child process and return early if so.
-  if (!allocator || allocator->IsReadonly())
+  if (!allocator || allocator->IsReadonly()) {
     return;
+  }
 
   FieldTrial::FieldTrialRef ref = field_trial->ref_;
   if (ref == FieldTrialAllocator::kReferenceNull) {
@@ -1224,8 +1263,9 @@ void FieldTrialList::ActivateFieldTrialEntryWhileLocked(
 
 FieldTrial* FieldTrialList::PreLockedFind(std::string_view name) {
   auto it = registered_.find(name);
-  if (registered_.end() == it)
+  if (registered_.end() == it) {
     return nullptr;
+  }
   return it->second;
 }
 
@@ -1239,8 +1279,9 @@ void FieldTrialList::Register(FieldTrial* trial, bool is_randomized_trial) {
   trial->SetTrialRegistered();
   global_->registered_[trial->trial_name()] = trial;
 
-  if (is_randomized_trial)
+  if (is_randomized_trial) {
     ++global_->num_registered_randomized_trials_;
+  }
 }
 
 // static
@@ -1262,8 +1303,9 @@ bool FieldTrialList::CreateTrialsFromFieldTrialStatesInternal(
     FieldTrial* trial =
         CreateFieldTrial(entry.trial_name, entry.group_name,
                          /*is_low_anonymity=*/false, entry.is_overridden);
-    if (!trial)
+    if (!trial) {
       return false;
+    }
     if (entry.activated) {
       // Mark the trial as "used" and notify observers, if any.
       // This is useful to ensure that field trials created in child
