@@ -4,6 +4,7 @@
 
 #include "base/profiler/module_cache.h"
 
+#include <algorithm>
 #include <iomanip>
 #include <map>
 #include <memory>
@@ -14,7 +15,6 @@
 #include "base/containers/adapters.h"
 #include "base/functional/callback.h"
 #include "base/functional/callback_helpers.h"
-#include "base/ranges/algorithm.h"
 #include "base/test/bind.h"
 #include "build/build_config.h"
 #include "testing/gtest/include/gtest/gtest.h"
@@ -219,7 +219,7 @@ MAYBE_TEST(ModuleCacheTest, UpdateNonNativeModulesRemoveModuleIsNotDestroyed) {
     std::vector<std::unique_ptr<const ModuleCache::Module>> modules;
     modules.push_back(std::make_unique<FakeModule>(
         1, 1, false,
-        BindLambdaForTesting([&was_destroyed]() { was_destroyed = true; })));
+        BindLambdaForTesting([&was_destroyed] { was_destroyed = true; })));
     const ModuleCache::Module* module = modules.back().get();
     cache.UpdateNonNativeModules({}, std::move(modules));
     cache.UpdateNonNativeModules({module}, {});
@@ -234,7 +234,7 @@ MAYBE_TEST(ModuleCacheTest, UpdateNonNativeModulesRemoveModuleIsNotDestroyed) {
 // https://crbug.com/1127466 case 2.
 MAYBE_TEST(ModuleCacheTest, UpdateNonNativeModulesPartitioning) {
   int destroyed_count = 0;
-  const auto record_destroyed = [&destroyed_count]() { ++destroyed_count; };
+  const auto record_destroyed = [&destroyed_count] { ++destroyed_count; };
   {
     ModuleCache cache;
     std::vector<std::unique_ptr<const ModuleCache::Module>> modules;
@@ -270,7 +270,7 @@ MAYBE_TEST(ModuleCacheTest, UpdateNonNativeModulesReplace) {
 MAYBE_TEST(ModuleCacheTest,
            UpdateNonNativeModulesMultipleRemovedModulesAtSameAddress) {
   int destroyed_count = 0;
-  const auto record_destroyed = [&destroyed_count]() { ++destroyed_count; };
+  const auto record_destroyed = [&destroyed_count] { ++destroyed_count; };
   ModuleCache cache;
 
   // Checks that non-native modules can be repeatedly added and removed at the
@@ -350,11 +350,12 @@ TEST(ModuleCacheTest, CheckAgainstProcMaps) {
   using RegionVector = std::vector<const debug::MappedMemoryRegion*>;
   using PathRegionsMap = std::map<std::string_view, RegionVector>;
   PathRegionsMap path_regions;
-  for (const debug::MappedMemoryRegion& region : regions)
+  for (const debug::MappedMemoryRegion& region : regions) {
     path_regions[region.path].push_back(&region);
+  }
 
   const auto find_last_executable_region = [](const RegionVector& regions) {
-    const auto rloc = base::ranges::find_if(
+    const auto rloc = std::ranges::find_if(
         base::Reversed(regions), [](const debug::MappedMemoryRegion* region) {
           return static_cast<bool>(region->permissions &
                                    debug::MappedMemoryRegion::EXECUTE);
@@ -368,15 +369,17 @@ TEST(ModuleCacheTest, CheckAgainstProcMaps) {
   for (const auto& path_regions_pair : path_regions) {
     // Regions that aren't associated with absolute paths are unlikely to be
     // part of modules.
-    if (path_regions_pair.first.empty() || path_regions_pair.first[0] != '/')
+    if (path_regions_pair.first.empty() || path_regions_pair.first[0] != '/') {
       continue;
+    }
 
     const debug::MappedMemoryRegion* const last_executable_region =
         find_last_executable_region(path_regions_pair.second);
     // The region isn't part of a module if no executable regions are associated
     // with the same path.
-    if (!last_executable_region)
+    if (!last_executable_region) {
       continue;
+    }
 
     // Loop through all the regions associated with the path, checking that
     // modules created for addresses in each region have the expected extents.
@@ -389,8 +392,9 @@ TEST(ModuleCacheTest, CheckAgainstProcMaps) {
       // Not all regions matching the prior conditions are necessarily modules;
       // things like resources are also mmapped into memory from files. Ignore
       // any region isn't part of a module.
-      if (!module)
+      if (!module) {
         continue;
+      }
 
       ++module_count;
 
