@@ -5,9 +5,10 @@
 #include "base/sequence_token.h"
 
 #include "base/atomic_sequence_num.h"
-#include "third_party/abseil-cpp/absl/base/attributes.h"
+#include "base/check.h"
 
-namespace base::internal {
+namespace base {
+namespace internal {
 
 namespace {
 
@@ -17,7 +18,8 @@ base::AtomicSequenceNumber g_task_token_generator;
 
 thread_local SequenceToken current_sequence_token;
 thread_local TaskToken current_task_token;
-thread_local bool current_task_is_thread_bound = true;
+constinit thread_local bool current_task_is_thread_bound = true;
+constinit thread_local bool current_task_is_running_synchronously = false;
 
 }  // namespace
 
@@ -73,19 +75,32 @@ bool CurrentTaskIsThreadBound() {
   return current_task_is_thread_bound;
 }
 
-TaskScope::TaskScope(SequenceToken sequence_token, bool is_single_threaded)
+TaskScope::TaskScope(SequenceToken sequence_token,
+                     bool is_single_threaded,
+                     bool is_running_synchronously)
     : previous_task_token_(TaskToken::GetForCurrentThread()),
       previous_sequence_token_(SequenceToken::GetForCurrentThread()),
-      previous_task_is_thread_bound_(current_task_is_thread_bound) {
+      previous_task_is_thread_bound_(current_task_is_thread_bound),
+      previous_task_is_running_synchronously_(
+          current_task_is_running_synchronously) {
   current_task_token = TaskToken::Create();
   current_sequence_token = sequence_token;
   current_task_is_thread_bound = is_single_threaded;
+  current_task_is_running_synchronously = is_running_synchronously;
 }
 
 TaskScope::~TaskScope() {
   current_task_token = previous_task_token_;
   current_sequence_token = previous_sequence_token_;
   current_task_is_thread_bound = previous_task_is_thread_bound_;
+  current_task_is_running_synchronously =
+      previous_task_is_running_synchronously_;
 }
 
-}  // namespace base::internal
+}  // namespace internal
+
+bool CurrentTaskIsRunningSynchronously() {
+  return internal::current_task_is_running_synchronously;
+}
+
+}  // namespace base
