@@ -7,8 +7,8 @@
 #include <optional>
 #include <string_view>
 
-#include "base/auto_reset.h"
 #include "base/metrics/histogram_macros.h"
+#include "base/profiler/thread_group_profiler.h"
 #include "base/sequence_token.h"
 #include "base/strings/stringprintf.h"
 #include "base/task/common/checked_lock.h"
@@ -20,14 +20,7 @@
 #include "base/trace_event/base_tracing.h"
 #include "third_party/abseil-cpp/absl/container/inlined_vector.h"
 
-namespace base {
-namespace internal {
-
-namespace {
-
-constexpr size_t kMaxNumberOfWorkers2 = 256;
-
-}  // namespace
+namespace base::internal {
 
 // Upon destruction, executes actions that control the number of active workers.
 // Useful to satisfy locking requirements of these actions.
@@ -136,7 +129,7 @@ class ThreadGroupImpl::WorkerDelegate : public WorkerThread::Delegate,
   template <typename Worker>
   bool ContainsWorker(const std::vector<scoped_refptr<Worker>>& workers,
                       const WorkerThread* worker) {
-    auto it = ranges::find_if(
+    auto it = std::ranges::find_if(
         workers,
         [worker](const scoped_refptr<Worker>& i) { return i.get() == worker; });
     return it != workers.end();
@@ -216,6 +209,7 @@ class ThreadGroupImpl::WorkerDelegate : public WorkerThread::Delegate,
 ThreadGroupImpl::ThreadGroupImpl(std::string_view histogram_label,
                                  std::string_view thread_group_label,
                                  ThreadType thread_type_hint,
+                                 int64_t thread_group_type,
                                  TrackedRef<TaskTracker> task_tracker,
                                  TrackedRef<Delegate> delegate)
     : ThreadGroup(histogram_label,
@@ -223,6 +217,7 @@ ThreadGroupImpl::ThreadGroupImpl(std::string_view histogram_label,
                   thread_type_hint,
                   std::move(task_tracker),
                   std::move(delegate)),
+      thread_group_type_(thread_group_type),
       tracked_ref_factory_(this) {
   DCHECK(!thread_group_label_.empty());
 }
@@ -241,6 +236,13 @@ void ThreadGroupImpl::Start(
       service_thread_task_runner, worker_thread_observer, worker_environment,
       synchronous_thread_start_for_testing, may_block_threshold);
 
+  // Create thread group profiler if profiling is enabled after the thread group
+  // start but before worker threads are created.
+  if (ThreadGroupProfiler::IsProfilingEnabled()) {
+    thread_group_profiler_.emplace(service_thread_task_runner,
+                                   thread_group_type_);
+  }
+
   ScopedCommandsExecutor executor(this);
   CheckedAutoLock auto_lock(lock_);
   DCHECK(workers_.empty());
@@ -337,10 +339,15 @@ void ThreadGroupImpl::WorkerDelegate::OnMainEntry(WorkerThread* worker) {
   worker_only().worker_thread_ = static_cast<WorkerThread*>(worker);
   SetBlockingObserverForCurrentThread(this);
 
+  if (outer_->thread_group_profiler_) {
+    outer_->thread_group_profiler_->OnWorkerThreadStarted(worker);
+  }
+
   if (outer_->worker_started_for_testing_) {
-    // When |worker_started_for_testing_| is set, the thread that starts workers
-    // should wait for a worker to have started before starting the next one,
-    // and there should only be one thread that wakes up workers at a time.
+    // When |worker_started_for_testing_| is set, the thread that starts
+    // workers should wait for a worker to have started before starting the
+    // next one, and there should only be one thread that wakes up workers at
+    // a time.
     DCHECK(!outer_->worker_started_for_testing_->IsSignaled());
     outer_->worker_started_for_testing_->Signal();
   }
@@ -370,6 +377,10 @@ void ThreadGroupImpl::WorkerDelegate::OnMainExit(WorkerThread* worker_base) {
   worker_only().win_thread_environment.reset();
 #endif  // BUILDFLAG(IS_WIN)
 
+  if (outer_->thread_group_profiler_) {
+    outer_->thread_group_profiler_->OnWorkerThreadExiting(worker_base);
+  }
+
   // Count cleaned up workers for tests. It's important to do this here
   // instead of at the end of CleanupLockRequired() because some side-effects
   // of cleaning up happen outside the lock (e.g. recording histograms) and
@@ -420,8 +431,22 @@ RegisteredTaskSource ThreadGroupImpl::WorkerDelegate::GetWork(
   DCHECK(!read_worker().current_shutdown_behavior);
 
   ScopedCommandsExecutor executor(outer_.get());
-  CheckedAutoLock auto_lock(outer_->lock_);
-  return GetWorkLockRequired(&executor, worker);
+  RegisteredTaskSource task_source;
+  {
+    CheckedAutoLock auto_lock(outer_->lock_);
+    task_source = GetWorkLockRequired(&executor, worker);
+  }
+  // Notify the profiler on the worker thread status when profiling is enabled.
+  // This must be called without holding lock_ as lock_ is not a universal
+  // predecessor that does not satisfy OnWorkerThreadIdle's CheckedLock.
+  if (outer_->thread_group_profiler_) {
+    // GetWork is only called when waking up, i.e. from an idle state. No need
+    // to mark it idle again if no task source available.
+    if (task_source) {
+      outer_->thread_group_profiler_->OnWorkerThreadActive(worker);
+    }
+  }
+  return task_source;
 }
 
 RegisteredTaskSource ThreadGroupImpl::WorkerDelegate::GetWorkLockRequired(
@@ -507,39 +532,47 @@ RegisteredTaskSource ThreadGroupImpl::WorkerDelegate::SwapProcessedTask(
 
   ScopedCommandsExecutor workers_executor(outer_.get());
   ScopedReenqueueExecutor reenqueue_executor;
-  CheckedAutoLock auto_lock(outer_->lock_);
+  RegisteredTaskSource next_task_source;
+  {
+    CheckedAutoLock auto_lock(outer_->lock_);
 
-  // During shutdown, max_tasks may have been incremented in
-  // OnShutdownStartedLockRequired().
-  if (incremented_max_tasks_for_shutdown_) {
-    DCHECK(outer_->shutdown_started_);
-    outer_->DecrementMaxTasksLockRequired();
-    if (*read_worker().current_task_priority == TaskPriority::BEST_EFFORT) {
-      outer_->DecrementMaxBestEffortTasksLockRequired();
+    // During shutdown, max_tasks may have been incremented in
+    // OnShutdownStartedLockRequired().
+    if (incremented_max_tasks_for_shutdown_) {
+      DCHECK(outer_->shutdown_started_);
+      outer_->DecrementMaxTasksLockRequired();
+      if (*read_worker().current_task_priority == TaskPriority::BEST_EFFORT) {
+        outer_->DecrementMaxBestEffortTasksLockRequired();
+      }
+      incremented_max_tasks_since_blocked_ = false;
+      incremented_max_best_effort_tasks_since_blocked_ = false;
+      incremented_max_tasks_for_shutdown_ = false;
     }
-    incremented_max_tasks_since_blocked_ = false;
-    incremented_max_best_effort_tasks_since_blocked_ = false;
-    incremented_max_tasks_for_shutdown_ = false;
+
+    DCHECK(read_worker().blocking_start_time.is_null());
+    DCHECK(!incremented_max_tasks_since_blocked_);
+    DCHECK(!incremented_max_best_effort_tasks_since_blocked_);
+
+    // Running task bookkeeping.
+    outer_->DecrementTasksRunningLockRequired(
+        *read_worker().current_task_priority);
+    write_worker().current_shutdown_behavior = std::nullopt;
+    write_worker().current_task_priority = std::nullopt;
+
+    if (transaction_with_task_source) {
+      outer_->ReEnqueueTaskSourceLockRequired(
+          &workers_executor, &reenqueue_executor,
+          std::move(transaction_with_task_source.value()));
+    }
+
+    next_task_source = GetWorkLockRequired(&workers_executor,
+                                           static_cast<WorkerThread*>(worker));
   }
-
-  DCHECK(read_worker().blocking_start_time.is_null());
-  DCHECK(!incremented_max_tasks_since_blocked_);
-  DCHECK(!incremented_max_best_effort_tasks_since_blocked_);
-
-  // Running task bookkeeping.
-  outer_->DecrementTasksRunningLockRequired(
-      *read_worker().current_task_priority);
-  write_worker().current_shutdown_behavior = std::nullopt;
-  write_worker().current_task_priority = std::nullopt;
-
-  if (transaction_with_task_source) {
-    outer_->ReEnqueueTaskSourceLockRequired(
-        &workers_executor, &reenqueue_executor,
-        std::move(transaction_with_task_source.value()));
+  // Must be called without holding a lock.
+  if (outer_->thread_group_profiler_ && !task_source) {
+    outer_->thread_group_profiler_->OnWorkerThreadIdle(worker);
   }
-
-  return GetWorkLockRequired(&workers_executor,
-                             static_cast<WorkerThread*>(worker));
+  return next_task_source;
 }
 
 bool ThreadGroupImpl::WorkerDelegate::CanCleanupLockRequired(
@@ -575,7 +608,7 @@ void ThreadGroupImpl::WorkerDelegate::CleanupLockRequired(
   }
 
   // Remove the worker from |workers_|.
-  auto worker_iter = ranges::find(outer_->workers_, worker);
+  auto worker_iter = std::ranges::find(outer_->workers_, worker);
   CHECK(worker_iter != outer_->workers_.end(), base::NotFatalUntil::M125);
   outer_->workers_.erase(worker_iter);
 }
@@ -762,6 +795,10 @@ void ThreadGroupImpl::WorkerDelegate::IncrementMaxTasksLockRequired()
 }
 
 void ThreadGroupImpl::JoinForTesting() {
+  // profiler needs to shutdown first to not block worker thread joins.
+  if (thread_group_profiler_) {
+    thread_group_profiler_->Shutdown();
+  }
   decltype(workers_) workers_copy;
   {
     CheckedAutoLock auto_lock(lock_);
@@ -797,10 +834,10 @@ size_t ThreadGroupImpl::NumberOfIdleWorkersLockRequiredForTesting() const {
 
 void ThreadGroupImpl::MaintainAtLeastOneIdleWorkerLockRequired(
     ScopedCommandsExecutor* executor) {
-  if (workers_.size() == kMaxNumberOfWorkers2) {
+  if (workers_.size() == kMaxNumberOfWorkers) {
     return;
   }
-  DCHECK_LT(workers_.size(), kMaxNumberOfWorkers2);
+  DCHECK_LT(workers_.size(), kMaxNumberOfWorkers);
 
   if (!idle_workers_set_.IsEmpty()) {
     return;
@@ -821,7 +858,7 @@ ThreadGroupImpl::CreateAndRegisterWorkerLockRequired(
     ScopedCommandsExecutor* executor) {
   DCHECK(!join_for_testing_started_);
   DCHECK_LT(workers_.size(), max_tasks_);
-  DCHECK_LT(workers_.size(), kMaxNumberOfWorkers2);
+  DCHECK_LT(workers_.size(), kMaxNumberOfWorkers);
   DCHECK(idle_workers_set_.IsEmpty());
 
   // WorkerThread needs |lock_| as a predecessor for its thread lock because in
@@ -831,9 +868,7 @@ ThreadGroupImpl::CreateAndRegisterWorkerLockRequired(
       thread_type_hint_,
       std::make_unique<WorkerDelegate>(
           tracked_ref_factory_.GetTrackedRef(),
-          /* is_excess=*/after_start().no_worker_reclaim
-              ? workers_.size() >= after_start().initial_max_tasks
-              : true),
+          /* is_excess=*/workers_.size() >= after_start().initial_max_tasks),
       task_tracker_, worker_sequence_num_++, &lock_);
 
   workers_.push_back(worker);
@@ -868,6 +903,10 @@ void ThreadGroupImpl::OnShutdownStarted() {
     return;
   }
 
+  if (thread_group_profiler_) {
+    thread_group_profiler_->Shutdown();
+  }
+
   // Start a MAY_BLOCK scope on each worker that is already running a task.
   for (scoped_refptr<WorkerThread>& worker : workers_) {
     // The delegates of workers inside a ThreadGroupImpl should be
@@ -970,5 +1009,4 @@ void ThreadGroupImpl::AdjustMaxTasks() {
   EnsureEnoughWorkersLockRequired(&executor);
 }
 
-}  // namespace internal
-}  // namespace base
+}  // namespace base::internal
