@@ -11,7 +11,6 @@
 #include <type_traits>
 #include <vector>
 
-#include "base/atomicops.h"
 #include "base/auto_reset.h"
 #include "base/base_export.h"
 #include "base/bits.h"
@@ -150,7 +149,6 @@ class BASE_EXPORT HangWatcher : public DelegateSimpleThread::Delegate {
   // Initializes HangWatcher. Must be called once on the main thread during
   // startup while single-threaded.
   static void InitializeOnMainThread(ProcessType process_type,
-                                     bool is_zygote_child,
                                      bool emit_crashes);
 
   // Returns the values that were set through InitializeOnMainThread() to their
@@ -292,7 +290,7 @@ class BASE_EXPORT HangWatcher : public DelegateSimpleThread::Delegate {
    public:
     struct WatchStateCopy {
       base::TimeTicks deadline;
-      base::PlatformThreadId thread_id;
+      uint64_t thread_id;
     };
 
     WatchStateSnapShot();
@@ -636,6 +634,7 @@ class BASE_EXPORT HangWatchState {
 #endif
 
   PlatformThreadId GetThreadID() const;
+  uint64_t GetSystemWideThreadID() const;
 
   // Retrieve the current hang watch deadline directly. For testing only.
   HangWatchDeadline* GetHangWatchDeadlineForTesting();
@@ -667,6 +666,14 @@ class BASE_EXPORT HangWatchState {
   // only.
   PlatformThreadId thread_id_;
 
+#if BUILDFLAG(IS_MAC)
+  // TODO(crbug.com/40187449): Remove this once macOS uses system-wide ids.
+  // On macOS the thread ids used by CrashPad are not the same as the ones
+  // provided by PlatformThread. Make sure to use the same for correct
+  // attribution.
+  uint64_t system_wide_thread_id_;
+#endif
+
   // Number of active HangWatchScopeEnables on this thread.
   int nesting_level_ = 0;
 
