@@ -5,6 +5,8 @@
 #include "base/trace_event/named_trigger.h"
 
 #include "base/check.h"
+#include "base/hash/hash.h"
+#include "base/strings/strcat.h"
 
 namespace base::trace_event {
 
@@ -24,4 +26,15 @@ void NamedTriggerManager::SetInstance(NamedTriggerManager* manager) {
   g_named_trigger_manager = manager;
 }
 
+uint64_t TriggerFlowId(const std::string_view& name,
+                       std::optional<int32_t> value) {
+  size_t name_hash = base::FastHash(name);
+  return base::HashInts(name_hash, static_cast<uint32_t>(value.value_or(0)));
+}
+
+perfetto::Flow TriggerFlow(const std::string_view& name,
+                           std::optional<int32_t> value) {
+  return perfetto::Flow::Global(TriggerFlowId(name, value));
+}
+
 }  // namespace base::trace_event
