@@ -11,6 +11,7 @@
 #include <string>
 
 #include "base/base_export.h"
+#include "base/trace_event/base_tracing.h"
 
 namespace base::trace_event {
 
@@ -33,6 +34,15 @@ class NamedTriggerManager {
   BASE_EXPORT static void SetInstance(NamedTriggerManager* manager);
 };
 
+// Returns a flow id that connects to a background tracing trigger.
+BASE_EXPORT uint64_t TriggerFlowId(const std::string_view& name,
+                                   std::optional<int32_t> value = std::nullopt);
+
+// Returns a perfetto flow that connects to a background tracing trigger.
+BASE_EXPORT perfetto::Flow TriggerFlow(
+    const std::string_view& name,
+    std::optional<int32_t> value = std::nullopt);
+
 }  // namespace base::trace_event
 
 #endif  // BASE_TRACE_EVENT_NAMED_TRIGGER_H_
