@@ -16,6 +16,7 @@
 #include <string>
 
 #include "base/base_export.h"
+#include "base/compiler_specific.h"
 #include "base/functional/callback.h"
 #include "base/memory/raw_ptr.h"
 #include "base/process/process_handle.h"
@@ -24,7 +25,6 @@
 #include "base/time/time.h"
 #include "base/trace_event/common/trace_event_common.h"
 #include "base/trace_event/trace_arguments.h"
-#include "base/trace_event/trace_event_memory_overhead.h"
 #include "build/build_config.h"
 
 namespace base {
@@ -42,12 +42,7 @@ typedef base::RepeatingCallback<bool(const std::string& metadata_name)>
     MetadataFilterPredicate;
 
 struct TraceEventHandle {
-  uint32_t chunk_seq;
-  // These numbers of bits must be kept consistent with
-  // TraceBufferChunk::kMaxTrunkIndex and
-  // TraceBufferChunk::kTraceBufferChunkSize (in trace_buffer.h).
-  unsigned chunk_index : 26;
-  unsigned event_index : 6;
+  uint64_t dummy;
 };
 
 class BASE_EXPORT TraceEvent {
@@ -65,7 +60,6 @@ class BASE_EXPORT TraceEvent {
              const char* name,
              const char* scope,
              unsigned long long id,
-             unsigned long long bind_id,
              TraceArguments* args,
              unsigned int flags);
 
@@ -95,14 +89,11 @@ class BASE_EXPORT TraceEvent {
              const char* name,
              const char* scope,
              unsigned long long id,
-             unsigned long long bind_id,
              TraceArguments* args,
              unsigned int flags);
 
   void UpdateDuration(const TimeTicks& now, const ThreadTicks& thread_now);
 
-  void EstimateTraceMemoryOverhead(TraceEventMemoryOverhead* overhead);
-
   // Serialize event data to JSON
   void AppendAsJSON(
       std::string* out,
@@ -119,10 +110,9 @@ class BASE_EXPORT TraceEvent {
   const char* scope() const { return scope_; }
   unsigned long long id() const { return id_; }
   unsigned int flags() const { return flags_; }
-  unsigned long long bind_id() const { return bind_id_; }
   // Exposed for unittesting:
 
-  const StringStorage& parameter_copy_storage() const {
+  const StringStorage& parameter_copy_storage() const LIFETIME_BOUND {
     return parameter_copy_storage_;
   }
 
@@ -172,7 +162,6 @@ class BASE_EXPORT TraceEvent {
     ProcessId process_id_;
   };
   unsigned int flags_ = 0;
-  unsigned long long bind_id_ = 0;
   char phase_ = TRACE_EVENT_PHASE_BEGIN;
 };
 
