@@ -455,6 +455,17 @@ struct Track {
   explicit Track(uint64_t id) {}
 };
 
+struct NamedTrack {
+  template <class T>
+  explicit NamedTrack(T name, uint64_t id = 0, Track parent = Track{0}) {}
+};
+
+struct Flow {
+  static inline Flow ProcessScoped(uint64_t flow_id) { return Flow(); }
+  static inline Flow FromPointer(void* ptr) { return Flow(); }
+  static inline Flow Global(uint64_t flow_id) { return Flow(); }
+};
+
 namespace protos::pbzero {
 namespace SequenceManagerTask {
 
