@@ -13,7 +13,7 @@
 #include "base/time/time.h"
 #include "base/types/optional_ref.h"
 #include "cc/cc_export.h"
-#include "cc/input/browser_controls_offset_tags_info.h"
+#include "cc/input/browser_controls_offset_tag_modifications.h"
 #include "cc/input/browser_controls_state.h"
 #include "cc/input/compositor_input_interfaces.h"
 #include "cc/input/event_listener_properties.h"
@@ -57,7 +57,9 @@ enum class ScrollBeginThreadState {
   kScrollingOnCompositor = 0,
   kScrollingOnCompositorBlockedOnMain = 1,
   kScrollingOnMain = 2,
-  kMaxValue = kScrollingOnMain,
+  kRasterInducingScroll = 3,
+  kRasterInducingScrollBlockedOnMain = 4,
+  kMaxValue = kRasterInducingScrollBlockedOnMain,
 };
 
 struct CC_EXPORT InputHandlerPointerResult {
@@ -137,6 +139,11 @@ class CC_EXPORT InputHandlerClient {
     // `kUseScrollPredictorForEmptyQueue`. After which we will resume frame
     // production and enqueuing input.
     kUseScrollPredictorForDeadline,
+
+    // Will perform as `kDispatchScrollEventsImmediately` until the deadline.
+    // However no input arriving after the deadline will dispatch. Event if
+    // frame production has yet to complete.
+    kDispatchScrollEventsUntilDeadline,
   };
 
   InputHandlerClient(const InputHandlerClient&) = delete;
@@ -160,7 +167,8 @@ class CC_EXPORT InputHandlerClient {
   virtual void DeliverInputForDeadline() = 0;
   virtual void DidFinishImplFrame() = 0;
   virtual bool HasQueuedInput() const = 0;
-  virtual void SetScrollEventDispatchMode(ScrollEventDispatchMode mode) = 0;
+  virtual void SetScrollEventDispatchMode(ScrollEventDispatchMode mode,
+                                          double scroll_deadline_ratio) = 0;
 
  protected:
   InputHandlerClient() = default;
@@ -264,6 +272,11 @@ class CC_EXPORT InputHandler : public InputDelegateForCompositor {
     // a parameter to ThreadInputHandler to specify whether unused delta is
     // consumed by the viewport or bubbles to the parent.
     bool viewport_cannot_scroll = false;
+
+    // This bool indicates if this scroll operation is expected to require
+    // raster work to be done on worker threads before the scroll tree
+    // can be activated.
+    bool raster_inducing = false;
   };
 
   // ViewportScrollResult records, for a scroll gesture affecting a page's
@@ -289,6 +302,17 @@ class CC_EXPORT InputHandler : public InputDelegateForCompositor {
     kHandlerOnScrollingLayer
   };
 
+  // This struct contains the information about a snap animation executed on the
+  // impl thread.
+  // TODO(crbug.com/374801328): Put other snap-animation-related info into this
+  // struct, i.e. updated_snapped_elements_ so InputHandler keeps only one map.
+  struct SnapAnimationData {
+    // The ids of the elements to which the element associated with this state
+    // is snapping to. This is set at the end of a scroll when a snap animation
+    // is kicked off and cleared when that animation ends.
+    TargetSnapAreaElementIds animating_snap_target_ids_;
+  };
+
   virtual base::WeakPtr<InputHandler> AsWeakPtr();
 
   // Binds a client to this handler to receive notifications. Only one client
@@ -461,7 +485,8 @@ class CC_EXPORT InputHandler : public InputDelegateForCompositor {
       BrowserControlsState constraints,
       BrowserControlsState current,
       bool animate,
-      base::optional_ref<const BrowserControlsOffsetTagsInfo> offset_tags_info);
+      base::optional_ref<const BrowserControlsOffsetTagModifications>
+          offset_tag_modifications);
 
   virtual void SetIsHandlingTouchSequence(bool is_handling_touch_sequence);
 
@@ -512,7 +537,15 @@ class CC_EXPORT InputHandler : public InputDelegateForCompositor {
     return accumulated_root_overscroll_;
   }
 
-  bool animating_for_snap_for_testing() const { return IsAnimatingForSnap(); }
+  bool animating_for_snap_for_testing(
+      ElementId element_id = ElementId()) const {
+    return IsAnimatingForSnap(element_id);
+  }
+
+  base::flat_map<ElementId, SnapAnimationData>&
+  get_snap_animation_data_map_for_testing() {
+    return snap_animation_data_map_;
+  }
 
   const std::unique_ptr<SnapSelectionStrategy>& snap_strategy_for_testing()
       const {
@@ -542,7 +575,7 @@ class CC_EXPORT InputHandler : public InputDelegateForCompositor {
                             ScrollbarOrientation orientation) override;
   void DidUnregisterScrollbar(ElementId scroll_element_id,
                               ScrollbarOrientation orientation) override;
-  void ScrollOffsetAnimationFinished() override;
+  void ScrollOffsetAnimationFinished(ElementId element_id) override;
   void SetPrefersReducedMotion(bool prefers_reduced_motion) override;
   bool IsCurrentlyScrolling() const override;
   ActivelyScrollingType GetActivelyScrollingType() const override;
@@ -563,7 +596,7 @@ class CC_EXPORT InputHandler : public InputDelegateForCompositor {
   // visual and layout offsets of the viewport.
   gfx::PointF GetVisualScrollOffset(const ScrollNode& scroll_node) const;
   bool IsScrolledBy(LayerImpl* child, ScrollNode* ancestor);
-  bool IsAnimatingForSnap() const;
+  bool IsAnimatingForSnap(ElementId element_id) const;
 
   ScrollNode* CurrentlyScrollingNode();
   const ScrollNode* CurrentlyScrollingNode() const;
@@ -709,6 +742,34 @@ class CC_EXPORT InputHandler : public InputDelegateForCompositor {
       const gfx::PointF& current_offset,
       SnapReason snap_reason) const;
 
+  // This returns the ScrollNode associated with the CurrentlyScrollingNode()
+  // that is currently animating, if one exists.
+  // It is usually the same ScrollNode as the CurrentlyScrollingNode(), except
+  // when the inner viewport node is animating, in which case the
+  // CurrentlyScrollingNode() is still the outer viewport node.
+  ScrollNode* GetAnimatingNodeForCurrentScrollingNode();
+  // These get and set the ElementIds of the elements to which |element_id| is
+  // snapping while the snap animation is running.
+  TargetSnapAreaElementIds GetAnimatingSnapTargetsForElement(
+      ElementId element_id) const;
+  void SetAnimatingSnapTargetsForElement(
+      ElementId element_id,
+      TargetSnapAreaElementIds target_ids = TargetSnapAreaElementIds());
+  void ClearAnimatingSnapTargetsForElement(ElementId element_id);
+
+  void EnsureSnapAnimationData(ElementId element_id);
+
+  // Add |element_id| to the set of scroll containers for which an impl scroll
+  // has ended between the last commit and the next one. The main thread will
+  // enqueue scrollend events for these elements.
+  void InsertPendingScrollendContainer(const ElementId& element_id);
+
+  // Stop scrolling for |scroll_node| or |CurrentlyScrollingNode()|. If
+  // |scroll_node| is not null, we assume it is the ScrollNode for which the
+  // scroll has ended. Otherwise, we assume the scroll has ended for
+  // |CurrentlyScrollingNode()|.
+  void ScrollEnd(ScrollNode* scroll_node, bool should_snap = false);
+
   // The input handler is owned by the delegate so their lifetimes are tied
   // together.
   const raw_ref<CompositorDelegateForInput> compositor_delegate_;
@@ -743,6 +804,8 @@ class CC_EXPORT InputHandler : public InputDelegateForCompositor {
   // element id(s) of the target(s). Otherwise, the ids will be invalid.
   // At the end of a scroll animation, the target should be set as the scroll
   // node's snap target.
+  // TODO(crbug.com/372627916): Delete when cleaning up
+  // MultipleImplOnlyScrollAnimations flag.
   TargetSnapAreaElementIds scroll_animating_snap_target_ids_;
 
   enum SnapFlingState {
@@ -760,6 +823,14 @@ class CC_EXPORT InputHandler : public InputDelegateForCompositor {
   // the main thread in the next begin main frame.
   base::flat_map<ElementId, TargetSnapAreaElementIds> updated_snapped_elements_;
 
+  // This maps each element being scrolled to information about its snap
+  // target(s). When a container is scrolled, an entry is created when a snap
+  // animation is kicked off and erase when that snap animation ends.
+  // If |updated_snapped_elements_| is moved into ImplSnapState, the entries
+  // should live beyond the snap animation, i.e. indefinitely, like
+  // |updated_snapped_elements_| currently does.
+  base::flat_map<ElementId, SnapAnimationData> snap_animation_data_map_;
+
   ElementId scroll_element_id_mouse_currently_over_;
   ElementId scroll_element_id_mouse_currently_captured_;
 
@@ -836,6 +907,10 @@ class CC_EXPORT InputHandler : public InputDelegateForCompositor {
   // is being animated to.
   std::unique_ptr<SnapSelectionStrategy> snap_strategy_;
 
+  // The set of scroll containers for which an impl scroll ended between the
+  // last commit and the next one.
+  base::flat_set<ElementId> pending_scrollend_containers_;
+
   // Must be the last member to ensure this is destroyed first in the
   // destruction order and invalidates all weak pointers.
   base::WeakPtrFactory<InputHandler> weak_factory_{this};
