@@ -487,7 +487,7 @@ void ScrollbarController::DidUnregisterScrollbar(
       captured_scrollbar_metadata_->scroll_element_id == element_id &&
       captured_scrollbar_metadata_->orientation == orientation &&
       autoscroll_state_->status == AutoScrollStatus::kAutoscrollScrolling) {
-    layer_tree_host_impl_->mutator_host()->ScrollAnimationAbort();
+    layer_tree_host_impl_->mutator_host()->ScrollAnimationAbort(element_id);
     autoscroll_state_->status = AutoScrollStatus::kAutoscrollReady;
   }
 }
@@ -531,7 +531,8 @@ void ScrollbarController::RecomputeAutoscrollStateIfNeeded() {
       (autoscroll_state_->direction ==
            AutoScrollDirection::kAutoscrollBackward &&
        thumb_start < pointer_position)) {
-    layer_tree_host_impl_->mutator_host()->ScrollAnimationAbort();
+    layer_tree_host_impl_->mutator_host()->ScrollAnimationAbort(
+        captured_scrollbar_metadata_->scroll_element_id);
   }
 
   // When the scroller is autoscrolling forward, its dimensions need to be
@@ -543,7 +544,8 @@ void ScrollbarController::RecomputeAutoscrollStateIfNeeded() {
   if (autoscroll_state_->direction == AutoScrollDirection::kAutoscrollForward) {
     const float scroll_layer_length = scrollbar->scroll_layer_length();
     if (autoscroll_state_->scroll_layer_length != scroll_layer_length) {
-      layer_tree_host_impl_->mutator_host()->ScrollAnimationAbort();
+      layer_tree_host_impl_->mutator_host()->ScrollAnimationAbort(
+          scrollbar->scroll_element_id());
       StartAutoScrollAnimation();
     }
   }
@@ -555,7 +557,8 @@ void ScrollbarController::RecomputeAutoscrollStateIfNeeded() {
       GetRectForScrollbarPart(autoscroll_state_->pressed_scrollbar_part));
   if (!scrollbar_part_rect.Contains(scroller_relative_position)) {
     // Stop animating if pointer moves outside the rect bounds.
-    layer_tree_host_impl_->mutator_host()->ScrollAnimationAbort();
+    layer_tree_host_impl_->mutator_host()->ScrollAnimationAbort(
+        scrollbar->scroll_element_id());
   } else if (scrollbar_part_rect.Contains(scroller_relative_position) &&
              !layer_tree_host_impl_->mutator_host()->IsElementAnimating(
                  scrollbar->scroll_element_id())) {
@@ -626,7 +629,8 @@ void ScrollbarController::StartAutoScrollAnimation() {
                                      ? AutoScrollDirection::kAutoscrollBackward
                                      : AutoScrollDirection::kAutoscrollForward;
 
-  layer_tree_host_impl_->mutator_host()->ScrollAnimationAbort();
+  layer_tree_host_impl_->mutator_host()->ScrollAnimationAbort(
+      scroll_node->element_id);
   layer_tree_host_impl_->AutoScrollAnimationCreate(
       *scroll_node, target_offset_2d, std::abs(autoscroll_state_->velocity));
 }
@@ -645,7 +649,8 @@ InputHandlerPointerResult ScrollbarController::HandlePointerUp(
   // Only abort the animation if it is an "autoscroll" animation.
   if (autoscroll_state_.has_value() &&
       autoscroll_state_->status == AutoScrollStatus::kAutoscrollScrolling) {
-    layer_tree_host_impl_->mutator_host()->ScrollAnimationAbort();
+    layer_tree_host_impl_->mutator_host()->ScrollAnimationAbort(
+        captured_scrollbar_metadata_->scroll_element_id);
   }
 
   ResetState();
@@ -689,31 +694,6 @@ float ScrollbarController::GetViewportLength() const {
   return length / GetPageScaleFactorForScroll();
 }
 
-float ScrollbarController::GetScrollDistanceForPercentBasedScroll() const {
-  const ScrollbarLayerImplBase* scrollbar = ScrollbarLayer();
-
-  const ScrollNode* scroll_node =
-      layer_tree_host_impl_->active_tree()
-          ->property_trees()
-          ->scroll_tree()
-          .FindNodeFromElementId(scrollbar->scroll_element_id());
-  DCHECK(scroll_node);
-
-  const gfx::Vector2dF scroll_delta =
-      scrollbar->orientation() == ScrollbarOrientation::kVertical
-          ? gfx::Vector2dF(0, kPercentDeltaForDirectionalScroll)
-          : gfx::Vector2dF(kPercentDeltaForDirectionalScroll, 0);
-
-  const gfx::Vector2dF pixel_delta =
-      layer_tree_host_impl_->GetInputHandler().ResolveScrollGranularityToPixels(
-          *scroll_node, scroll_delta,
-          ui::ScrollGranularity::kScrollByPercentage);
-
-  return scrollbar->orientation() == ScrollbarOrientation::kVertical
-             ? pixel_delta.y()
-             : pixel_delta.x();
-}
-
 float ScrollbarController::GetPageScaleFactorForScroll() const {
   return layer_tree_host_impl_->active_tree()->page_scale_factor_for_scroll();
 }
@@ -726,11 +706,7 @@ float ScrollbarController::GetScrollDistanceForScrollbarPart(
   switch (scrollbar_part) {
     case ScrollbarPart::kBackButton:
     case ScrollbarPart::kForwardButton:
-      if (layer_tree_host_impl_->settings().percent_based_scrolling) {
-        scroll_delta = GetScrollDistanceForPercentBasedScroll();
-      } else {
-        scroll_delta = kPixelsPerLineStep * ScreenSpaceScaleFactor();
-      }
+      scroll_delta = kPixelsPerLineStep * ScreenSpaceScaleFactor();
       break;
     case ScrollbarPart::kBackTrack:
     case ScrollbarPart::kForwardTrack: {
