@@ -1,4 +1,4 @@
-// Copyright 2012 The Chromium Authors. All rights reserved.
+// Copyright 2012 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -7,6 +7,7 @@
 #include <memory>
 
 #include "cc/layers/solid_color_layer_impl.h"
+#include "third_party/skia/include/core/SkPictureRecorder.h"
 
 namespace cc {
 
@@ -23,9 +24,25 @@ SolidColorLayer::SolidColorLayer() = default;
 
 SolidColorLayer::~SolidColorLayer() = default;
 
-void SolidColorLayer::SetBackgroundColor(SkColor color) {
-  SetContentsOpaque(SkColorGetA(color) == 255);
+void SolidColorLayer::SetBackgroundColor(SkColor4f color) {
+  SetContentsOpaque(color.isOpaque());
   Layer::SetBackgroundColor(color);
+  UpdateDrawsContent();
+}
+
+sk_sp<const SkPicture> SolidColorLayer::GetPicture() const {
+  if (!draws_content() || bounds().IsEmpty()) {
+    return nullptr;
+  }
+
+  SkPictureRecorder recorder;
+  recorder.beginRecording(bounds().width(), bounds().height())
+      ->drawColor(background_color());
+  return recorder.finishRecordingAsPicture();
+}
+
+bool SolidColorLayer::IsSolidColorLayerForTesting() const {
+  return true;
 }
 
 }  // namespace cc
