@@ -55,9 +55,10 @@ Viewport::ScrollResult Viewport::ScrollBy(const gfx::Vector2dF& physical_delta,
   gfx::Vector2dF pending_scroll_node_delta = scroll_node_delta;
 
   // Attempt to scroll inner viewport first.
-  pending_scroll_node_delta -= host_impl_->GetInputHandler().ScrollSingleNode(
+  gfx::Vector2dF inner_delta = host_impl_->GetInputHandler().ScrollSingleNode(
       *InnerScrollNode(), pending_scroll_node_delta, viewport_point,
       is_direct_manipulation);
+  pending_scroll_node_delta -= inner_delta;
 
   // Now attempt to scroll the outer viewport.
   gfx::Vector2dF outer_delta;
@@ -70,6 +71,7 @@ Viewport::ScrollResult Viewport::ScrollBy(const gfx::Vector2dF& physical_delta,
 
   ScrollResult result;
   result.outer_viewport_scrolled_delta = outer_delta;
+  result.inner_viewport_scrolled_delta = inner_delta;
   result.consumed_delta =
       physical_delta - AdjustOverscroll(pending_scroll_node_delta);
   result.content_scrolled_delta = scroll_node_delta - pending_scroll_node_delta;
@@ -229,6 +231,7 @@ Viewport::ScrollResult Viewport::ScrollAnimated(const gfx::Vector2dF& delta,
   pending_delta.Scale(scale_factor);
   result.consumed_delta = delta - pending_delta;
   result.outer_viewport_scrolled_delta = outer_delta;
+  result.inner_viewport_scrolled_delta = inner_delta;
   return result;
 }
 
