@@ -147,8 +147,7 @@ class ImageTransferCacheEntryTest
                       CreateSolidPlane(gr_context(), 32, 32, GL_RG8_EXT,
                                        SkColors::kWhite, &release_flags[1])};
     } else {
-      NOTREACHED_IN_MIGRATION();
-      return {};
+      NOTREACHED();
     }
     if (!base::Contains(plane_images, nullptr)) {
       return plane_images;
@@ -248,20 +247,19 @@ TEST_P(ImageTransferCacheEntryTest, MAYBE_Deserialize) {
   ASSERT_TRUE(yuva_pixmaps.plane(0).erase(SkColors::kBlack, &top_color_rect));
 
   auto client_entry(std::make_unique<ClientImageTransferCacheEntry>(
-      ClientImageTransferCacheEntry::Image(yuva_pixmaps.planes().data(),
-                                           yuva_info,
+      ClientImageTransferCacheEntry::Image(yuva_pixmaps.planes(), yuva_info,
                                            nullptr /* decoded color space*/),
       true /* needs_mips */, std::nullopt));
   uint32_t size = client_entry->SerializedSize();
   auto data = PaintOpWriter::AllocateAlignedBuffer<uint8_t>(size);
   ASSERT_TRUE(client_entry->Serialize(
-      base::make_span(static_cast<uint8_t*>(data.get()), size)));
+      base::span(static_cast<uint8_t*>(data.get()), size)));
 
   // Create service-side entry from the client-side serialize info
   auto entry(std::make_unique<ServiceImageTransferCacheEntry>());
-  ASSERT_TRUE(entry->Deserialize(
-      gr_context(), /*graphite_recorder=*/nullptr,
-      base::make_span(static_cast<uint8_t*>(data.get()), size)));
+  ASSERT_TRUE(
+      entry->Deserialize(gr_context(), /*graphite_recorder=*/nullptr,
+                         base::span(static_cast<uint8_t*>(data.get()), size)));
   ASSERT_TRUE(entry->is_yuv());
 
   // Check color of pixels
@@ -381,8 +379,7 @@ std::string TestParamToString(
     case SkYUVAInfo::PlaneConfig::kY_UV:
       return "Y_UV";
     default:
-      NOTREACHED_IN_MIGRATION();
-      return "";
+      NOTREACHED();
   }
 }
 
@@ -406,12 +403,12 @@ TEST(ImageTransferCacheEntryTestNoYUV, CPUImageWithMips) {
       std::nullopt);
   const uint32_t storage_size = client_entry.SerializedSize();
   auto storage = PaintOpWriter::AllocateAlignedBuffer<uint8_t>(storage_size);
-  client_entry.Serialize(base::make_span(storage.get(), storage_size));
+  client_entry.Serialize(base::span(storage.get(), storage_size));
 
   ServiceImageTransferCacheEntry service_entry;
   service_entry.Deserialize(gr_context.get(),
                             /*graphite_recorder=*/nullptr,
-                            base::make_span(storage.get(), storage_size));
+                            base::span(storage.get(), storage_size));
   ASSERT_TRUE(service_entry.image());
   auto pre_mip_image = service_entry.image();
   EXPECT_FALSE(pre_mip_image->isTextureBacked());
@@ -436,12 +433,12 @@ TEST(ImageTransferCacheEntryTestNoYUV, CPUImageAddMipsLater) {
       std::nullopt);
   const uint32_t storage_size = client_entry.SerializedSize();
   auto storage = PaintOpWriter::AllocateAlignedBuffer<uint8_t>(storage_size);
-  client_entry.Serialize(base::make_span(storage.get(), storage_size));
+  client_entry.Serialize(base::span(storage.get(), storage_size));
 
   ServiceImageTransferCacheEntry service_entry;
   service_entry.Deserialize(gr_context.get(),
                             /*graphite_recorder=*/nullptr,
-                            base::make_span(storage.get(), storage_size));
+                            base::span(storage.get(), storage_size));
   ASSERT_TRUE(service_entry.image());
   auto pre_mip_image = service_entry.image();
   EXPECT_FALSE(pre_mip_image->isTextureBacked());
@@ -454,124 +451,7 @@ TEST(ImageTransferCacheEntryTestNoYUV, CPUImageAddMipsLater) {
   EXPECT_EQ(pre_mip_image, service_entry.image());
 }
 
-TEST(ImageTransferCacheEntryTestHDR, Gainmap) {
-  // Using an invalid context within the narrow scope of serializing and
-  // deserializing will test the path using software rendering.
-  GrDirectContext* gr_context = nullptr;
 
-  // Initialize the SDR image pixels.
-  constexpr int kSdrWidth = 2;
-  constexpr int kSdrHeight = 4;
-  SkBitmap sdr_bitmap;
-  {
-    constexpr float k10 = 1.0f;
-    constexpr float k05 = 0.735357f;
-    SkColor4f pixels[kSdrHeight][kSdrWidth] = {
-        {{k10, k10, k10, k10}, {k10, k10, k05, k10}},
-        {{k10, k05, k10, k10}, {k10, k05, k05, k10}},
-        {{k05, k10, k10, k10}, {k05, k10, k05, k10}},
-        {{k05, k05, k10, k10}, {k05, k05, k05, k10}},
-    };
-    SkPixmap pixmap(
-        SkImageInfo::Make(kSdrWidth, kSdrHeight, kRGBA_F32_SkColorType,
-                          kPremul_SkAlphaType),
-        pixels, kSdrWidth * sizeof(SkColor4f));
-
-    SkImageInfo info = SkImageInfo::Make(
-        kSdrWidth, kSdrHeight, kRGBA_8888_SkColorType, kPremul_SkAlphaType);
-    sdr_bitmap.allocPixels(info, info.minRowBytes());
-    EXPECT_TRUE(pixmap.readPixels(sdr_bitmap.pixmap(), 0, 0));
-  }
-
-  // Initialize the gainmap pixels.
-  constexpr int kGainmapWidth = 1;
-  constexpr int kGainmapHeight = 4;
-  SkBitmap gainmap_bitmap;
-  {
-    constexpr float k10 = 1.0f;
-    constexpr float k00 = 0.0f;
-    SkColor4f pixels[kGainmapHeight][kGainmapWidth] = {
-        {{k10, k00, k00, 1.f}},
-        {{k10, k00, k00, 1.f}},
-        {{k00, k10, k10, 1.f}},
-        {{k00, k10, k10, 1.f}},
-    };
-    SkPixmap pixmap(
-        SkImageInfo::Make(kGainmapWidth, kGainmapHeight, kRGBA_F32_SkColorType,
-                          kPremul_SkAlphaType),
-        pixels, kGainmapWidth * sizeof(SkColor4f));
-
-    SkImageInfo info =
-        SkImageInfo::Make(kGainmapWidth, kGainmapHeight, kRGBA_8888_SkColorType,
-                          kPremul_SkAlphaType);
-    gainmap_bitmap.allocPixels(info, info.minRowBytes());
-    EXPECT_TRUE(pixmap.readPixels(gainmap_bitmap.pixmap(), 0, 0));
-  }
-
-  // Initialize the gainmap rendering parameters.
-  SkGainmapInfo gainmap_info;
-  {
-    constexpr float kHdrRatioMax = 2.f;
-    gainmap_info.fDisplayRatioSdr = 1.f;
-    gainmap_info.fDisplayRatioHdr = kHdrRatioMax;
-    gainmap_info.fEpsilonSdr = {0.f, 0.f, 0.f, 1.f};
-    gainmap_info.fEpsilonHdr = {0.f, 0.f, 0.f, 1.f};
-    gainmap_info.fGainmapRatioMin = {1.f, 1.f, 1.f, 1.f};
-    gainmap_info.fGainmapRatioMax = {kHdrRatioMax, kHdrRatioMax, kHdrRatioMax,
-                                     1.f};
-  }
-
-  // Read the resulting image back into a bitmap.
-  SkBitmap result;
-  {
-    ClientImageTransferCacheEntry client_entry(
-        ClientImageTransferCacheEntry::Image(&sdr_bitmap.pixmap()),
-        ClientImageTransferCacheEntry::Image(&gainmap_bitmap.pixmap()),
-        gainmap_info, false);
-
-    std::vector<uint8_t> storage(client_entry.SerializedSize());
-    client_entry.Serialize(storage);
-
-    ServiceImageTransferCacheEntry service_entry;
-    service_entry.Deserialize(gr_context, /*graphite_recorder=*/nullptr,
-                              storage);
-    ASSERT_TRUE(service_entry.image());
-    ASSERT_TRUE(service_entry.NeedsToneMapApplied());
-    auto image = service_entry.GetImageWithToneMapApplied(2.f, false);
-
-    SkImageInfo info =
-        SkImageInfo::Make(kSdrWidth, kSdrHeight, kRGBA_F32_SkColorType,
-                          kPremul_SkAlphaType, SkColorSpace::MakeSRGBLinear());
-    result.allocPixels(info, info.minRowBytes());
-    EXPECT_TRUE(image->readPixels(gr_context, result.pixmap(), 0, 0));
-  }
-
-  // Ensure that it matches the expected result.
-  {
-    constexpr float k20 = 2.0f;
-    constexpr float k10 = 1.0f;
-    constexpr float k05 = 0.5f;
-    SkColor4f pixels[4][2] = {
-        {{k20, k10, k10, 1.f}, {k20, k10, k05, 1.f}},
-        {{k20, k05, k10, 1.f}, {k20, k05, k05, 1.f}},
-        {{k05, k20, k20, 1.f}, {k05, k20, k10, 1.f}},
-        {{k05, k10, k20, 1.f}, {k05, k10, k10, 1.f}},
-    };
-    auto approx_equal = [](const SkColor4f& a, const SkColor4f& b) {
-      constexpr float kEpsilon = 1 / 64.f;
-      return std::abs(a.fR - b.fR) < kEpsilon &&
-             std::abs(a.fG - b.fG) < kEpsilon &&
-             std::abs(a.fB - b.fB) < kEpsilon &&
-             std::abs(a.fA - b.fA) < kEpsilon;
-    };
-    for (int y = 0; y < 4; ++y) {
-      for (int x = 0; x < 2; ++x) {
-        auto color = result.getColor4f(x, y);
-        EXPECT_TRUE(approx_equal(color, pixels[y][x]));
-      }
-    }
-  }
-}
 
 }  // namespace
 }  // namespace cc
