@@ -7,6 +7,9 @@
 #include <stddef.h>
 
 #include <algorithm>
+#include <array>
+#include <map>
+#include <unordered_set>
 #include <utility>
 #include <vector>
 
@@ -16,7 +19,6 @@
 #include "base/logging.h"
 #include "base/memory/raw_ptr.h"
 #include "base/notreached.h"
-#include "base/ranges/algorithm.h"
 #include "build/build_config.h"
 #include "cc/base/features.h"
 #include "cc/base/math_util.h"
@@ -24,6 +26,7 @@
 #include "cc/layers/layer.h"
 #include "cc/layers/layer_impl.h"
 #include "cc/layers/picture_layer.h"
+#include "cc/layers/view_transition_content_layer_impl.h"
 #include "cc/paint/filter_operation.h"
 #include "cc/trees/clip_node.h"
 #include "cc/trees/effect_node.h"
@@ -352,41 +355,21 @@ bool HasSingularTransform(int transform_tree_index, const TransformTree& tree) {
 
 int LowestCommonAncestor(int clip_id_1,
                          int clip_id_2,
-                         const ClipTree* clip_tree) {
-  const ClipNode* clip_node_1 = clip_tree->Node(clip_id_1);
-  const ClipNode* clip_node_2 = clip_tree->Node(clip_id_2);
+                         const ClipTree& clip_tree) {
+  const ClipNode* clip_node_1 = clip_tree.Node(clip_id_1);
+  const ClipNode* clip_node_2 = clip_tree.Node(clip_id_2);
   while (clip_node_1->id != clip_node_2->id) {
-    if (clip_node_1->id < clip_node_2->id)
-      clip_node_2 = clip_tree->parent(clip_node_2);
-    else
-      clip_node_1 = clip_tree->parent(clip_node_1);
+    if (clip_node_1->id < clip_node_2->id) {
+      clip_node_2 = clip_tree.parent(clip_node_2);
+    } else {
+      clip_node_1 = clip_tree.parent(clip_node_1);
+    }
   }
   return clip_node_1->id;
 }
 
-void SetHasContributingLayerThatEscapesClip(int lca_clip_id,
-                                            int target_effect_id,
-                                            EffectTree* effect_tree) {
-  DCHECK(!base::FeatureList::IsEnabled(
-      features::kRenderSurfaceCommonAncestorClip));
-  const EffectNode* effect_node = effect_tree->Node(target_effect_id);
-  // Find all ancestor targets starting from effect_node who are clipped by
-  // a descendant of lowest ancestor clip and set their
-  // has_contributing_layer_that_escapes_clip to true.
-  while (effect_node->clip_id > lca_clip_id) {
-    RenderSurfaceImpl* render_surface =
-        effect_tree->GetRenderSurface(effect_node->id);
-    DCHECK(render_surface);
-    render_surface->set_has_contributing_layer_that_escapes_clip(true);
-    effect_node = effect_tree->Node(effect_node->target_id);
-  }
-}
-
 void UpdateRenderSurfaceCommonAncestorClip(LayerImpl* layer,
-                                           const ClipTree* clip_tree,
-                                           EffectTree* effect_tree) {
-  DCHECK(
-      base::FeatureList::IsEnabled(features::kRenderSurfaceCommonAncestorClip));
+                                           const ClipTree& clip_tree) {
   RenderSurfaceImpl* render_surface = layer->render_target();
   CHECK(render_surface);
   int clip_id = layer->clip_tree_index();
@@ -406,8 +389,6 @@ void UpdateRenderSurfaceCommonAncestorClip(LayerImpl* layer,
 }
 
 void ClearRenderSurfaceCommonAncestorClip(LayerImpl* layer) {
-  DCHECK(
-      base::FeatureList::IsEnabled(features::kRenderSurfaceCommonAncestorClip));
   RenderSurfaceImpl* render_surface = layer->render_target();
   CHECK(render_surface);
   while (render_surface->has_contributing_layer_that_escapes_clip()) {
@@ -571,8 +552,7 @@ void SetSurfaceIsClipped(const ClipTree& clip_tree,
   if (render_surface->EffectTreeIndex() == kContentsRootPropertyNodeId) {
     // Root render surface is always clipped.
     is_clipped = true;
-  } else if (base::FeatureList::IsEnabled(
-                 features::kRenderSurfaceCommonAncestorClip)) {
+  } else {
     int parent_target_clip_id =
         render_surface->render_target()->common_ancestor_clip_id();
     for (const ClipNode* clip_node =
@@ -584,22 +564,6 @@ void SetSurfaceIsClipped(const ClipTree& clip_tree,
         break;
       }
     }
-  } else if (render_surface->has_contributing_layer_that_escapes_clip()) {
-    CHECK_EQ(render_surface->common_ancestor_clip_id(),
-             render_surface->ClipTreeIndex());
-    // We cannot clip a surface that has a contribuitng layer which escapes the
-    // clip.
-    is_clipped = false;
-  } else if (render_surface->ClipTreeIndex() ==
-             render_surface->render_target()->ClipTreeIndex()) {
-    // There is no clip between the render surface and its target, so
-    // the surface need not be clipped.
-    is_clipped = false;
-  } else {
-    // If the clips between the render surface and its target only expand the
-    // clips and do not apply any new clip, we need not clip the render surface.
-    const ClipNode* clip_node = clip_tree.Node(render_surface->ClipTreeIndex());
-    is_clipped = clip_node->AppliesLocalClip();
   }
   render_surface->SetIsClipped(is_clipped);
 }
@@ -646,8 +610,7 @@ gfx::Transform ScreenSpaceTransformInternal(LayerType* layer,
   return xform;
 }
 
-void SetSurfaceClipRect(const ClipNode* parent_clip_node,
-                        PropertyTrees* property_trees,
+void SetSurfaceClipRect(PropertyTrees* property_trees,
                         RenderSurfaceImpl* render_surface) {
   if (!render_surface->is_clipped()) {
     render_surface->SetClipRect(gfx::Rect());
@@ -664,9 +627,6 @@ void SetSurfaceClipRect(const ClipNode* parent_clip_node,
     render_surface->SetClipRect(
         ToEnclosingClipRect(clip_tree.Node(effect_node->clip_id)->clip));
   } else {
-    DCHECK(base::FeatureList::IsEnabled(
-               features::kRenderSurfaceCommonAncestorClip) ||
-           render_surface->common_ancestor_clip_id() == effect_node->clip_id);
     ConditionalClip accumulated_clip_rect = ComputeAccumulatedClip(
         property_trees, include_expanding_clips,
         render_surface->common_ancestor_clip_id(), target_node->id);
@@ -815,26 +775,32 @@ std::pair<gfx::MaskFilterInfo, bool> GetMaskFilterInfoPair(
   if (!property_trees->GetToTarget(node->transform_id, target_id, &to_target))
     return kEmptyMaskFilterInfoPair;
 
-  auto mfi = node->mask_filter_info;
-  mfi.ApplyTransform(to_target);
+  auto result =
+      std::make_pair(node->mask_filter_info, node->is_fast_rounded_corner);
+  result.first.ApplyTransform(to_target);
 
-  auto rrect_f = gfx::RRectF::ToEnclosingRRectF(mfi.rounded_corner_bounds());
-  auto result = std::make_pair(
-      gfx::MaskFilterInfo(rrect_f,
-                          mfi.gradient_mask().value_or(gfx::LinearGradient())),
-      node->is_fast_rounded_corner);
   if (result.first.IsEmpty()) {
     return kEmptyMaskFilterInfoPair;
   }
   return result;
 }
 
-void UpdateRenderTarget(EffectTree* effect_tree) {
+void UpdateRenderTarget(LayerTreeImpl* layer_tree_impl,
+                        EffectTree* effect_tree) {
   int last_backdrop_filter = kInvalidNodeId;
+  base::flat_map<viz::ViewTransitionElementResourceId, int> resource_to_node;
 
   for (int i = kContentsRootPropertyNodeId;
        i < static_cast<int>(effect_tree->size()); ++i) {
     EffectNode* node = effect_tree->Node(i);
+
+    if (node->view_transition_element_resource_id.IsValid()) {
+      CHECK(!resource_to_node.contains(
+          node->view_transition_element_resource_id));
+      resource_to_node[node->view_transition_element_resource_id] = i;
+    }
+    node->view_transition_target_id = kInvalidPropertyNodeId;
+
     if (i == kContentsRootPropertyNodeId) {
       // Render target of the node corresponding to root is itself.
       node->target_id = kContentsRootPropertyNodeId;
@@ -849,6 +815,28 @@ void UpdateRenderTarget(EffectTree* effect_tree) {
     node->affected_by_backdrop_filter = false;
   }
 
+  if (!resource_to_node.empty()) {
+    for (auto* layer : *layer_tree_impl) {
+      auto resource_id = layer->ViewTransitionResourceId();
+      if (!resource_id.IsValid()) {
+        continue;
+      }
+
+      auto it = resource_to_node.find(resource_id);
+      if (it == resource_to_node.end()) {
+        continue;
+      }
+
+      auto* resource_node = effect_tree->Node(it->second);
+      auto* layer_node = effect_tree->Node(layer->effect_tree_index());
+      if (layer_node->HasRenderSurface()) {
+        resource_node->view_transition_target_id = layer_node->id;
+      } else {
+        resource_node->view_transition_target_id = layer_node->target_id;
+      }
+    }
+  }
+
   if (last_backdrop_filter == kInvalidNodeId)
     return;
 
@@ -916,9 +904,7 @@ void ComputeSurfaceDrawProperties(PropertyTrees* property_trees,
           render_surface->TransformTreeIndex(),
           render_surface->EffectTreeIndex()));
 
-  const ClipNode* clip_node =
-      property_trees->clip_tree().Node(render_surface->ClipTreeIndex());
-  SetSurfaceClipRect(clip_node, property_trees, render_surface);
+  SetSurfaceClipRect(property_trees, render_surface);
 }
 
 void AddSurfaceToRenderSurfaceList(RenderSurfaceImpl* render_surface,
@@ -929,6 +915,29 @@ void AddSurfaceToRenderSurfaceList(RenderSurfaceImpl* render_surface,
   RenderSurfaceImpl* target = render_surface->render_target();
   bool is_root =
       render_surface->EffectTreeIndex() == kContentsRootPropertyNodeId;
+
+  // If this node is producing a snapshot for a ViewTransition then the target
+  // surface (where its surface will be drawn) corresponds to the node where the
+  // ViewTransitionContentLayer rendering this snapshot is drawn.
+  if (render_surface->OwningEffectNode()->view_transition_target_id !=
+      kInvalidPropertyNodeId) {
+    CHECK(!is_root);
+    CHECK(render_surface->OwningEffectNode()
+              ->view_transition_element_resource_id.IsValid());
+
+    auto* vt_target = property_trees->effect_tree_mutable().GetRenderSurface(
+        render_surface->OwningEffectNode()->view_transition_target_id);
+    CHECK(vt_target);
+
+    if (!vt_target->is_render_surface_list_member()) {
+      AddSurfaceToRenderSurfaceList(vt_target, render_surface_list,
+                                    property_trees);
+    }
+  }
+
+  // TODO(vmpstr): revisit this later to see if there is a better fix, as this
+  // changes the render list in an incorrect way due to CC assumptions about how
+  // surfaces and view-transition captures interact.
   if (!is_root && !target->is_render_surface_list_member()) {
     AddSurfaceToRenderSurfaceList(target, render_surface_list, property_trees);
   }
@@ -1008,9 +1017,12 @@ bool SkipForInvertibility(const LayerImpl* layer,
              : !transform_node->ancestors_are_invertible;
 }
 
-void ComputeInitialRenderSurfaceList(LayerTreeImpl* layer_tree_impl,
-                                     PropertyTrees* property_trees,
-                                     RenderSurfaceList* render_surface_list) {
+void ComputeInitialRenderSurfaceList(
+    LayerTreeImpl* layer_tree_impl,
+    PropertyTrees* property_trees,
+    RenderSurfaceList* render_surface_list,
+    std::map<viz::ViewTransitionElementResourceId,
+             ViewTransitionContentLayerImpl*>& view_transition_content_layers) {
   EffectTree& effect_tree = property_trees->effect_tree_mutable();
   for (int i = kContentsRootPropertyNodeId;
        i < static_cast<int>(effect_tree.size()); ++i) {
@@ -1026,23 +1038,6 @@ void ComputeInitialRenderSurfaceList(LayerTreeImpl* layer_tree_impl,
   AddSurfaceToRenderSurfaceList(root_surface, render_surface_list,
                                 property_trees);
 
-  // Add all of the render surfaces for the transition pseudo elements early,
-  // since they will need to be added before the shared elements in the layer
-  // lists below, which isn't reflected in the dependency. This can't be done
-  // with dependency ordering because other things require correct dependency
-  // ordering (the AppendQuads pass). By adding the render surfaces right after
-  // the root, we guarantee that the pseudo element tree's render surfaces will
-  // come _after_ any render passes that they reference in the render pass
-  // order.
-  auto transition_pseudo_render_surfaces =
-      effect_tree.GetTransitionPseudoElementRenderSurfaces();
-  for (auto* surface : transition_pseudo_render_surfaces) {
-    if (!surface->is_render_surface_list_member()) {
-      AddSurfaceToRenderSurfaceList(surface, render_surface_list,
-                                    property_trees);
-    }
-  }
-
   // For all non-skipped layers, add their target to the render surface list if
   // it's not already been added, and add their content rect to the target
   // surface's accumulated content rect.
@@ -1097,12 +1092,27 @@ void ComputeInitialRenderSurfaceList(LayerTreeImpl* layer_tree_impl,
     // The layer contributes its drawable content rect to its render target.
     render_target->AccumulateContentRectFromContributingLayer(layer);
     render_target->increment_num_contributors();
+    if (!layer->ViewTransitionResourceId().IsValid()) {
+      continue;
+    }
+    auto* view_transition_content_layer =
+        static_cast<ViewTransitionContentLayerImpl*>(layer);
+    view_transition_content_layer->SetOriginatingSurfaceContentRect(
+        gfx::Rect());
+    view_transition_content_layers[layer->ViewTransitionResourceId()] =
+        view_transition_content_layer;
   }
 }
 
-void ComputeSurfaceContentRects(PropertyTrees* property_trees,
-                                RenderSurfaceList* render_surface_list,
-                                int max_texture_size) {
+void ComputeSurfaceContentRects(
+    PropertyTrees* property_trees,
+    RenderSurfaceList* render_surface_list,
+    int max_texture_size,
+    const std::map<viz::ViewTransitionElementResourceId,
+                   ViewTransitionContentLayerImpl*>
+        view_transition_content_layers,
+    std::vector<std::pair<viz::ViewTransitionElementResourceId, gfx::RectF>>&
+        view_transition_content_rects) {
   // Walk the list backwards, accumulating each surface's content rect into its
   // target's content rect.
   for (RenderSurfaceImpl* render_surface :
@@ -1125,6 +1135,28 @@ void ComputeSurfaceContentRects(PropertyTrees* property_trees,
     render_target->AccumulateContentRectFromContributingRenderSurface(
         render_surface);
     render_target->increment_num_contributors();
+
+    // Collect the content rects for view transition capture surfaces, and
+    // adjust the geometry for the corresponding content layer (the
+    // pseudo-element's layer).
+    const auto& view_transition_id =
+        render_surface->OwningEffectNode()->view_transition_element_resource_id;
+
+    if (!view_transition_id.IsValid()) {
+      continue;
+    }
+
+    auto unscaled_content_rect =
+        render_surface->SurfaceScale().InverseOrIdentity().MapRect(
+            render_surface->content_rect());
+
+    view_transition_content_rects.emplace_back(
+        view_transition_id, gfx::RectF(unscaled_content_rect));
+
+    if (view_transition_content_layers.contains(view_transition_id)) {
+      view_transition_content_layers.at(view_transition_id)
+          ->SetOriginatingSurfaceContentRect(unscaled_content_rect);
+    }
   }
 }
 
@@ -1136,20 +1168,41 @@ void ComputeListOfNonEmptySurfaces(LayerTreeImpl* layer_tree_impl,
   // surface with a non-empty content rect go into the final render surface
   // layer list. Surfaces with empty content rects or whose target isn't in
   // the final list do not get added to the final list.
-  bool removed_surface = false;
+  // Surface which require copy of output (view transition captures) are exempt
+  // because their contents are required regardless of the state of the target
+  // surface.
+  std::unordered_set<RenderSurfaceImpl*> surfaces_to_remove;
   for (RenderSurfaceImpl* surface : *initial_surface_list) {
     bool is_root = surface->EffectTreeIndex() == kContentsRootPropertyNodeId;
     RenderSurfaceImpl* target_surface = surface->render_target();
     if (!is_root && (surface->content_rect().IsEmpty() ||
-                     !target_surface->is_render_surface_list_member())) {
+                     (!target_surface->is_render_surface_list_member() &&
+                      !surface->CopyOfOutputRequired()))) {
       surface->set_is_render_surface_list_member(false);
-      removed_surface = true;
-      target_surface->decrement_num_contributors();
+      surfaces_to_remove.insert(surface);
       continue;
     }
+
+    // If one of the child surfaces had a CopyOfOutputRequired, it may be the
+    // reason we're adding it. However, we may have skipped its target surface
+    // already, so undelete the chain of all target surfaces for any surface
+    // that we're adding.
+    for (auto* target_to_undelete = target_surface;
+         surfaces_to_remove.count(target_to_undelete);
+         target_to_undelete = target_to_undelete->render_target()) {
+      surface->set_is_render_surface_list_member(true);
+      final_surface_list->push_back(target_to_undelete);
+      surfaces_to_remove.erase(target_to_undelete);
+    }
     final_surface_list->push_back(surface);
   }
-  if (removed_surface) {
+
+  for (auto* surface : surfaces_to_remove) {
+    RenderSurfaceImpl* target_surface = surface->render_target();
+    target_surface->decrement_num_contributors();
+  }
+
+  if (!surfaces_to_remove.empty()) {
     for (LayerImpl* layer : *layer_tree_impl) {
       if (layer->contributes_to_drawn_render_surface()) {
         RenderSurfaceImpl* render_target = layer->render_target();
@@ -1167,17 +1220,28 @@ void CalculateRenderSurfaceLayerList(LayerTreeImpl* layer_tree_impl,
                                      RenderSurfaceList* render_surface_list,
                                      const int max_texture_size) {
   RenderSurfaceList initial_render_surface_list;
+  std::vector<std::pair<viz::ViewTransitionElementResourceId, gfx::RectF>>
+      view_transition_content_rects;
+  std::map<viz::ViewTransitionElementResourceId,
+           ViewTransitionContentLayerImpl*>
+      view_transition_content_layers;
 
   // First compute a list that might include surfaces that later turn out to
   // have an empty content rect. After surface content rects are computed,
   // produce a final list that omits empty surfaces.
   ComputeInitialRenderSurfaceList(layer_tree_impl, property_trees,
-                                  &initial_render_surface_list);
+                                  &initial_render_surface_list,
+                                  view_transition_content_layers);
   ComputeSurfaceContentRects(property_trees, &initial_render_surface_list,
-                             max_texture_size);
+                             max_texture_size, view_transition_content_layers,
+                             view_transition_content_rects);
   ComputeListOfNonEmptySurfaces(layer_tree_impl, property_trees,
                                 &initial_render_surface_list,
                                 render_surface_list);
+
+  for (const auto& [id, rect] : view_transition_content_rects) {
+    layer_tree_impl->SetViewTransitionContentRect(id, rect);
+  }
 }
 
 void RecordRenderSurfaceReasonsForTracing(
@@ -1196,7 +1260,7 @@ void RecordRenderSurfaceReasonsForTracing(
 
   // kTest is the last value which is not included for tracing.
   constexpr auto kNumReasons = static_cast<size_t>(RenderSurfaceReason::kTest);
-  int reason_counts[kNumReasons] = {0};
+  std::array<int, kNumReasons> reason_counts = {0};
   for (const RenderSurfaceImpl* render_surface : *render_surface_list) {
     const auto* effect_node =
         property_trees->effect_tree().Node(render_surface->EffectTreeIndex());
@@ -1280,9 +1344,6 @@ void UpdateElasticOverscroll(
 
 void ComputeDrawPropertiesOfVisibleLayers(const LayerImplList* layer_list,
                                           PropertyTrees* property_trees) {
-  const bool common_ancestor_clip_enabled =
-      base::FeatureList::IsEnabled(features::kRenderSurfaceCommonAncestorClip);
-
   // Compute transforms and clear common ancestor clips of render surfaces.
   for (LayerImpl* layer : *layer_list) {
     const TransformNode* transform_node =
@@ -1300,30 +1361,14 @@ void ComputeDrawPropertiesOfVisibleLayers(const LayerImplList* layer_list,
     layer->draw_properties().is_fast_rounded_corner =
         mask_filter_info_pair.second;
 
-    if (common_ancestor_clip_enabled) {
-      ClearRenderSurfaceCommonAncestorClip(layer);
-    }
+    ClearRenderSurfaceCommonAncestorClip(layer);
   }
 
   // Compute effects and common ancestor clips of render surfaces.
   for (LayerImpl* layer : *layer_list) {
     layer->draw_properties().opacity =
         LayerDrawOpacity(layer, property_trees->effect_tree());
-    if (common_ancestor_clip_enabled) {
-      UpdateRenderSurfaceCommonAncestorClip(
-          layer, &property_trees->clip_tree(),
-          &property_trees->effect_tree_mutable());
-    } else {
-      RenderSurfaceImpl* render_target = layer->render_target();
-      int lca_clip_id = LowestCommonAncestor(layer->clip_tree_index(),
-                                             render_target->ClipTreeIndex(),
-                                             &property_trees->clip_tree());
-      if (lca_clip_id != render_target->ClipTreeIndex()) {
-        SetHasContributingLayerThatEscapesClip(
-            lca_clip_id, render_target->EffectTreeIndex(),
-            &property_trees->effect_tree_mutable());
-      }
-    }
+    UpdateRenderSurfaceCommonAncestorClip(layer, property_trees->clip_tree());
   }
 
   // Compute clips and visible rects
@@ -1353,13 +1398,6 @@ void ComputeDrawPropertiesOfVisibleLayers(const LayerImplList* layer_list,
         LayerDrawableContentRect(layer, visible_bounds_in_target_space,
                                  layer->draw_properties().clip_rect);
   }
-
-  // Make sure that the layers push their properties. This isn't necessary for
-  // picture layers that always push their properties, but is important for
-  // other layers to invalidate the active tree.
-  for (LayerImpl* layer : *layer_list) {
-    layer->SetNeedsPushProperties();
-  }
 }
 
 #if DCHECK_IS_ON()
@@ -1469,21 +1507,7 @@ void FindLayersThatNeedUpdates(LayerTreeImpl* layer_tree_impl,
 
 void ComputeTransforms(TransformTree* transform_tree,
                        const ViewportPropertyIds& viewport_property_ids) {
-  if (!transform_tree->needs_update()) {
-#if DCHECK_IS_ON()
-    // If the transform tree does not need an update, no TransformNode should
-    // need a local transform update.
-    for (int i = kContentsRootPropertyNodeId;
-         i < static_cast<int>(transform_tree->size()); ++i) {
-      DCHECK(!transform_tree->Node(i)->needs_local_transform_update);
-    }
-#endif
-    return;
-  }
-  for (int i = kContentsRootPropertyNodeId;
-       i < static_cast<int>(transform_tree->size()); ++i)
-    transform_tree->UpdateTransforms(i, &viewport_property_ids);
-  transform_tree->set_needs_update(false);
+  transform_tree->UpdateAllTransforms(viewport_property_ids);
 }
 
 void ComputeEffects(EffectTree* effect_tree) {
@@ -1518,7 +1542,7 @@ void UpdatePropertyTreesAndRenderSurfaces(LayerTreeImpl* layer_tree_impl,
     property_trees->clip_tree_mutable().set_needs_update(true);
     property_trees->effect_tree_mutable().set_needs_update(true);
   }
-  UpdateRenderTarget(&property_trees->effect_tree_mutable());
+  UpdateRenderTarget(layer_tree_impl, &property_trees->effect_tree_mutable());
 
   ComputeTransforms(&property_trees->transform_tree_mutable(),
                     layer_tree_impl->viewport_property_ids());
@@ -1658,7 +1682,7 @@ bool LogDoubleBackgroundBlur(const LayerTreeImpl& layer_tree_impl,
           gfx::Rect screen_space_rect = MathUtil::MapEnclosingClippedRect(
               render_surface->screen_space_transform(),
               render_surface->content_rect());
-          auto it = base::ranges::find_if(
+          auto it = std::ranges::find_if(
               rects, [&screen_space_rect](
                          const std::pair<const LayerImpl*, gfx::Rect>& r) {
                 return r.second.Intersects(screen_space_rect);
