@@ -26,7 +26,12 @@ LayerTreeSettings::~LayerTreeSettings() = default;
 
 bool LayerTreeSettings::UseLayerContextForDisplay() const {
   return use_layer_lists && !is_display_tree &&
-         base::FeatureList::IsEnabled(features::kVizLayers);
+         base::FeatureList::IsEnabled(features::kTreesInViz);
+}
+
+bool LayerTreeSettings::UseLayerContextForAnimations() const {
+  return UseLayerContextForDisplay() &&
+         base::FeatureList::IsEnabled(features::kTreeAnimationsInViz);
 }
 
 SchedulerSettings LayerTreeSettings::ToSchedulerSettings() const {
@@ -54,7 +59,11 @@ SchedulerSettings LayerTreeSettings::ToSchedulerSettings() const {
              ::features::
                  kScrollEventDispatchModeDispatchScrollEventsImmediately ||
          mode_name ==
-             ::features::kScrollEventDispatchModeUseScrollPredictorForDeadline);
+             ::features::
+                 kScrollEventDispatchModeUseScrollPredictorForDeadline ||
+         mode_name ==
+             ::features::
+                 kScrollEventDispatchModeDispatchScrollEventsUntilDeadline);
     if (scheduler_settings.scroll_deadline_mode_enabled) {
       scheduler_settings.scroll_deadline_ratio =
           ::features::kWaitForLateScrollEventsDeadlineRatio.Get();
