@@ -4,18 +4,14 @@
 
 #include "chrome/browser/accessibility/accessibility_state_utils.h"
 
-#include "build/chromeos_buildflags.h"
+#include "build/build_config.h"
 
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
 #include "chrome/browser/ash/accessibility/accessibility_manager.h"
 #else
 #include <stdint.h>
 #include "content/public/browser/browser_accessibility_state.h"
-#endif  // BUILDFLAG(IS_CHROMEOS_ASH)
-
-#if BUILDFLAG(IS_CHROMEOS_LACROS)
-#include "chrome/browser/lacros/embedded_a11y_manager_lacros.h"
-#endif  // BUILDFLAG(IS_CHROMEOS_LACROS)
+#endif  // BUILDFLAG(IS_CHROMEOS)
 
 namespace accessibility_state_utils {
 
@@ -24,7 +20,7 @@ enum class OverrideStatus { kNotSet = 0, kEnabled = 1, kDisabled = 2 };
 static OverrideStatus screen_reader_enabled_override_for_testing =
     OverrideStatus::kNotSet;
 
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
 using ::ash::AccessibilityManager;
 #endif
 
@@ -33,16 +29,16 @@ bool IsScreenReaderEnabled() {
     return screen_reader_enabled_override_for_testing ==
            OverrideStatus::kEnabled;
   }
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
   return AccessibilityManager::Get() &&
          AccessibilityManager::Get()->IsSpokenFeedbackEnabled();
 #else
-  // TODO(katie): Can we use AXMode in Chrome OS as well? May need to stop
-  // Switch Access and Select-to-Speak from setting kScreenReader.
+  // TODO(crbug.com/383057958): Consider updating this to return true only when
+  // an actual screen reader is enabled.
   ui::AXMode mode =
       content::BrowserAccessibilityState::GetInstance()->GetAccessibilityMode();
   return mode.has_mode(ui::AXMode::kScreenReader);
-#endif  // BUILDFLAG(IS_CHROMEOS_ASH)
+#endif  // BUILDFLAG(IS_CHROMEOS)
 }
 
 void OverrideIsScreenReaderEnabledForTesting(bool enabled) {
@@ -51,15 +47,12 @@ void OverrideIsScreenReaderEnabledForTesting(bool enabled) {
 }
 
 bool IsSelectToSpeakEnabled() {
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
   return AccessibilityManager::Get() &&
          AccessibilityManager::Get()->IsSelectToSpeakEnabled();
-#elif BUILDFLAG(IS_CHROMEOS_LACROS)
-  return EmbeddedA11yManagerLacros::GetInstance() &&
-         EmbeddedA11yManagerLacros::GetInstance()->IsSelectToSpeakEnabled();
 #else
   return false;
-#endif  // BUILDFLAG(IS_CHROMEOS_ASH)
+#endif  // BUILDFLAG(IS_CHROMEOS)
 }
 
 }  // namespace accessibility_state_utils
