@@ -23,11 +23,11 @@
 #include "components/signin/public/identity_manager/identity_manager.h"
 #include "components/variations/service/variations_service.h"
 #include "components/variations/service/variations_service_utils.h"
+#include "google_apis/gaia/gaia_constants.h"
 #include "net/base/load_flags.h"
 
 const char kAidaEndpointUrl[] =
     "https://aida.googleapis.com/v1/aida:doConversation";
-const char kAidaScopeUrl[] = "https://www.googleapis.com/auth/aida";
 
 constexpr auto kLoggingDisallowedCountries =
     base::MakeFixedFlatSet<std::string_view>(
@@ -59,7 +59,7 @@ constexpr auto kAidaSupportedCountries =
 AidaClient::AidaClient(Profile* profile)
     : profile_(*profile),
       aida_endpoint_(kAidaEndpointUrl),
-      aida_scope_(kAidaScopeUrl) {}
+      aida_scope_(GaiaConstants::kAidaOAuth2Scope) {}
 
 AidaClient::~AidaClient() = default;
 
@@ -129,6 +129,9 @@ AidaClient::Availability AidaClient::CanUseAida(Profile* profile) {
       IsLoggingDisabledByGeo(country_code);
   result.blocked = result.blocked_by_age ||
                    result.blocked_by_enterprise_policy || result.blocked_by_geo;
+  result.enterprise_policy_value =
+      static_cast<DevToolsGenAiEnterprisePolicyValue>(
+          profile->GetPrefs()->GetInteger(prefs::kDevToolsGenAiSettings));
 
   return result;
 #else
@@ -154,6 +157,10 @@ void AidaClient::OverrideAidaEndpointAndScopeForTesting(
   aida_scope_ = aida_scope;
 }
 
+void AidaClient::RemoveAccessToken() {
+  access_token_.clear();
+}
+
 void AidaClient::PrepareRequestOrFail(
     base::OnceCallback<
         void(absl::variant<network::ResourceRequest, std::string>)> callback) {
@@ -167,7 +174,7 @@ void AidaClient::PrepareRequestOrFail(
     return;
   }
   CoreAccountId account_id =
-      identity_manager->GetPrimaryAccountId(signin::ConsentLevel::kSync);
+      identity_manager->GetPrimaryAccountId(signin::ConsentLevel::kSignin);
   access_token_fetcher_ = identity_manager->CreateAccessTokenFetcherForAccount(
       account_id, "AIDA client", signin::ScopeSet{aida_scope_},
       base::BindOnce(&AidaClient::AccessTokenFetchFinished,
