@@ -8,11 +8,13 @@
 #include <memory>
 #include <string>
 
+#include "base/memory/raw_ptr.h"
 #include "base/memory/weak_ptr.h"
 #include "base/time/time.h"
 #include "chrome/browser/devtools/devtools_contents_resizing_strategy.h"
 #include "chrome/browser/devtools/devtools_toggle_action.h"
 #include "chrome/browser/devtools/devtools_ui_bindings.h"
+#include "content/public/browser/child_process_host.h"
 #include "content/public/browser/web_contents_delegate.h"
 #include "content/public/browser/web_contents_observer.h"
 
@@ -58,9 +60,11 @@ enum class DevToolsOpenedByAction {
   kTargetReload = 8,
   // Open Node DevTools button in a regular app
   kOpenForNodeFromAnotherTarget = 9,
+  // User-pinned button in the toolbar
+  kPinnedToolbarButton = 10,
   // Add values above this line with a corresponding label in
-  // tools/metrics/histograms/enums.xml
-  kMaxValue = kOpenForNodeFromAnotherTarget,
+  // tools/metrics/histograms/metadata/dev/enums.xml
+  kMaxValue = kPinnedToolbarButton,
 };
 
 enum class DevToolsClosedByAction {
@@ -72,11 +76,14 @@ enum class DevToolsClosedByAction {
   kToggleShortcut = 2,
   kCloseButton = 3,
   kTargetDetach = 4,
-  kMaxValue = kTargetDetach,
+  kPinnedToolbarButton = 5,
+  kMaxValue = kPinnedToolbarButton,
 };
 
 class DevToolsWindow : public DevToolsUIBindings::Delegate,
-                       public content::WebContentsDelegate {
+                       public content::WebContentsDelegate,
+                       public content::WebContentsObserver,
+                       public infobars::InfoBarManager::Observer {
  public:
   static const char kDevToolsApp[];
 
@@ -176,18 +183,12 @@ class DevToolsWindow : public DevToolsUIBindings::Delegate,
   static std::unique_ptr<content::NavigationThrottle>
   MaybeCreateNavigationThrottle(content::NavigationHandle* handle);
 
-  // Updates the WebContents inspected by the DevToolsWindow by reattaching
-  // the binding to |new_web_contents|. Called when swapping an outer
-  // WebContents with its inner WebContents.
-  void UpdateInspectedWebContents(content::WebContents* new_web_contents,
-                                  base::OnceCallback<void()> callback);
-
   // Sets closure to be called after load is done. If already loaded, calls
   // closure immediately.
   void SetLoadCompletedCallback(base::OnceClosure closure);
 
   // Forwards an unhandled keyboard event to the DevTools frontend.
-  bool ForwardKeyboardEvent(const content::NativeWebKeyboardEvent& event);
+  bool ForwardKeyboardEvent(const input::NativeWebKeyboardEvent& event);
 
   // Reloads inspected web contents as if it was triggered from DevTools.
   // Returns true if it has successfully handled reload, false if the caller
@@ -196,7 +197,9 @@ class DevToolsWindow : public DevToolsUIBindings::Delegate,
 
   content::WebContents* OpenURLFromTab(
       content::WebContents* source,
-      const content::OpenURLParams& params) override;
+      const content::OpenURLParams& params,
+      base::OnceCallback<void(content::NavigationHandle&)>
+          navigation_handle_callback) override;
 
   content::WebContents* OpenURLFromInspectedTab(
       const content::OpenURLParams& params);
@@ -277,6 +280,13 @@ class DevToolsWindow : public DevToolsUIBindings::Delegate,
 
   content::WebContents* GetInspectedWebContents();
 
+  // content::DevToolsUIBindings::Delegate overrides
+  void ActivateWindow() override;
+
+  void MainWebContentRenderFrameHostChanged(
+      content::RenderFrameHost* old_frame,
+      content::RenderFrameHost* new_frame);
+
  private:
   friend class DevToolsWindowTesting;
   friend class DevToolsWindowCreationObserver;
@@ -376,13 +386,14 @@ class DevToolsWindow : public DevToolsUIBindings::Delegate,
 
   // content::WebContentsDelegate:
   void ActivateContents(content::WebContents* contents) override;
-  void AddNewContents(content::WebContents* source,
-                      std::unique_ptr<content::WebContents> new_contents,
-                      const GURL& target_url,
-                      WindowOpenDisposition disposition,
-                      const blink::mojom::WindowFeatures& window_features,
-                      bool user_gesture,
-                      bool* was_blocked) override;
+  content::WebContents* AddNewContents(
+      content::WebContents* source,
+      std::unique_ptr<content::WebContents> new_contents,
+      const GURL& target_url,
+      WindowOpenDisposition disposition,
+      const blink::mojom::WindowFeatures& window_features,
+      bool user_gesture,
+      bool* was_blocked) override;
   void WebContentsCreated(content::WebContents* source_contents,
                           int opener_render_process_id,
                           int opener_render_frame_id,
@@ -396,10 +407,9 @@ class DevToolsWindow : public DevToolsUIBindings::Delegate,
                          bool* proceed_to_fire_unload) override;
   content::KeyboardEventProcessingResult PreHandleKeyboardEvent(
       content::WebContents* source,
-      const content::NativeWebKeyboardEvent& event) override;
-  bool HandleKeyboardEvent(
-      content::WebContents* source,
-      const content::NativeWebKeyboardEvent& event) override;
+      const input::NativeWebKeyboardEvent& event) override;
+  bool HandleKeyboardEvent(content::WebContents* source,
+                           const input::NativeWebKeyboardEvent& event) override;
   content::JavaScriptDialogManager* GetJavaScriptDialogManager(
       content::WebContents* source) override;
   std::unique_ptr<content::EyeDropper> OpenEyeDropper(
@@ -413,13 +423,13 @@ class DevToolsWindow : public DevToolsUIBindings::Delegate,
   void Close(DevToolsClosedByAction closed_by);
 
   // content::DevToolsUIBindings::Delegate overrides
-  void ActivateWindow() override;
   void CloseWindow() override;
   void Inspect(scoped_refptr<content::DevToolsAgentHost> host) override;
   void SetInspectedPageBounds(const gfx::Rect& rect) override;
   void InspectElementCompleted() override;
   void SetIsDocked(bool is_docked) override;
   void OpenInNewTab(const std::string& url) override;
+  void OpenSearchResultsInNewTab(const std::string& url) override;
   void SetWhitelistedShortcuts(const std::string& message) override;
   void SetEyeDropperActive(bool active) override;
   void OpenNodeFrontend() override;
@@ -435,8 +445,16 @@ class DevToolsWindow : public DevToolsUIBindings::Delegate,
   int GetOpenedByForLogging() override;
   int GetClosedByForLogging() override;
 
+  void OpenInNewTab(const GURL& url);
   void ColorPickedInEyeDropper(int r, int g, int b, int a);
 
+  // content::WebContentsObserver
+  using content::WebContentsObserver::BeforeUnloadFired;
+  void PrimaryPageChanged(content::Page& page) override;
+
+  // infobars::InfoBarManager::Observer
+  void OnInfoBarRemoved(infobars::InfoBar* infobar, bool animate) override;
+
   // This method creates a new Browser object (if possible), and passes
   // ownership of owned_main_web_contents_ to the tab strip of the Browser.
   void CreateDevToolsBrowser();
@@ -452,8 +470,6 @@ class DevToolsWindow : public DevToolsUIBindings::Delegate,
   // display web modal dialogs triggered by it.
   void RegisterModalDialogManager(Browser* browser);
 
-  void OnReattachMainTargetComplete(base::Value);
-
   // Called when the accepted language changes. |navigator.language| of the
   // DevTools window should match the application language. When the user
   // changes the accepted language then this listener flips the language back
@@ -463,11 +479,26 @@ class DevToolsWindow : public DevToolsUIBindings::Delegate,
   void OnLocaleChanged();
   void OverrideAndSyncDevToolsRendererPrefs();
 
-  base::WeakPtr<content::WebContents> inspected_web_contents_;
+  void MaybeShowSharedProcessInfobar();
 
   FrontendType frontend_type_;
-  Profile* profile_;
-  content::WebContents* main_web_contents_;
+  raw_ptr<Profile> profile_;
+  raw_ptr<content::WebContents> main_web_contents_;
+
+  class MainWebContentsObserver : public content::WebContentsObserver {
+   public:
+    MainWebContentsObserver(content::WebContents& web_contents,
+                            DevToolsWindow& window)
+        : WebContentsObserver(&web_contents), window_(window) {}
+    ~MainWebContentsObserver() override;
+
+   private:
+    void RenderFrameHostChanged(content::RenderFrameHost* old_frame,
+                                content::RenderFrameHost* new_frame) override;
+
+    raw_ref<DevToolsWindow> window_;
+  };
+  MainWebContentsObserver main_web_contents_observer_;
 
   // DevToolsWindow is informed of the creation of the |toolbox_web_contents_|
   // in WebContentsCreated right before ownership is passed to to DevToolsWindow
@@ -476,11 +507,11 @@ class DevToolsWindow : public DevToolsUIBindings::Delegate,
   // |toolbox_web_contents_|, and then update ownership immediately afterwards.
   // TODO(erikchen): If we updated AddNewContents() to also pass back the
   // target url, then we wouldn't need to listen to WebContentsCreated at all.
-  content::WebContents* toolbox_web_contents_;
+  raw_ptr<content::WebContents, DanglingUntriaged> toolbox_web_contents_;
   std::unique_ptr<content::WebContents> owned_toolbox_web_contents_;
 
-  DevToolsUIBindings* bindings_;
-  Browser* browser_;
+  raw_ptr<DevToolsUIBindings> bindings_;
+  raw_ptr<Browser> browser_;
 
   // When DevToolsWindow is docked, it owns main_web_contents_. When it isn't
   // docked, the tab strip model owns the main_web_contents_.
@@ -510,10 +541,10 @@ class DevToolsWindow : public DevToolsUIBindings::Delegate,
   const base::UnguessableToken session_id_for_logging_;
 
   class Throttle;
-  Throttle* throttle_ = nullptr;
+  raw_ptr<Throttle> throttle_ = nullptr;
   bool open_new_window_for_popups_ = false;
-
-  base::OnceCallback<void()> reattach_complete_callback_;
+  raw_ptr<infobars::InfoBar> sharing_infobar_ = nullptr;
+  int checked_sharing_process_id_ = content::ChildProcessHost::kInvalidUniqueID;
 
   PrefChangeRegistrar pref_change_registrar_;
 
