@@ -54,7 +54,7 @@
 
 namespace extensions {
 
-using ContextType = ExtensionApiTest::ContextType;
+using ContextType = extensions::browser_test_util::ContextType;
 
 class ExtensionContentSettingsApiTest : public ExtensionApiTest {
  public:
