@@ -6,34 +6,23 @@
 
 #include <stdint.h>
 
+#include <optional>
 #include <string>
 #include <utility>
 #include <vector>
 
 #include "base/values.h"
+#include "chrome/browser/ash/crosapi/keystore_service_ash.h"
+#include "chrome/browser/ash/crosapi/keystore_service_factory_ash.h"
 #include "chrome/browser/chromeos/platform_keys/extension_platform_keys_service.h"
 #include "chrome/browser/chromeos/platform_keys/extension_platform_keys_service_factory.h"
 #include "chrome/browser/chromeos/platform_keys/platform_keys.h"
-#include "chrome/browser/extensions/api/platform_keys/platform_keys_api.h"
+#include "chrome/browser/extensions/api/platform_keys_core/platform_keys_utils.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/common/extensions/api/enterprise_platform_keys.h"
 #include "chrome/common/extensions/api/enterprise_platform_keys_internal.h"
-#include "chrome/common/pref_names.h"
 #include "chromeos/crosapi/mojom/keystore_service.mojom.h"
-#include "components/pref_registry/pref_registry_syncable.h"
-#include "components/prefs/pref_service.h"
 #include "extensions/browser/extension_function.h"
-#include "extensions/common/extension.h"
-#include "extensions/common/manifest.h"
-
-#if BUILDFLAG(IS_CHROMEOS_LACROS)
-#include "chromeos/lacros/lacros_service.h"
-#endif  // BUILDFLAG(IS_CHROMEOS_LACROS)
-
-#if BUILDFLAG(IS_CHROMEOS_ASH)
-#include "chrome/browser/ash/crosapi/keystore_service_ash.h"
-#include "chrome/browser/ash/crosapi/keystore_service_factory_ash.h"
-#endif  // #if BUILDFLAG(IS_CHROMEOS_ASH)
 
 namespace extensions {
 
@@ -43,64 +32,37 @@ namespace api_epk = api::enterprise_platform_keys;
 namespace api_epki = api::enterprise_platform_keys_internal;
 using crosapi::mojom::KeystoreService;
 
-#if BUILDFLAG(IS_CHROMEOS_LACROS)
-const char kUnsupportedByAsh[] = "Not implemented.";
-const char kUnsupportedProfile[] = "Not available.";
-#endif  // BUILDFLAG(IS_CHROMEOS_LACROS)
 const char kExtensionDoesNotHavePermission[] =
     "The extension does not have permission to call this function.";
-const char kChromeOsEcdsaUnsupported[] =
-    "Installed ChromeOS version does not support ECDSA.";
 
 crosapi::mojom::KeystoreService* GetKeystoreService(
     content::BrowserContext* browser_context) {
-#if BUILDFLAG(IS_CHROMEOS_LACROS)
-  // TODO(b/191958380): Lift the restriction when *.platformKeys.* APIs are
-  // implemented for secondary profiles in Lacros.
-  CHECK(Profile::FromBrowserContext(browser_context)->IsMainProfile())
-      << "Attempted to use an incorrect profile. Please file a bug at "
-         "https://bugs.chromium.org/ if this happens.";
-  return chromeos::LacrosService::Get()->GetRemote<KeystoreService>().get();
-#endif  // #if BUILDFLAG(IS_CHROMEOS_LACROS)
-
-#if BUILDFLAG(IS_CHROMEOS_ASH)
   return crosapi::KeystoreServiceFactoryAsh::GetForBrowserContext(
       browser_context);
-#endif  // #if BUILDFLAG(IS_CHROMEOS_ASH)
-}
-
-// Performs common crosapi validation. These errors are not caused by the
-// extension so they are considered recoverable. Returns an error message on
-// error, or empty string on success. |min_version| is the minimum version of
-// the ash implementation of KeystoreService necessary to support this
-// extension. |context| is the browser context in which the extension is hosted.
-std::string ValidateCrosapi(int min_version, content::BrowserContext* context) {
-#if BUILDFLAG(IS_CHROMEOS_LACROS)
-  chromeos::LacrosService* service = chromeos::LacrosService::Get();
-  if (!service || !service->IsAvailable<crosapi::mojom::KeystoreService>())
-    return kUnsupportedByAsh;
-
-  int version = service->GetInterfaceVersion<KeystoreService>();
-  if (version < min_version)
-    return kUnsupportedByAsh;
-
-  // These APIs are used in security-sensitive contexts. We need to ensure that
-  // the user for ash is the same as the user for lacros. We do this by
-  // restricting the API to the default profile, which is guaranteed to be the
-  // same user.
-  if (!Profile::FromBrowserContext(context)->IsMainProfile())
-    return kUnsupportedProfile;
-#endif  // #if BUILDFLAG(IS_CHROMEOS_LACROS)
-
-  return "";
 }
 
 std::optional<crosapi::mojom::KeystoreType> KeystoreTypeFromString(
     const std::string& input) {
-  if (input == "user")
+  if (input == "user") {
     return crosapi::mojom::KeystoreType::kUser;
-  if (input == "system")
+  }
+  if (input == "system") {
     return crosapi::mojom::KeystoreType::kDevice;
+  }
+  return std::nullopt;
+}
+
+std::optional<chromeos::platform_keys::KeyType> KeyTypeFromString(
+    const std::string& input) {
+  if (input == "RSASSA-PKCS1-v1_5") {
+    return chromeos::platform_keys::KeyType::kRsassaPkcs1V15;
+  }
+  if (input == "RSA-OAEP") {
+    return chromeos::platform_keys::KeyType::kRsaOaep;
+  }
+  if (input == "ECDSA") {
+    return chromeos::platform_keys::KeyType::kEcdsa;
+  }
   return std::nullopt;
 }
 
@@ -112,34 +74,15 @@ std::string ValidateInput(const std::string& token_id,
                           crosapi::mojom::KeystoreType* keystore) {
   std::optional<crosapi::mojom::KeystoreType> keystore_type =
       KeystoreTypeFromString(token_id);
-  if (!keystore_type)
+  if (!keystore_type) {
     return platform_keys::kErrorInvalidToken;
+  }
 
   *keystore = keystore_type.value();
   return "";
 }
 }  // namespace
 
-namespace platform_keys {
-
-void RegisterProfilePrefs(user_prefs::PrefRegistrySyncable* registry) {
-  registry->RegisterListPref(prefs::kAttestationExtensionAllowlist);
-}
-
-bool IsExtensionAllowed(Profile* profile, const Extension* extension) {
-  if (Manifest::IsComponentLocation(extension->location())) {
-    // Note: For this to even be called, the component extension must also be
-    // allowed in chrome/common/extensions/api/_permission_features.json
-    return true;
-  }
-  const base::Value::List& list =
-      profile->GetPrefs()->GetList(prefs::kAttestationExtensionAllowlist);
-  base::Value value(extension->id());
-  return base::Contains(list, value);
-}
-
-}  // namespace platform_keys
-
 //------------------------------------------------------------------------------
 
 EnterprisePlatformKeysInternalGenerateKeyFunction::
@@ -150,46 +93,47 @@ EnterprisePlatformKeysInternalGenerateKeyFunction::Run() {
   std::optional<api_epki::GenerateKey::Params> params =
       api_epki::GenerateKey::Params::Create(args());
 
-#if BUILDFLAG(IS_CHROMEOS_LACROS)
-  // TODO(b/191958380): Lift the restriction when *.platformKeys.* APIs are
-  // implemented for secondary profiles in Lacros.
-  if (!Profile::FromBrowserContext(browser_context())->IsMainProfile())
-    return RespondNow(Error(kUnsupportedProfile));
-#endif  // BUILDFLAG(IS_CHROMEOS_LACROS)
-
   EXTENSION_FUNCTION_VALIDATE(params);
   std::optional<chromeos::platform_keys::TokenId> platform_keys_token_id =
       platform_keys::ApiIdToPlatformKeysTokenId(params->token_id);
-  if (!platform_keys_token_id)
+  if (!platform_keys_token_id) {
     return RespondNow(Error(platform_keys::kErrorInvalidToken));
+  }
 
   chromeos::ExtensionPlatformKeysService* service =
       chromeos::ExtensionPlatformKeysServiceFactory::GetForBrowserContext(
           browser_context());
   DCHECK(service);
 
-  if (params->algorithm.name == "RSASSA-PKCS1-v1_5") {
-    // TODO(pneubeck): Add support for unsigned integers to IDL.
-    EXTENSION_FUNCTION_VALIDATE(params->algorithm.modulus_length &&
-                                *(params->algorithm.modulus_length) >= 0);
-    service->GenerateRSAKey(
-        platform_keys_token_id.value(), *(params->algorithm.modulus_length),
-        params->software_backed, extension_id(),
-        base::BindOnce(
-            &EnterprisePlatformKeysInternalGenerateKeyFunction::OnGeneratedKey,
-            this));
-  } else if (params->algorithm.name == "ECDSA") {
-    EXTENSION_FUNCTION_VALIDATE(params->algorithm.named_curve);
-    service->GenerateECKey(
-        platform_keys_token_id.value(), *(params->algorithm.named_curve),
-        extension_id(),
-        base::BindOnce(
-            &EnterprisePlatformKeysInternalGenerateKeyFunction::OnGeneratedKey,
-            this));
-  } else {
-    NOTREACHED_IN_MIGRATION();
-    EXTENSION_FUNCTION_VALIDATE(false);
+  std::optional<chromeos::platform_keys::KeyType> key_type =
+      KeyTypeFromString(params->algorithm.name);
+  CHECK(key_type.has_value());
+
+  switch (key_type.value()) {
+    case chromeos::platform_keys::KeyType::kRsassaPkcs1V15:
+    case chromeos::platform_keys::KeyType::kRsaOaep:
+      // TODO(pneubeck): Add support for unsigned integers to IDL.
+      EXTENSION_FUNCTION_VALIDATE(params->algorithm.modulus_length &&
+                                  *(params->algorithm.modulus_length) >= 0);
+      service->GenerateRSAKey(
+          platform_keys_token_id.value(), key_type.value(),
+          *(params->algorithm.modulus_length), params->software_backed,
+          extension_id(),
+          base::BindOnce(&EnterprisePlatformKeysInternalGenerateKeyFunction::
+                             OnGeneratedKey,
+                         this));
+      break;
+    case chromeos::platform_keys::KeyType::kEcdsa:
+      EXTENSION_FUNCTION_VALIDATE(params->algorithm.named_curve);
+      service->GenerateECKey(
+          platform_keys_token_id.value(), key_type.value(),
+          *(params->algorithm.named_curve), extension_id(),
+          base::BindOnce(&EnterprisePlatformKeysInternalGenerateKeyFunction::
+                             OnGeneratedKey,
+                         this));
+      break;
   }
+
   return RespondLater();
 }
 
@@ -214,14 +158,8 @@ EnterprisePlatformKeysGetCertificatesFunction::Run() {
       api_epk::GetCertificates::Params::Create(args());
   EXTENSION_FUNCTION_VALIDATE(params);
 
-  std::string error = ValidateCrosapi(
-      KeystoreService::kGetCertificatesMinVersion, browser_context());
-  if (!error.empty()) {
-    return RespondNow(Error(error));
-  }
-
   crosapi::mojom::KeystoreType keystore;
-  error = ValidateInput(params->token_id, &keystore);
+  std::string error = ValidateInput(params->token_id, &keystore);
   if (!error.empty()) {
     return RespondNow(Error(error));
   }
@@ -260,14 +198,8 @@ EnterprisePlatformKeysImportCertificateFunction::Run() {
       api_epk::ImportCertificate::Params::Create(args());
   EXTENSION_FUNCTION_VALIDATE(params);
 
-  std::string error = ValidateCrosapi(
-      KeystoreService::kAddCertificateMinVersion, browser_context());
-  if (!error.empty()) {
-    return RespondNow(Error(error));
-  }
-
   crosapi::mojom::KeystoreType keystore;
-  error = ValidateInput(params->token_id, &keystore);
+  std::string error = ValidateInput(params->token_id, &keystore);
   EXTENSION_FUNCTION_VALIDATE(error.empty());
 
   auto c = base::BindOnce(
@@ -295,14 +227,8 @@ EnterprisePlatformKeysRemoveCertificateFunction::Run() {
       api_epk::RemoveCertificate::Params::Create(args());
   EXTENSION_FUNCTION_VALIDATE(params);
 
-  std::string error = ValidateCrosapi(
-      KeystoreService::kRemoveCertificateMinVersion, browser_context());
-  if (!error.empty()) {
-    return RespondNow(Error(error));
-  }
-
   crosapi::mojom::KeystoreType keystore;
-  error = ValidateInput(params->token_id, &keystore);
+  std::string error = ValidateInput(params->token_id, &keystore);
   EXTENSION_FUNCTION_VALIDATE(error.empty());
 
   auto c = base::BindOnce(
@@ -329,12 +255,6 @@ ExtensionFunction::ResponseAction
 EnterprisePlatformKeysInternalGetTokensFunction::Run() {
   EXTENSION_FUNCTION_VALIDATE(args().empty());
 
-  std::string error = ValidateCrosapi(KeystoreService::kGetKeyStoresMinVersion,
-                                      browser_context());
-  if (!error.empty()) {
-    return RespondNow(Error(error));
-  }
-
   auto c = base::BindOnce(
       &EnterprisePlatformKeysInternalGetTokensFunction::OnGetKeyStores, this);
   GetKeystoreService(browser_context())->GetKeyStores(std::move(c));
@@ -377,12 +297,6 @@ EnterprisePlatformKeysChallengeMachineKeyFunction::Run() {
       api_epk::ChallengeMachineKey::Params::Create(args());
   EXTENSION_FUNCTION_VALIDATE(params);
 
-  const std::string error = ValidateCrosapi(
-      KeystoreService::kChallengeAttestationOnlyKeystoreMinVersion,
-      browser_context());
-  if (!error.empty())
-    return RespondNow(Error(error));
-
   if (!platform_keys::IsExtensionAllowed(
           Profile::FromBrowserContext(browser_context()), extension())) {
     return RespondNow(Error(kExtensionDoesNotHavePermission));
@@ -395,8 +309,7 @@ EnterprisePlatformKeysChallengeMachineKeyFunction::Run() {
       ->ChallengeAttestationOnlyKeystore(
           crosapi::mojom::KeystoreType::kDevice, params->challenge,
           /*migrate=*/params->register_key ? *params->register_key : false,
-          crosapi::mojom::KeystoreSigningAlgorithmName::kRsassaPkcs115,
-          std::move(c));
+          crosapi::mojom::KeystoreAlgorithmName::kRsassaPkcs115, std::move(c));
   return RespondLater();
 }
 
@@ -426,12 +339,6 @@ EnterprisePlatformKeysChallengeUserKeyFunction::Run() {
       api_epk::ChallengeUserKey::Params::Create(args());
   EXTENSION_FUNCTION_VALIDATE(params);
 
-  const std::string error = ValidateCrosapi(
-      KeystoreService::kChallengeAttestationOnlyKeystoreMinVersion,
-      browser_context());
-  if (!error.empty())
-    return RespondNow(Error(error));
-
   if (!platform_keys::IsExtensionAllowed(
           Profile::FromBrowserContext(browser_context()), extension())) {
     return RespondNow(Error(kExtensionDoesNotHavePermission));
@@ -444,8 +351,7 @@ EnterprisePlatformKeysChallengeUserKeyFunction::Run() {
       ->ChallengeAttestationOnlyKeystore(
           crosapi::mojom::KeystoreType::kUser, params->challenge,
           /*migrate=*/params->register_key,
-          crosapi::mojom::KeystoreSigningAlgorithmName::kRsassaPkcs115,
-          std::move(c));
+          crosapi::mojom::KeystoreAlgorithmName::kRsassaPkcs115, std::move(c));
   return RespondLater();
 }
 
@@ -468,21 +374,12 @@ void EnterprisePlatformKeysChallengeUserKeyFunction::
 
 //------------------------------------------------------------------------------
 
-const uint64_t kChallengeKeystoreAlgorithmParameterMinVersion = 17;
-
 ExtensionFunction::ResponseAction
 EnterprisePlatformKeysChallengeKeyFunction::Run() {
   std::optional<api_epk::ChallengeKey::Params> params =
       api_epk::ChallengeKey::Params::Create(args());
   EXTENSION_FUNCTION_VALIDATE(params);
 
-  std::string error = ValidateCrosapi(
-      KeystoreService::kChallengeAttestationOnlyKeystoreMinVersion,
-      browser_context());
-  if (!error.empty()) {
-    return RespondNow(Error(std::move(error)));
-  }
-
   if (!platform_keys::IsExtensionAllowed(
           Profile::FromBrowserContext(browser_context()), extension())) {
     return RespondNow(Error(kExtensionDoesNotHavePermission));
@@ -500,34 +397,26 @@ EnterprisePlatformKeysChallengeKeyFunction::Run() {
       keystore_type = crosapi::mojom::KeystoreType::kDevice;
       break;
     case api::enterprise_platform_keys::Scope::kNone:
-      NOTREACHED_IN_MIGRATION();
+      NOTREACHED();
   }
 
   // Default to RSA when not registering a key.
-  crosapi::mojom::KeystoreSigningAlgorithmName algorithm =
-      crosapi::mojom::KeystoreSigningAlgorithmName::kRsassaPkcs115;
+  crosapi::mojom::KeystoreAlgorithmName algorithm =
+      crosapi::mojom::KeystoreAlgorithmName::kRsassaPkcs115;
   if (params->options.register_key.has_value()) {
     EXTENSION_FUNCTION_VALIDATE(
         params->options.register_key->algorithm !=
         api::enterprise_platform_keys::Algorithm::kNone);
     switch (params->options.register_key->algorithm) {
       case api::enterprise_platform_keys::Algorithm::kRsa:
-        algorithm =
-            crosapi::mojom::KeystoreSigningAlgorithmName::kRsassaPkcs115;
+        algorithm = crosapi::mojom::KeystoreAlgorithmName::kRsassaPkcs115;
         break;
       case api::enterprise_platform_keys::Algorithm::kEcdsa: {
-        // Older versions of Ash default to RSA. If ECDSA is specified but the
-        // Keystore would use RSA instead, return an error.
-        const std::string version_error = ValidateCrosapi(
-            kChallengeKeystoreAlgorithmParameterMinVersion, browser_context());
-        if (!version_error.empty()) {
-          return RespondNow(Error(kChromeOsEcdsaUnsupported));
-        }
-        algorithm = crosapi::mojom::KeystoreSigningAlgorithmName::kEcdsa;
+        algorithm = crosapi::mojom::KeystoreAlgorithmName::kEcdsa;
         break;
       }
       case api::enterprise_platform_keys::Algorithm::kNone:
-        NOTREACHED_IN_MIGRATION();
+        NOTREACHED();
     }
   }
 
