@@ -4,6 +4,7 @@
 
 #include "chrome/browser/extensions/api/quick_unlock_private/quick_unlock_private_api.h"
 
+#include <algorithm>
 #include <optional>
 #include <string>
 #include <utility>
@@ -12,17 +13,15 @@
 #include "ash/constants/ash_pref_names.h"
 #include "base/containers/contains.h"
 #include "base/functional/bind.h"
-#include "base/ranges/algorithm.h"
 #include "chrome/browser/ash/login/quick_unlock/auth_token.h"
 #include "chrome/browser/ash/login/quick_unlock/pin_backend.h"
 #include "chrome/browser/ash/login/quick_unlock/quick_unlock_factory.h"
 #include "chrome/browser/ash/login/quick_unlock/quick_unlock_storage.h"
 #include "chrome/browser/ash/login/quick_unlock/quick_unlock_utils.h"
-#include "chrome/browser/ash/login/users/chrome_user_manager.h"
 #include "chrome/browser/ash/profiles/profile_helper.h"
 #include "chrome/browser/extensions/api/quick_unlock_private/quick_unlock_private_ash_utils.h"
+#include "chrome/browser/extensions/profile_util.h"
 #include "chrome/browser/profiles/profile.h"
-#include "chrome/browser/profiles/profile_manager.h"
 #include "chromeos/ash/components/browser_context_helper/browser_context_helper.h"
 #include "chromeos/ash/components/login/auth/public/authentication_error.h"
 #include "chromeos/ash/components/login/auth/public/user_context.h"
@@ -112,7 +111,7 @@ bool AreModesEqual(const QuickUnlockModeList& a, const QuickUnlockModeList& b) {
 }
 
 bool IsPinNumeric(const std::string& pin) {
-  return base::ranges::all_of(pin, ::isdigit);
+  return std::ranges::all_of(pin, ::isdigit);
 }
 
 // Reads and sanitizes the pin length policy.
@@ -197,7 +196,7 @@ Profile* GetActiveProfile(content::BrowserContext* browser_context) {
   // When OOBE continues in-session as Furst Run UI, it is still executed
   // under Sign-In profile.
   if (ash::ProfileHelper::IsSigninProfile(profile))
-    return ProfileManager::GetPrimaryUserProfile();
+    return profile_util::GetPrimaryUserProfile();
 
   return profile;
 }
@@ -258,7 +257,7 @@ QuickUnlockPrivateSetLockScreenEnabledFunction::
     : chrome_details_(this) {}
 
 QuickUnlockPrivateSetLockScreenEnabledFunction::
-    ~QuickUnlockPrivateSetLockScreenEnabledFunction() {}
+    ~QuickUnlockPrivateSetLockScreenEnabledFunction() = default;
 
 ExtensionFunction::ResponseAction
 QuickUnlockPrivateSetLockScreenEnabledFunction::Run() {
@@ -341,7 +340,9 @@ QuickUnlockPrivateCanAuthenticatePinFunction::Run() {
 }
 
 void QuickUnlockPrivateCanAuthenticatePinFunction::HandleCanAuthenticateResult(
-    bool result) {
+    bool result,
+    cryptohome::PinLockAvailability available_at) {
+  // |available_at| is ignored.
   Respond(ArgumentList(
       quick_unlock_private::CanAuthenticatePin::Results::Create(result)));
 }
@@ -353,7 +354,7 @@ QuickUnlockPrivateGetAvailableModesFunction::
     : chrome_details_(this) {}
 
 QuickUnlockPrivateGetAvailableModesFunction::
-    ~QuickUnlockPrivateGetAvailableModesFunction() {}
+    ~QuickUnlockPrivateGetAvailableModesFunction() = default;
 
 ExtensionFunction::ResponseAction
 QuickUnlockPrivateGetAvailableModesFunction::Run() {
@@ -393,10 +394,10 @@ void QuickUnlockPrivateGetActiveModesFunction::OnGetActiveModes(
 // quickUnlockPrivate.checkCredential
 
 QuickUnlockPrivateCheckCredentialFunction::
-    QuickUnlockPrivateCheckCredentialFunction() {}
+    QuickUnlockPrivateCheckCredentialFunction() = default;
 
 QuickUnlockPrivateCheckCredentialFunction::
-    ~QuickUnlockPrivateCheckCredentialFunction() {}
+    ~QuickUnlockPrivateCheckCredentialFunction() = default;
 
 ExtensionFunction::ResponseAction
 QuickUnlockPrivateCheckCredentialFunction::Run() {
@@ -442,10 +443,10 @@ QuickUnlockPrivateCheckCredentialFunction::Run() {
 }
 
 QuickUnlockPrivateGetCredentialRequirementsFunction::
-    QuickUnlockPrivateGetCredentialRequirementsFunction() {}
+    QuickUnlockPrivateGetCredentialRequirementsFunction() = default;
 
 QuickUnlockPrivateGetCredentialRequirementsFunction::
-    ~QuickUnlockPrivateGetCredentialRequirementsFunction() {}
+    ~QuickUnlockPrivateGetCredentialRequirementsFunction() = default;
 
 ExtensionFunction::ResponseAction
 QuickUnlockPrivateGetCredentialRequirementsFunction::Run() {
