@@ -16,8 +16,6 @@
 #include "chrome/common/extensions/api/scripting.h"
 #include "content/public/browser/navigation_controller.h"
 #include "content/public/browser/navigation_entry.h"
-#include "extensions/browser/api/scripting/scripting_constants.h"
-#include "extensions/browser/api/scripting/scripting_utils.h"
 #include "extensions/browser/extension_api_frame_id_map.h"
 #include "extensions/browser/extension_file_task_runner.h"
 #include "extensions/browser/extension_registry.h"
@@ -26,6 +24,8 @@
 #include "extensions/browser/extension_util.h"
 #include "extensions/browser/load_and_localize_file.h"
 #include "extensions/browser/script_executor.h"
+#include "extensions/browser/scripting_constants.h"
+#include "extensions/browser/scripting_utils.h"
 #include "extensions/browser/user_script_manager.h"
 #include "extensions/common/api/extension_types.h"
 #include "extensions/common/api/scripts_internal.h"
@@ -36,9 +36,9 @@
 #include "extensions/common/mojom/css_origin.mojom-shared.h"
 #include "extensions/common/mojom/execution_world.mojom-shared.h"
 #include "extensions/common/mojom/host_id.mojom.h"
+#include "extensions/common/mojom/match_origin_as_fallback.mojom-shared.h"
 #include "extensions/common/mojom/run_location.mojom-shared.h"
 #include "extensions/common/permissions/permissions_data.h"
-#include "extensions/common/script_constants.h"
 #include "extensions/common/user_script.h"
 #include "extensions/common/utils/content_script_utils.h"
 #include "extensions/common/utils/extension_types_utils.h"
@@ -47,9 +47,6 @@ namespace extensions {
 
 namespace {
 
-constexpr char kCouldNotLoadFileError[] = "Could not load file: '*'.";
-constexpr char kDuplicateFileSpecifiedError[] =
-    "Duplicate file specified: '*'.";
 constexpr char kEmptyMatchesError[] =
     "Script with ID '*' must specify 'matches'.";
 constexpr char kExactlyOneOfCssAndFilesError[] =
@@ -92,6 +89,17 @@ mojom::ExecutionWorld ConvertExecutionWorld(
   return execution_world;
 }
 
+scripting::InjectionTarget ConvertToInternalInjectionTarget(
+    api::scripting::InjectionTarget injection_target) {
+  scripting::InjectionTarget internal_injection_target;
+  internal_injection_target.all_frames = injection_target.all_frames;
+  internal_injection_target.document_ids =
+      std::move(injection_target.document_ids);
+  internal_injection_target.frame_ids = std::move(injection_target.frame_ids);
+  internal_injection_target.tab_id = std::move(injection_target.tab_id);
+  return internal_injection_target;
+}
+
 std::string InjectionKeyForCode(const mojom::HostID& host_id,
                                 const std::string& code) {
   return ScriptExecutor::GenerateInjectionKey(host_id, /*script_url=*/GURL(),
@@ -104,25 +112,9 @@ std::string InjectionKeyForFile(const mojom::HostID& host_id,
                                               /*code=*/std::string());
 }
 
-// Constructs an array of file sources from the read file `data`.
-std::vector<InjectedFileSource> ConstructFileSources(
-    std::vector<std::unique_ptr<std::string>> data,
-    std::vector<std::string> file_names) {
-  // Note: CHECK (and not DCHECK) because if it fails, we have an out-of-bounds
-  // access.
-  CHECK_EQ(data.size(), file_names.size());
-  const size_t num_sources = data.size();
-  std::vector<InjectedFileSource> sources;
-  sources.reserve(num_sources);
-  for (size_t i = 0; i < num_sources; ++i)
-    sources.emplace_back(std::move(file_names[i]), std::move(data[i]));
-
-  return sources;
-}
-
 std::vector<mojom::JSSourcePtr> FileSourcesToJSSources(
     const Extension& extension,
-    std::vector<InjectedFileSource> file_sources) {
+    std::vector<scripting::InjectedFileSource> file_sources) {
   std::vector<mojom::JSSourcePtr> js_sources;
   js_sources.reserve(file_sources.size());
   for (auto& file_source : file_sources) {
@@ -136,7 +128,7 @@ std::vector<mojom::JSSourcePtr> FileSourcesToJSSources(
 
 std::vector<mojom::CSSSourcePtr> FileSourcesToCSSSources(
     const Extension& extension,
-    std::vector<InjectedFileSource> file_sources) {
+    std::vector<scripting::InjectedFileSource> file_sources) {
   mojom::HostID host_id(mojom::HostID::HostType::kExtensions, extension.id());
 
   std::vector<mojom::CSSSourcePtr> css_sources;
@@ -151,297 +143,6 @@ std::vector<mojom::CSSSourcePtr> FileSourcesToCSSSources(
   return css_sources;
 }
 
-// Checks `files` and populates `resources_out` with the appropriate extension
-// resource. Returns true on success; on failure, populates `error_out`.
-bool GetFileResources(const std::vector<std::string>& files,
-                      const Extension& extension,
-                      std::vector<ExtensionResource>* resources_out,
-                      std::string* error_out) {
-  if (files.empty()) {
-    static constexpr char kAtLeastOneFileError[] =
-        "At least one file must be specified.";
-    *error_out = kAtLeastOneFileError;
-    return false;
-  }
-
-  std::vector<ExtensionResource> resources;
-  for (const auto& file : files) {
-    ExtensionResource resource = extension.GetResource(file);
-    if (resource.extension_root().empty() || resource.relative_path().empty()) {
-      *error_out = ErrorUtils::FormatErrorMessage(kCouldNotLoadFileError, file);
-      return false;
-    }
-
-    // ExtensionResource doesn't implement an operator==.
-    if (base::Contains(resources, resource.relative_path(),
-                       &ExtensionResource::relative_path)) {
-      // Disallow duplicates. Note that we could allow this, if we wanted (and
-      // there *might* be reason to with JS injection, to perform an operation
-      // twice?). However, this matches content script behavior, and injecting
-      // twice can be done by chaining calls to executeScript() / insertCSS().
-      // This isn't a robust check, and could probably be circumvented by
-      // passing two paths that look different but are the same - but in that
-      // case, we just try to load and inject the script twice, which is
-      // inefficient, but safe.
-      *error_out =
-          ErrorUtils::FormatErrorMessage(kDuplicateFileSpecifiedError, file);
-      return false;
-    }
-
-    resources.push_back(std::move(resource));
-  }
-
-  resources_out->swap(resources);
-  return true;
-}
-
-using ResourcesLoadedCallback =
-    base::OnceCallback<void(std::vector<InjectedFileSource>,
-                            std::optional<std::string>)>;
-
-// Checks the loaded content of extension resources. Invokes `callback` with
-// the constructed file sources on success or with an error on failure.
-void CheckLoadedResources(std::vector<std::string> file_names,
-                          ResourcesLoadedCallback callback,
-                          std::vector<std::unique_ptr<std::string>> file_data,
-                          std::optional<std::string> load_error) {
-  if (load_error) {
-    std::move(callback).Run({}, std::move(load_error));
-    return;
-  }
-
-  std::vector<InjectedFileSource> file_sources =
-      ConstructFileSources(std::move(file_data), std::move(file_names));
-
-  for (const auto& source : file_sources) {
-    DCHECK(source.data);
-    // TODO(devlin): What necessitates this encoding requirement? Is it needed
-    // for blink injection?
-    if (!base::IsStringUTF8(*source.data)) {
-      static constexpr char kBadFileEncodingError[] =
-          "Could not load file '*'. It isn't UTF-8 encoded.";
-      std::string error = ErrorUtils::FormatErrorMessage(kBadFileEncodingError,
-                                                         source.file_name);
-      std::move(callback).Run({}, std::move(error));
-      return;
-    }
-  }
-
-  std::move(callback).Run(std::move(file_sources), std::nullopt);
-}
-
-// Checks the specified `files` for validity, and attempts to load and localize
-// them, invoking `callback` with the result. Returns true on success; on
-// failure, populates `error`.
-bool CheckAndLoadFiles(std::vector<std::string> files,
-                       const Extension& extension,
-                       bool requires_localization,
-                       ResourcesLoadedCallback callback,
-                       std::string* error) {
-  std::vector<ExtensionResource> resources;
-  if (!GetFileResources(files, extension, &resources, error))
-    return false;
-
-  LoadAndLocalizeResources(
-      extension, resources, requires_localization,
-      script_parsing::GetMaxScriptLength(),
-      base::BindOnce(&CheckLoadedResources, std::move(files),
-                     std::move(callback)));
-  return true;
-}
-
-// Returns an error message string for when an extension cannot access a page it
-// is attempting to.
-std::string GetCannotAccessPageErrorMessage(const PermissionsData& permissions,
-                                            const GURL& url) {
-  if (permissions.HasAPIPermission(mojom::APIPermissionID::kTab)) {
-    return ErrorUtils::FormatErrorMessage(
-        manifest_errors::kCannotAccessPageWithUrl, url.spec());
-  }
-  return manifest_errors::kCannotAccessPage;
-}
-
-// Returns true if the `permissions` allow for injection into the given `frame`.
-// If false, populates `error`.
-bool HasPermissionToInjectIntoFrame(const PermissionsData& permissions,
-                                    int tab_id,
-                                    content::RenderFrameHost* frame,
-                                    std::string* error) {
-  GURL committed_url = frame->GetLastCommittedURL();
-  if (committed_url.is_empty()) {
-    if (!frame->IsInPrimaryMainFrame()) {
-      // We can't check the pending URL for subframes from the //chrome layer.
-      // Assume the injection is allowed; the renderer has additional checks
-      // later on.
-      return true;
-    }
-    // Unknown URL, e.g. because no load was committed yet. In this case we look
-    // for any pending entry on the NavigationController associated with the
-    // WebContents for the frame.
-    content::WebContents* web_contents =
-        content::WebContents::FromRenderFrameHost(frame);
-    content::NavigationEntry* pending_entry =
-        web_contents->GetController().GetPendingEntry();
-    if (!pending_entry) {
-      *error = manifest_errors::kCannotAccessPage;
-      return false;
-    }
-    GURL pending_url = pending_entry->GetURL();
-    if (pending_url.SchemeIsHTTPOrHTTPS() &&
-        !permissions.CanAccessPage(pending_url, tab_id, error)) {
-      // This catches the majority of cases where an extension tried to inject
-      // on a newly-created navigating tab, saving us a potentially-costly IPC
-      // and, maybe, slightly reducing (but not by any stretch eliminating) an
-      // attack surface.
-      *error = GetCannotAccessPageErrorMessage(permissions, pending_url);
-      return false;
-    }
-
-    // Otherwise allow for now. The renderer has additional checks and will
-    // fail the injection if needed.
-    return true;
-  }
-
-  // TODO(devlin): Add more schemes here, in line with
-  // https://crbug.com/55084.
-  if (committed_url.SchemeIs(url::kAboutScheme) ||
-      committed_url.SchemeIs(url::kDataScheme)) {
-    url::Origin origin = frame->GetLastCommittedOrigin();
-    const url::SchemeHostPort& tuple_or_precursor_tuple =
-        origin.GetTupleOrPrecursorTupleIfOpaque();
-    if (!tuple_or_precursor_tuple.IsValid()) {
-      *error = GetCannotAccessPageErrorMessage(permissions, committed_url);
-      return false;
-    }
-
-    committed_url = tuple_or_precursor_tuple.GetURL();
-  }
-
-  return permissions.CanAccessPage(committed_url, tab_id, error);
-}
-
-// Collects the frames for injection. Method will return false if an error is
-// encountered.
-bool CollectFramesForInjection(const api::scripting::InjectionTarget& target,
-                               content::WebContents* tab,
-                               std::set<int>& frame_ids,
-                               std::set<content::RenderFrameHost*>& frames,
-                               std::string* error_out) {
-  if (target.document_ids) {
-    for (const auto& id : *target.document_ids) {
-      ExtensionApiFrameIdMap::DocumentId document_id =
-          ExtensionApiFrameIdMap::DocumentIdFromString(id);
-
-      if (!document_id) {
-        *error_out = base::StringPrintf("Invalid document id %s", id.c_str());
-        return false;
-      }
-
-      content::RenderFrameHost* frame =
-          ExtensionApiFrameIdMap::Get()->GetRenderFrameHostByDocumentId(
-              document_id);
-
-      // If the frame was not found or it matched another tab reject this
-      // request.
-      if (!frame || content::WebContents::FromRenderFrameHost(frame) != tab) {
-        *error_out =
-            base::StringPrintf("No document with id %s in tab with id %d",
-                               id.c_str(), target.tab_id);
-        return false;
-      }
-
-      // Convert the documentId into a frameId since the content will be
-      // injected synchronously.
-      frame_ids.insert(ExtensionApiFrameIdMap::GetFrameId(frame));
-      frames.insert(frame);
-    }
-  } else {
-    if (target.frame_ids) {
-      frame_ids.insert(target.frame_ids->begin(), target.frame_ids->end());
-    } else {
-      frame_ids.insert(ExtensionApiFrameIdMap::kTopFrameId);
-    }
-
-    for (int frame_id : frame_ids) {
-      content::RenderFrameHost* frame =
-          ExtensionApiFrameIdMap::GetRenderFrameHostById(tab, frame_id);
-      if (!frame) {
-        *error_out = base::StringPrintf("No frame with id %d in tab with id %d",
-                                        frame_id, target.tab_id);
-        return false;
-      }
-      frames.insert(frame);
-    }
-  }
-  return true;
-}
-
-// Returns true if the `target` can be accessed with the given `permissions`.
-// If the target can be accessed, populates `script_executor_out`,
-// `frame_scope_out`, and `frame_ids_out` with the appropriate values;
-// if the target cannot be accessed, populates `error_out`.
-bool CanAccessTarget(const PermissionsData& permissions,
-                     const api::scripting::InjectionTarget& target,
-                     content::BrowserContext* browser_context,
-                     bool include_incognito_information,
-                     ScriptExecutor** script_executor_out,
-                     ScriptExecutor::FrameScope* frame_scope_out,
-                     std::set<int>* frame_ids_out,
-                     std::string* error_out) {
-  content::WebContents* tab = nullptr;
-  TabHelper* tab_helper = nullptr;
-  if (!ExtensionTabUtil::GetTabById(target.tab_id, browser_context,
-                                    include_incognito_information, &tab) ||
-      !(tab_helper = TabHelper::FromWebContents(tab))) {
-    // TODO(devlin): Add a constant for this in a centrally-consumable location.
-    *error_out = base::StringPrintf("No tab with id: %d", target.tab_id);
-    return false;
-  }
-
-  if ((target.all_frames && *target.all_frames == true) &&
-      (target.frame_ids || target.document_ids)) {
-    *error_out =
-        "Cannot specify 'allFrames' if either 'frameIds' or 'documentIds' is "
-        "specified.";
-    return false;
-  }
-
-  if (target.frame_ids && target.document_ids) {
-    *error_out = "Cannot specify both 'frameIds' and 'documentIds'.";
-    return false;
-  }
-
-  ScriptExecutor* script_executor = tab_helper->script_executor();
-  DCHECK(script_executor);
-
-  ScriptExecutor::FrameScope frame_scope =
-      target.all_frames && *target.all_frames == true
-          ? ScriptExecutor::INCLUDE_SUB_FRAMES
-          : ScriptExecutor::SPECIFIED_FRAMES;
-
-  std::set<int> frame_ids;
-  std::set<content::RenderFrameHost*> frames;
-  if (!CollectFramesForInjection(target, tab, frame_ids, frames, error_out))
-    return false;
-
-  // TODO(devlin): If `allFrames` is true, we error out if the extension
-  // doesn't have access to the top frame (even if it may inject in child
-  // frames). This is inconsistent with content scripts (which can execute on
-  // child frames), but consistent with the old tabs.executeScript() API.
-  for (content::RenderFrameHost* frame : frames) {
-    DCHECK_EQ(content::WebContents::FromRenderFrameHost(frame), tab);
-    if (!HasPermissionToInjectIntoFrame(permissions, target.tab_id, frame,
-                                        error_out)) {
-      return false;
-    }
-  }
-
-  *frame_ids_out = std::move(frame_ids);
-  *frame_scope_out = frame_scope;
-  *script_executor_out = script_executor;
-  return true;
-}
-
 api::scripts_internal::SerializedUserScript
 ConvertRegisteredContentScriptToSerializedUserScript(
     api::scripting::RegisteredContentScript content_script) {
@@ -529,13 +230,12 @@ api::scripting::RegisteredContentScript CreateRegisteredContentScriptInfo(
       [](api::extension_types::ExecutionWorld world) {
         switch (world) {
           case api::extension_types::ExecutionWorld::kNone:
-            NOTREACHED_NORETURN()
+            NOTREACHED()
                 << "Execution world should always be present in serialization.";
           case api::extension_types::ExecutionWorld::kIsolated:
             return api::scripting::ExecutionWorld::kIsolated;
           case api::extension_types::ExecutionWorld::kUserScript:
-            NOTREACHED_NORETURN()
-                << "ISOLATED worlds are not supported in this API.";
+            NOTREACHED() << "ISOLATED worlds are not supported in this API.";
           case api::extension_types::ExecutionWorld::kMain:
             return api::scripting::ExecutionWorld::kMain;
         }
@@ -564,12 +264,6 @@ api::scripting::RegisteredContentScript CreateRegisteredContentScriptInfo(
 
 }  // namespace
 
-InjectedFileSource::InjectedFileSource(std::string file_name,
-                                       std::unique_ptr<std::string> data)
-    : file_name(std::move(file_name)), data(std::move(data)) {}
-InjectedFileSource::InjectedFileSource(InjectedFileSource&&) = default;
-InjectedFileSource::~InjectedFileSource() = default;
-
 ScriptingExecuteScriptFunction::ScriptingExecuteScriptFunction() = default;
 ScriptingExecuteScriptFunction::~ScriptingExecuteScriptFunction() = default;
 
@@ -604,7 +298,9 @@ ExtensionFunction::ResponseAction ScriptingExecuteScriptFunction::Run() {
     constexpr bool kRequiresLocalization = false;
     std::string error;
     if (!CheckAndLoadFiles(
-            std::move(*injection_.files), *extension(), kRequiresLocalization,
+            std::move(*injection_.files),
+            script_parsing::ContentScriptType::kJs, *extension(),
+            kRequiresLocalization,
             base::BindOnce(&ScriptingExecuteScriptFunction::DidLoadResources,
                            this),
             &error)) {
@@ -645,7 +341,7 @@ ExtensionFunction::ResponseAction ScriptingExecuteScriptFunction::Run() {
 }
 
 void ScriptingExecuteScriptFunction::DidLoadResources(
-    std::vector<InjectedFileSource> file_sources,
+    std::vector<scripting::InjectedFileSource> file_sources,
     std::optional<std::string> load_error) {
   if (load_error) {
     Respond(Error(std::move(*load_error)));
@@ -664,39 +360,28 @@ void ScriptingExecuteScriptFunction::DidLoadResources(
 bool ScriptingExecuteScriptFunction::Execute(
     std::vector<mojom::JSSourcePtr> sources,
     std::string* error) {
+  scripting::InjectionTarget internal_injection_target =
+      ConvertToInternalInjectionTarget(std::move(injection_.target));
   ScriptExecutor* script_executor = nullptr;
   ScriptExecutor::FrameScope frame_scope = ScriptExecutor::SPECIFIED_FRAMES;
   std::set<int> frame_ids;
-  if (!CanAccessTarget(*extension()->permissions_data(), injection_.target,
-                       browser_context(), include_incognito_information(),
-                       &script_executor, &frame_scope, &frame_ids, error)) {
+  if (!scripting::CanAccessTarget(
+          *extension()->permissions_data(), internal_injection_target,
+          browser_context(), include_incognito_information(), &script_executor,
+          &frame_scope, &frame_ids, error)) {
     return false;
   }
 
   mojom::ExecutionWorld execution_world =
       ConvertExecutionWorld(injection_.world);
+  // scripting.executeScript() doesn't support selecting execution world id.
+  std::optional<std::string> execution_world_id = std::nullopt;
+  bool inject_immediately = injection_.inject_immediately.value_or(false);
 
-  // Extensions can specify that the script should be injected "immediately".
-  // In this case, we specify kDocumentStart as the injection time. Due to
-  // inherent raciness between tab creation and load and this function
-  // execution, there is no guarantee that it will actually happen at
-  // document start, but the renderer will appropriately inject it
-  // immediately if document start has already passed.
-  mojom::RunLocation run_location =
-      injection_.inject_immediately && *injection_.inject_immediately
-          ? mojom::RunLocation::kDocumentStart
-          : mojom::RunLocation::kDocumentIdle;
-  script_executor->ExecuteScript(
-      mojom::HostID(mojom::HostID::HostType::kExtensions, extension()->id()),
-      mojom::CodeInjection::NewJs(mojom::JSInjection::New(
-          std::move(sources), execution_world,
-          blink::mojom::WantResultOption::kWantResult,
-          user_gesture() ? blink::mojom::UserActivationOption::kActivate
-                         : blink::mojom::UserActivationOption::kDoNotActivate,
-          blink::mojom::PromiseResultOption::kAwait)),
-      frame_scope, frame_ids, ScriptExecutor::MATCH_ABOUT_BLANK, run_location,
-      ScriptExecutor::DEFAULT_PROCESS,
-      /* webview_src */ GURL(),
+  scripting::ExecuteScript(
+      extension()->id(), std::move(sources), execution_world,
+      execution_world_id, script_executor, frame_scope, frame_ids,
+      inject_immediately, user_gesture(),
       base::BindOnce(&ScriptingExecuteScriptFunction::OnScriptExecuted, this));
 
   return true;
@@ -757,7 +442,9 @@ ExtensionFunction::ResponseAction ScriptingInsertCSSFunction::Run() {
     constexpr bool kRequiresLocalization = true;
     std::string error;
     if (!CheckAndLoadFiles(
-            std::move(*injection_.files), *extension(), kRequiresLocalization,
+            std::move(*injection_.files),
+            script_parsing::ContentScriptType::kCss, *extension(),
+            kRequiresLocalization,
             base::BindOnce(&ScriptingInsertCSSFunction::DidLoadResources, this),
             &error)) {
       return RespondNow(Error(std::move(error)));
@@ -784,7 +471,7 @@ ExtensionFunction::ResponseAction ScriptingInsertCSSFunction::Run() {
 }
 
 void ScriptingInsertCSSFunction::DidLoadResources(
-    std::vector<InjectedFileSource> file_sources,
+    std::vector<scripting::InjectedFileSource> file_sources,
     std::optional<std::string> load_error) {
   if (load_error) {
     Respond(Error(std::move(*load_error)));
@@ -803,12 +490,15 @@ void ScriptingInsertCSSFunction::DidLoadResources(
 bool ScriptingInsertCSSFunction::Execute(
     std::vector<mojom::CSSSourcePtr> sources,
     std::string* error) {
+  scripting::InjectionTarget internal_injection_target =
+      ConvertToInternalInjectionTarget(std::move(injection_.target));
   ScriptExecutor* script_executor = nullptr;
   ScriptExecutor::FrameScope frame_scope = ScriptExecutor::SPECIFIED_FRAMES;
   std::set<int> frame_ids;
-  if (!CanAccessTarget(*extension()->permissions_data(), injection_.target,
-                       browser_context(), include_incognito_information(),
-                       &script_executor, &frame_scope, &frame_ids, error)) {
+  if (!scripting::CanAccessTarget(
+          *extension()->permissions_data(), internal_injection_target,
+          browser_context(), include_incognito_information(), &script_executor,
+          &frame_scope, &frame_ids, error)) {
     return false;
   }
   DCHECK(script_executor);
@@ -818,7 +508,7 @@ bool ScriptingInsertCSSFunction::Execute(
       mojom::CodeInjection::NewCss(mojom::CSSInjection::New(
           std::move(sources), ConvertStyleOriginToCSSOrigin(injection_.origin),
           mojom::CSSInjection::Operation::kAdd)),
-      frame_scope, frame_ids, ScriptExecutor::MATCH_ABOUT_BLANK,
+      frame_scope, frame_ids, mojom::MatchOriginAsFallbackBehavior::kAlways,
       kCSSRunLocation, ScriptExecutor::DEFAULT_PROCESS,
       /* webview_src */ GURL(),
       base::BindOnce(&ScriptingInsertCSSFunction::OnCSSInserted, this));
@@ -853,13 +543,16 @@ ExtensionFunction::ResponseAction ScriptingRemoveCSSFunction::Run() {
     return RespondNow(Error(kExactlyOneOfCssAndFilesError));
   }
 
+  scripting::InjectionTarget internal_injection_target =
+      ConvertToInternalInjectionTarget(std::move(injection.target));
   ScriptExecutor* script_executor = nullptr;
   ScriptExecutor::FrameScope frame_scope = ScriptExecutor::SPECIFIED_FRAMES;
   std::set<int> frame_ids;
   std::string error;
-  if (!CanAccessTarget(*extension()->permissions_data(), injection.target,
-                       browser_context(), include_incognito_information(),
-                       &script_executor, &frame_scope, &frame_ids, &error)) {
+  if (!scripting::CanAccessTarget(
+          *extension()->permissions_data(), internal_injection_target,
+          browser_context(), include_incognito_information(), &script_executor,
+          &frame_scope, &frame_ids, &error)) {
     return RespondNow(Error(std::move(error)));
   }
   DCHECK(script_executor);
@@ -870,8 +563,11 @@ ExtensionFunction::ResponseAction ScriptingRemoveCSSFunction::Run() {
 
   if (injection.files) {
     std::vector<ExtensionResource> resources;
-    if (!GetFileResources(*injection.files, *extension(), &resources, &error))
+    if (!scripting::GetFileResources(*injection.files,
+                                     script_parsing::ContentScriptType::kCss,
+                                     *extension(), &resources, &error)) {
       return RespondNow(Error(std::move(error)));
+    }
 
     // Note: Since we're just removing the CSS, we don't actually need to load
     // the file here. It's okay for `code` to be empty in this case.
@@ -895,7 +591,7 @@ ExtensionFunction::ResponseAction ScriptingRemoveCSSFunction::Run() {
       mojom::CodeInjection::NewCss(mojom::CSSInjection::New(
           std::move(sources), ConvertStyleOriginToCSSOrigin(injection.origin),
           mojom::CSSInjection::Operation::kRemove)),
-      frame_scope, frame_ids, ScriptExecutor::MATCH_ABOUT_BLANK,
+      frame_scope, frame_ids, mojom::MatchOriginAsFallbackBehavior::kAlways,
       kCSSRunLocation, ScriptExecutor::DEFAULT_PROCESS,
       /* webview_src */ GURL(),
       base::BindOnce(&ScriptingRemoveCSSFunction::OnCSSRemoved, this));
@@ -1122,8 +818,8 @@ ScriptingUnregisterContentScriptsFunction::Run() {
 
   std::optional<api::scripting::ContentScriptFilter>& filter = params->filter;
   std::optional<std::vector<std::string>> ids = std::nullopt;
-  // TODO(crbug.com/1300657): `ids` should have an empty list when filter ids is
-  // empty, instead of a nullopt. Otherwise, we are incorrectly removing all
+  // TODO(crbug.com/40216362): `ids` should have an empty list when filter ids
+  // is empty, instead of a nullopt. Otherwise, we are incorrectly removing all
   // content scripts when ids is empty.
   if (filter && filter->ids && !filter->ids->empty()) {
     ids = std::move(filter->ids);
