@@ -15,7 +15,6 @@
 #include "base/strings/string_split.h"
 #include "base/strings/stringprintf.h"
 #include "base/test/scoped_command_line.h"
-#include "base/test/scoped_feature_list.h"
 #include "build/build_config.h"
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/extensions/api/webrtc_logging_private/webrtc_logging_private_api.h"
@@ -417,7 +416,6 @@ class WebrtcLoggingPrivateApiTest : public extensions::ExtensionApiTest {
     }
   }
 
-  base::test::ScopedFeatureList scoped_feature_list_;
   base::test::ScopedCommandLine scoped_command_line_;
   scoped_refptr<const Extension> extension_;
 
@@ -681,26 +679,6 @@ class WebrtcLoggingPrivateApiStartEventLoggingTestBase
   ~WebrtcLoggingPrivateApiStartEventLoggingTestBase() override = default;
 
  protected:
-  void SetUp() override {
-    SetUpFeatures();
-    WebrtcLoggingPrivateApiTest::SetUp();
-  }
-
-  void SetUpFeatures() {
-    std::vector<base::test::FeatureRef> enabled;
-    std::vector<base::test::FeatureRef> disabled;
-
-    if (WebRtcEventLogCollectionFeature()) {
-      enabled.push_back(features::kWebRtcRemoteEventLog);
-    } else {
-      disabled.push_back(features::kWebRtcRemoteEventLog);
-    }
-
-    enabled.push_back(features::kWebRtcRemoteEventLogGzipped);
-
-    scoped_feature_list_.InitWithFeatures(enabled, disabled);
-  }
-
   void SetUpInProcessBrowserTestFixture() override {
     provider_.SetDefaultReturns(
         /*is_initialization_complete_return=*/true,
@@ -717,10 +695,6 @@ class WebrtcLoggingPrivateApiStartEventLoggingTestBase
     provider_.UpdateChromePolicy(values);
   }
 
-  // Whether the test should have WebRTC remote-bound event logging generally
-  // enabled (default behavior), or disabled (Finch kill-switch engaged).
-  virtual bool WebRtcEventLogCollectionFeature() const = 0;
-
   // Whether the test should simulate running on a user profile which
   // has the kWebRtcEventLogCollectionAllowed policy configured or not.
   virtual bool WebRtcEventLogCollectionPolicy() const = 0;
@@ -729,24 +703,21 @@ class WebrtcLoggingPrivateApiStartEventLoggingTestBase
   testing::NiceMock<policy::MockConfigurationPolicyProvider> provider_;
 };
 
-// Test StartEventLogging's behavior when the feature is active (kill-switch
-// from Finch *not* engaged, working in a profile where the policy is
-// configured).
-class WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled
+// Test StartEventLogging's behavior when the feature is active (non-Android,
+// working in a profile where the policy is configured).
+class WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled
     : public WebrtcLoggingPrivateApiStartEventLoggingTestBase,
       public testing::WithParamInterface<bool> {
  public:
-  ~WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled()
-      override = default;
-
-  bool WebRtcEventLogCollectionFeature() const override { return true; }
+  ~WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled() override =
+      default;
 
   bool WebRtcEventLogCollectionPolicy() const override { return true; }
 };
 
 // Also covers StartEventLoggingForLegalWebAppIdSucceeds scenario.
 IN_PROC_BROWSER_TEST_P(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingForKnownPeerConnectionSucceeds) {
   const std::string session_id = "id";
   SetUpPeerConnection(session_id);
@@ -758,7 +729,7 @@ IN_PROC_BROWSER_TEST_P(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingWithUnlimitedSizeFails) {
   const std::string session_id = "id";
   SetUpPeerConnection(session_id);
@@ -771,7 +742,7 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingWithTooSmallMaxSize) {
   const std::string session_id = "id";
   SetUpPeerConnection(session_id);
@@ -783,7 +754,7 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingWithExcessiveMaxSizeFails) {
   const std::string session_id = "id";
   SetUpPeerConnection(session_id);
@@ -795,7 +766,7 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingWithTooLargeOutputPeriodMsFails) {
   const std::string session_id = "id";
   SetUpPeerConnection(session_id);
@@ -808,7 +779,7 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingForNeverAddedPeerConnectionFails) {
   // Note that manager->OnPeerConnectionAdded() is not called.
   const std::string session_id = "id";
@@ -821,7 +792,7 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingForWrongSessionIdFails) {
   const std::string session_id_1 = "id1";
   const std::string session_id_2 = "id2";
@@ -836,7 +807,7 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingIfSessionIdNeverSetFails) {
   SetUpPeerConnection();  // Note lack of session ID.
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
@@ -848,7 +819,7 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingIfSessionIdNeverSetFailsForEmptySessionId) {
   SetUpPeerConnection();  // Note lack of session ID.
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
@@ -860,7 +831,7 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLogginWithEmptySessionIdFails) {
   SetUpPeerConnection("session_id");
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
@@ -872,7 +843,7 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingForAlreadyLoggedPeerConnectionFails) {
   const std::string session_id = "id";
   SetUpPeerConnection(session_id);
@@ -895,7 +866,7 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingForTooLowWebAppIdFails) {
   const std::string session_id = "id";
   SetUpPeerConnection(session_id);
@@ -911,7 +882,7 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingForTooHighWebAppIdFails) {
   const std::string session_id = "id";
   SetUpPeerConnection(session_id);
@@ -928,50 +899,43 @@ IN_PROC_BROWSER_TEST_F(
 
 INSTANTIATE_TEST_SUITE_P(
     _,
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     ::testing::Bool());
 
-// Testing with either the feature or the policy disabled (not both).
-class WebrtcLoggingPrivateApiStartEventLoggingTestFeatureOrPolicyDisabled
+// Testing with the policy enabled/disabled.
+class WebrtcLoggingPrivateApiStartEventLoggingTestPolicy
     : public WebrtcLoggingPrivateApiStartEventLoggingTestBase,
       public ::testing::WithParamInterface<bool> {
  public:
-  WebrtcLoggingPrivateApiStartEventLoggingTestFeatureOrPolicyDisabled()
-      : feature_enabled_(GetParam()), policy_enabled_(!feature_enabled_) {}
+  WebrtcLoggingPrivateApiStartEventLoggingTestPolicy()
+      : policy_enabled_(GetParam()) {}
 
-  ~WebrtcLoggingPrivateApiStartEventLoggingTestFeatureOrPolicyDisabled()
-      override = default;
+  ~WebrtcLoggingPrivateApiStartEventLoggingTestPolicy() override = default;
 
  protected:
-  bool WebRtcEventLogCollectionFeature() const override {
-    return feature_enabled_;
-  }
-
   bool WebRtcEventLogCollectionPolicy() const override {
     return policy_enabled_;
   }
 
  private:
-  const bool feature_enabled_;
   const bool policy_enabled_;
 };
 
-IN_PROC_BROWSER_TEST_P(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureOrPolicyDisabled,
-    StartEventLoggingFails) {
+IN_PROC_BROWSER_TEST_P(WebrtcLoggingPrivateApiStartEventLoggingTestPolicy,
+                       StartEventLogging) {
   const std::string session_id = "id";
   SetUpPeerConnection(session_id);
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
-  constexpr bool expect_success = false;
-  const std::string error_message = kStartRemoteLoggingFailureFeatureDisabled;
+  bool expect_success = WebRtcEventLogCollectionPolicy();
+  const std::string error_message =
+      expect_success ? "" : kStartRemoteLoggingFailureFeatureDisabled;
   StartEventLogging(session_id, max_size_bytes, 0, kWebAppId, expect_success,
                     error_message);
 }
 
-INSTANTIATE_TEST_SUITE_P(
-    FeatureEnabled,
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureOrPolicyDisabled,
-    ::testing::Bool());
+INSTANTIATE_TEST_SUITE_P(PolicyEnabled,
+                         WebrtcLoggingPrivateApiStartEventLoggingTestPolicy,
+                         ::testing::Bool());
 
 // Make sure that, even if both the feature and the policy enable remote-bound
 // event logging, it will be blocked for incognito sessions.
@@ -989,8 +953,6 @@ class WebrtcLoggingPrivateApiStartEventLoggingTestInIncognitoMode
     return browser_;
   }
 
-  bool WebRtcEventLogCollectionFeature() const override { return true; }
-
   bool WebRtcEventLogCollectionPolicy() const override { return true; }
 
  private:
