@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -7,7 +7,7 @@
 #include <memory>
 #include <utility>
 
-#include "base/bind.h"
+#include "base/functional/bind.h"
 #include "chrome/browser/extensions/api/tab_capture/tab_capture_registry.h"
 #include "chrome/browser/media/webrtc/capture_policy_utils.h"
 #include "chrome/browser/media/webrtc/media_capture_devices_dispatcher.h"
@@ -22,6 +22,7 @@
 #include "content/public/browser/web_contents_media_capture_id.h"
 #include "extensions/common/permissions/permissions_data.h"
 #include "third_party/blink/public/mojom/mediastream/media_stream.mojom-shared.h"
+#include "third_party/blink/public/mojom/mediastream/media_stream.mojom.h"
 
 #if BUILDFLAG(IS_CHROMEOS)
 #include "chrome/browser/chromeos/policy/dlp/dlp_content_manager.h"
@@ -69,26 +70,26 @@ std::unique_ptr<content::MediaStreamUI> GetMediaStreamUI(
     const content::MediaStreamRequest& request,
     content::WebContents* web_contents,
     std::unique_ptr<MediaStreamUI> media_ui,
-    blink::MediaStreamDevices* out_devices) {
+    blink::mojom::StreamDevices& out_devices) {
   if (request.audio_type ==
       blink::mojom::MediaStreamType::GUM_TAB_AUDIO_CAPTURE) {
-    out_devices->emplace_back(blink::MediaStreamDevice(
+    out_devices.audio_device = blink::MediaStreamDevice(
         blink::mojom::MediaStreamType::GUM_TAB_AUDIO_CAPTURE,
         /*id=*/std::string(),
-        /*name=*/std::string()));
+        /*name=*/std::string());
   }
 
   if (request.video_type ==
       blink::mojom::MediaStreamType::GUM_TAB_VIDEO_CAPTURE) {
-    out_devices->emplace_back(blink::MediaStreamDevice(
+    out_devices.video_device = blink::MediaStreamDevice(
         blink::mojom::MediaStreamType::GUM_TAB_VIDEO_CAPTURE,
         /*id=*/std::string(),
-        /*name=*/std::string()));
+        /*name=*/std::string());
   }
 
   return MediaCaptureDevicesDispatcher::GetInstance()
       ->GetMediaStreamCaptureIndicator()
-      ->RegisterMediaStream(web_contents, *out_devices, std::move(media_ui));
+      ->RegisterMediaStream(web_contents, out_devices, std::move(media_ui));
 }
 
 }  // namespace
@@ -98,7 +99,7 @@ TabCaptureAccessHandler::TabCaptureAccessHandler() = default;
 TabCaptureAccessHandler::~TabCaptureAccessHandler() = default;
 
 bool TabCaptureAccessHandler::SupportsStreamType(
-    content::WebContents* web_contents,
+    content::RenderFrameHost* render_frame_host,
     const blink::mojom::MediaStreamType type,
     const extensions::Extension* extension) {
   return type == blink::mojom::MediaStreamType::GUM_TAB_VIDEO_CAPTURE ||
@@ -107,7 +108,7 @@ bool TabCaptureAccessHandler::SupportsStreamType(
 
 bool TabCaptureAccessHandler::CheckMediaAccessPermission(
     content::RenderFrameHost* render_frame_host,
-    const GURL& security_origin,
+    const url::Origin& security_origin,
     blink::mojom::MediaStreamType type,
     const extensions::Extension* extension) {
   return false;
@@ -126,10 +127,6 @@ void TabCaptureAccessHandler::HandleRequest(
       extensions::TabCaptureRegistry::Get(profile);
   if (!tab_capture_registry) {
     NOTREACHED();
-    std::move(callback).Run(
-        blink::MediaStreamDevices(),
-        blink::mojom::MediaStreamRequestResult::INVALID_STATE, /*ui=*/nullptr);
-    return;
   }
 
   AllowedScreenCaptureLevel capture_level =
@@ -145,7 +142,7 @@ void TabCaptureAccessHandler::HandleRequest(
                                            request.render_frame_id));
   if (!can_show_web_contents.Run(target_web_contents)) {
     std::move(callback).Run(
-        blink::MediaStreamDevices(),
+        blink::mojom::StreamDevicesSet(),
         blink::mojom::MediaStreamRequestResult::PERMISSION_DENIED,
         /*ui=*/nullptr);
     return;
@@ -153,12 +150,12 @@ void TabCaptureAccessHandler::HandleRequest(
 
   // |extension| may be null if the tabCapture starts with
   // tabCapture.getMediaStreamId().
-  // TODO(crbug.com/831722): Deprecate tabCaptureRegistry soon.
+  // TODO(crbug.com/40571241): Deprecate tabCaptureRegistry soon.
   const std::string extension_id = extension ? extension->id() : "";
   if (!tab_capture_registry->VerifyRequest(
           request.render_process_id, request.render_frame_id, extension_id)) {
     std::move(callback).Run(
-        blink::MediaStreamDevices(),
+        blink::mojom::StreamDevicesSet(),
         blink::mojom::MediaStreamRequestResult::INVALID_STATE, /*ui=*/nullptr);
     return;
   }
@@ -177,10 +174,11 @@ void TabCaptureAccessHandler::HandleRequest(
     // Use extension name as title for extensions and host/origin for drive-by
     // web.
     std::u16string application_title =
-        extension ? base::UTF8ToUTF16(extension->name())
-                  : url_formatter::FormatOriginForSecurityDisplay(
-                        web_contents->GetMainFrame()->GetLastCommittedOrigin(),
-                        url_formatter::SchemeDisplay::OMIT_CRYPTOGRAPHIC);
+        extension
+            ? base::UTF8ToUTF16(extension->name())
+            : url_formatter::FormatOriginForSecurityDisplay(
+                  web_contents->GetPrimaryMainFrame()->GetLastCommittedOrigin(),
+                  url_formatter::SchemeDisplay::OMIT_CRYPTOGRAPHIC);
     content::DesktopMediaID media_id(
         content::DesktopMediaID::TYPE_WEB_CONTENTS, /*id=*/0,
         content::WebContentsMediaCaptureId(request.render_process_id,
@@ -215,13 +213,20 @@ void TabCaptureAccessHandler::AcceptRequest(
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
   DCHECK(web_contents);
 
-  blink::MediaStreamDevices devices;
-  std::unique_ptr<content::MediaStreamUI> ui =
-      GetMediaStreamUI(request, web_contents, std::move(media_ui), &devices);
-  DCHECK(!devices.empty());
+  // TOOD(crbug.com/1300883): Generalize to multiple streams.
+  blink::mojom::StreamDevicesSet stream_devices_set;
+  stream_devices_set.stream_devices.emplace_back(
+      blink::mojom::StreamDevices::New());
+  blink::mojom::StreamDevices& stream_devices =
+      *stream_devices_set.stream_devices[0];
+  std::unique_ptr<content::MediaStreamUI> ui = GetMediaStreamUI(
+      request, web_contents, std::move(media_ui), stream_devices);
+  DCHECK(stream_devices.audio_device.has_value() ||
+         stream_devices.video_device.has_value());
 
   UpdateExtensionTrusted(request, is_allowlisted_extension);
-  std::move(callback).Run(devices, blink::mojom::MediaStreamRequestResult::OK,
+  std::move(callback).Run(stream_devices_set,
+                          blink::mojom::MediaStreamRequestResult::OK,
                           std::move(ui));
 }
 
@@ -244,7 +249,7 @@ void TabCaptureAccessHandler::OnDlpRestrictionChecked(
                   std::move(media_ui));
   } else {
     std::move(pending_request->callback)
-        .Run(blink::MediaStreamDevices(),
+        .Run(blink::mojom::StreamDevicesSet(),
              blink::mojom::MediaStreamRequestResult::PERMISSION_DENIED,
              /*ui=*/nullptr);
   }
