@@ -14,15 +14,14 @@ class PrefService;
 
 namespace printing {
 
+#if BUILDFLAG(ENABLE_PRINT_PREVIEW)
 // Parse the printing.paper_size_default preference.
 std::optional<gfx::Size> ParsePaperSizeDefault(const PrefService& prefs);
+#endif
 
 #if BUILDFLAG(ENABLE_OOP_PRINTING)
-// Determine if out-of-process printing support is enabled.
-bool IsOopPrintingEnabled();
-
-// Determine if printing a job should be done out-of-process.
-bool ShouldPrintJobOop();
+// Determine the out-of-process printing support preference.
+std::optional<bool> OopPrintingPref();
 #endif
 
 }  // namespace printing
