@@ -10,8 +10,8 @@
 #include "content/public/browser/isolated_context_util.h"
 #include "content/public/browser/render_frame_host.h"
 #include "printing/buildflags/buildflags.h"
+#include "services/network/public/mojom/permissions_policy/permissions_policy_feature.mojom.h"
 #include "third_party/blink/public/common/features_generated.h"
-#include "third_party/blink/public/mojom/permissions_policy/permissions_policy_feature.mojom.h"
 
 #if BUILDFLAG(IS_CHROMEOS) && BUILDFLAG(USE_CUPS)
 #include "chrome/browser/printing/web_api/web_printing_service_chromeos.h"
@@ -50,7 +50,7 @@ void CreateWebPrintingServiceForFrame(
     return;
   }
   if (!render_frame_host->IsFeatureEnabled(
-          blink::mojom::PermissionsPolicyFeature::kWebPrinting)) {
+          network::mojom::PermissionsPolicyFeature::kWebPrinting)) {
     mojo::ReportBadMessage(
         "Access to the feature \"web-printing\" is disallowed by permissions "
         "policy.");
