@@ -4,7 +4,9 @@
 
 #include "chrome/browser/printing/web_api/web_printing_service_chromeos.h"
 
+#include <string>
 #include <utility>
+#include <vector>
 
 #include "base/containers/contains.h"
 #include "base/containers/map_util.h"
@@ -62,7 +64,7 @@ bool ValidateMediaCol(
   }
   const auto& papers = printer_attributes.papers;
   // Validate that the requested paper is supported by the printer.
-  if (!base::ranges::any_of(papers, [&](const auto& paper) {
+  if (!std::ranges::any_of(papers, [&](const auto& paper) {
         return paper.IsSizeWithinBounds(media.size_microns);
       })) {
     return false;
@@ -162,9 +164,9 @@ blink::mojom::WebPrinterAttributesPtr MergePrinterAttributesAndStatus(
   for (const auto& reason : printer_status->reasons) {
     printer_state_reasons.push_back(reason.reason);
   }
-  base::ranges::sort(printer_state_reasons);
-  printer_state_reasons.erase(base::ranges::unique(printer_state_reasons),
-                              printer_state_reasons.end());
+  std::ranges::sort(printer_state_reasons);
+  auto repeated = std::ranges::unique(printer_state_reasons);
+  printer_state_reasons.erase(repeated.begin(), repeated.end());
   printer_attributes->printer_state_message = printer_status->message;
   return printer_attributes;
 }
@@ -380,13 +382,6 @@ void WebPrintingServiceChromeOS::OnPrintJobCreated(
   in_progress_jobs_storage_.PrintJobAcknowledgedByThePrintSystem(
       printer_id, creation_info->job_id, std::move(observer),
       std::move(controller));
-
-#if BUILDFLAG(IS_CHROMEOS_LACROS)
-  NotifyAshJobCreated(
-      creation_info->job_id, *creation_info->document,
-      /*source=*/crosapi::mojom::PrintJob::Source::kIsolatedWebApp,
-      /*source_id=*/app_id_, GetLocalPrinterInterface());
-#endif
 }
 
 }  // namespace printing
