@@ -1,10 +1,16 @@
-// Copyright 2021 The Chromium Authors. All rights reserved.
+// Copyright 2021 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+import './uuid.mojom-webui.js';
+
 /**
  * Format in a user readable way service UUIDs.
- * @param ?Array<bluetooth.mojom.UUID> uuids
+ * Note: UUID type is defined in uuid.mojom-webui.ts, however, pure types
+ * are elided by the TS compiler at runtime, so we don't import it here since
+ * this file is in JavaScript. The import can be restored when this file is
+ * migrated to TypeScript.
+ * @param ?Array<UUID> uuids
  * @return {string}
  */
 export function formatServiceUuids(serviceUuids) {
@@ -28,4 +34,4 @@ export function formatManufacturerDataMap(manufacturerDataMap) {
         return `0x${companyIdentifier} 0x${data}`;
       })
       .join(' | ');
-}
\ No newline at end of file
+}
