@@ -159,7 +159,7 @@ export class PostSelectionRendererElement extends PolymerElement {
       this.browserProxy.callbackRouter.clearAllSelections.addListener(
           this.clearSelection.bind(this)),
       this.browserProxy.callbackRouter.clearRegionSelection.addListener(
-          this.clearSelection.bind(this)),
+          this.clearRegionSelection.bind(this)),
       this.browserProxy.callbackRouter.setPostRegionSelection.addListener(
           this.setSelection.bind(this)),
     ];
@@ -182,6 +182,12 @@ export class PostSelectionRendererElement extends PolymerElement {
     this.canvasPhysicalHeight = height * window.devicePixelRatio;
   }
 
+  clearRegionSelection() {
+    unfocusShimmer(this, ShimmerControlRequester.CURSOR);
+    unfocusShimmer(this, ShimmerControlRequester.MANUAL_REGION);
+    this.clearSelection();
+  }
+
   clearSelection() {
     unfocusShimmer(this, ShimmerControlRequester.POST_SELECTION);
     this.height = 0;
@@ -191,11 +197,11 @@ export class PostSelectionRendererElement extends PolymerElement {
     this.notifyPostSelectionUpdated();
   }
 
-  handleDownGesture(event: GestureEvent): boolean {
+  handleGestureStart(event: GestureEvent): boolean {
     this.currentDragTarget =
-        this.dragTargetFromPoint(event.clientX, event.clientY);
+        this.dragTargetFromPoint(event.startX, event.startY);
 
-    if (this.shouldHandleDownGesture()) {
+    if (this.shouldHandleGestureStart()) {
       // User is dragging the post selection (if enabled) or resizing.
       this.originalBounds = {
         left: this.left,
@@ -208,7 +214,7 @@ export class PostSelectionRendererElement extends PolymerElement {
     return false;
   }
 
-  handleDragGesture(event: GestureEvent) {
+  handleGestureDrag(event: GestureEvent) {
     const imageBounds = this.selectionOverlayRect;
     const normalizedX = (event.clientX - imageBounds.left) / imageBounds.width;
     const normalizedY = (event.clientY - imageBounds.top) / imageBounds.height;
@@ -274,7 +280,7 @@ export class PostSelectionRendererElement extends PolymerElement {
     this.rerender();
   }
 
-  handleUpGesture() {
+  handleGestureEnd() {
     if (this.areBoundsChanging()) {
       // Issue Lens request for new bounds
       BrowserProxyImpl.getInstance().handler.issueLensRegionRequest(
@@ -300,6 +306,22 @@ export class PostSelectionRendererElement extends PolymerElement {
     this.currentDragTarget = DragTarget.NONE;
   }
 
+  handleRightClick(event: PointerEvent) {
+    const boundingRect = this.$.postSelection.getBoundingClientRect();
+    if (this.dragTargetFromPoint(event.clientX, event.clientY) !==
+            DragTarget.NONE ||
+        (event.clientX >= boundingRect.left &&
+         event.clientX <= boundingRect.right &&
+         event.clientY >= boundingRect.top &&
+         event.clientY <= boundingRect.bottom)) {
+      this.dispatchEvent(
+          new CustomEvent('restore-selected-region-context-menu', {
+            bubbles: true,
+            composed: true,
+          }));
+    }
+  }
+
   private setSelection(region: CenterRotatedBox) {
     const normalizedTop = region.box.y - (region.box.height / 2);
     const normalizedLeft = region.box.x - (region.box.width / 2);
@@ -527,7 +549,7 @@ export class PostSelectionRendererElement extends PolymerElement {
     return DragTarget.NONE;
   }
 
-  private shouldHandleDownGesture(): boolean {
+  private shouldHandleGestureStart(): boolean {
     return this.currentDragTarget !== DragTarget.NONE;
   }
 
