@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-import './strings.m.js';
+import '/strings.m.js';
 
 export {I18nMixin} from 'chrome://resources/cr_elements/i18n_mixin.js';
 export {I18nMixinLit} from 'chrome://resources/cr_elements/i18n_mixin_lit.js';
