@@ -73,7 +73,7 @@ export class MoveSinglePasswordDialogElement extends
   }
 
   private onMoveButtonClick_() {
-    assert(this.isOptedInForAccountStorage);
+    assert(this.isAccountStorageEnabled);
     PasswordManagerImpl.getInstance().movePasswordsToAccount(
         [this.password.id]);
     this.dispatchEvent(new CustomEvent('passwords-moved', {
