@@ -3,9 +3,8 @@
 // found in the LICENSE file.
 import 'chrome://resources/cr_elements/cr_button/cr_button.js';
 import 'chrome://resources/polymer/v3_0/iron-list/iron-list.js';
-import 'chrome://resources/polymer/v3_0/iron-flex-layout/iron-flex-layout-classes.js';
 import 'chrome://resources/cr_elements/cr_shared_style.css.js';
-import './strings.m.js';
+import '/strings.m.js';
 import './password_list_item.js';
 import './dialogs/add_password_dialog.js';
 import './dialogs/auth_timed_out_dialog.js';
@@ -104,12 +103,6 @@ export class PasswordsSectionElement extends PasswordsSectionElementBase {
         computed: 'computePasswordsOnDevice_(groups_)',
       },
 
-      showMovePasswords_: {
-        type: Boolean,
-        computed: 'computeShowMovePasswords_(isAccountStoreUser, ' +
-            'passwordsOnDevice_, searchTerm_)',
-      },
-
       showPasswordsDescription_: {
         type: Boolean,
         computed: 'computeShowPasswordsDescription_(groups_, searchTerm_)',
