@@ -23,11 +23,14 @@ export function getHtml(this: CardsElement) {
   <cr-collapse ?opened="${this.show_}" ?no-animation="${!this.initialized_}">
     <hr class="sp-hr">
     ${this.modules_.map((item, index) => html`
-      <div class="card" data-index="${index}" @click="${this.onCardClick_}">
+      <div class="card" data-index="${index}" @click="${this.onCardClick_}"
+          ?hidden="${!item.visible}">
         <cr-checkbox class="card-checkbox label-first" data-index="${index}"
             ?checked="${item.enabled}" ?disabled="${this.managedByPolicy_}"
             title="${item.name}" @change="${this.onCardCheckboxChange_}">
-          <div class="card-name">${item.name}</div>
+          <customize-chrome-button-label class="card-label" label="${item.name}"
+              label-description="${item.description}">
+          </customize-chrome-button-label>
         </cr-checkbox>
       </div>
     `)}
