@@ -19,9 +19,6 @@ export function ensureLazyLoaded(): Promise<void> {
     lazyLoadPromise = Promise
                           .all([
                             'profile-type-choice', 'profile-switch',
-                            // <if expr="chromeos_lacros">
-                            'account-selection-lacros',
-                            // </if>
                           ].map(name => customElements.whenDefined(name)))
                           .then(() => {});
   }
