@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-import './strings.m.js';
+import '/strings.m.js';
 import './tab.js';
 import './tab_group.js';
 
@@ -13,12 +13,15 @@ import {EventTracker} from 'chrome://resources/js/event_tracker.js';
 import {FocusOutlineManager} from 'chrome://resources/js/focus_outline_manager.js';
 import {isRTL} from 'chrome://resources/js/util.js';
 
-import {DragManager, DragManagerDelegate} from './drag_manager.js';
+import type {DragManagerDelegate} from './drag_manager.js';
+import {DragManager} from './drag_manager.js';
 import {isTabElement, TabElement} from './tab.js';
-import {isDragHandle, isTabGroupElement, TabGroupElement} from './tab_group.js';
+import type {TabGroupElement} from './tab_group.js';
+import {isDragHandle, isTabGroupElement} from './tab_group.js';
 import {getTemplate} from './tab_list.html.js';
-import {Tab, TabGroupVisualData} from './tab_strip.mojom-webui.js';
-import {TabsApiProxy, TabsApiProxyImpl} from './tabs_api_proxy.js';
+import type {Tab, TabGroupVisualData} from './tab_strip.mojom-webui.js';
+import type {TabsApiProxy} from './tabs_api_proxy.js';
+import {TabsApiProxyImpl} from './tabs_api_proxy.js';
 
 /**
  * The amount of padding to leave between the edge of the screen and the active
@@ -206,11 +209,11 @@ export class TabListElement extends CustomElement implements
 
     this.eventTracker_ = new EventTracker();
 
-    this.pinnedTabsElement_ = this.$('#pinnedTabs')!;
+    this.pinnedTabsElement_ = this.getRequiredElement('#pinnedTabs');
 
     this.tabsApi_ = TabsApiProxyImpl.getInstance();
 
-    this.unpinnedTabsElement_ = this.$('#unpinnedTabs')!;
+    this.unpinnedTabsElement_ = this.getRequiredElement('#unpinnedTabs');
 
     /**
      * Timeout that is created at every scroll event and is either canceled at
@@ -380,7 +383,7 @@ export class TabListElement extends CustomElement implements
   }
 
   private fetchAndUpdateGroupData_() {
-    const tabGroupElements = this.$all<TabGroupElement>('tabstrip-tab-group');
+    const tabGroupElements = this.$all('tabstrip-tab-group');
     this.tabsApi_.getGroupVisualData().then(({data}) => {
       tabGroupElements.forEach(tabGroupElement => {
         const visualData = data[tabGroupElement.dataset['groupId']!];
@@ -662,7 +665,8 @@ export class TabListElement extends CustomElement implements
   }
 
   placeTabElement(
-      element: TabElement, index: number, pinned: boolean, groupId?: string) {
+      element: TabElement, index: number, pinned: boolean,
+      groupId: string|null) {
     const isInserting = !element.isConnected;
 
     const previousIndex = isInserting ? -1 : this.getIndexOfTab(element);
@@ -690,10 +694,11 @@ export class TabListElement extends CustomElement implements
       index++;
     }
 
-    let elementAtIndex = this.$all('tabstrip-tab')[index]!;
+    let elementAtIndex: TabGroupElement|TabElement =
+        this.$all('tabstrip-tab')[index]!;
     if (elementAtIndex && elementAtIndex.parentElement &&
         isTabGroupElement(elementAtIndex.parentElement)) {
-      elementAtIndex = elementAtIndex.parentElement;
+      elementAtIndex = elementAtIndex.parentElement as TabGroupElement;
     }
 
     this.unpinnedTabsElement_.insertBefore(element, elementAtIndex);
@@ -779,7 +784,8 @@ export class TabListElement extends CustomElement implements
   }
 
   private updateTabElementDomPosition_(
-      element: TabElement, index: number, pinned: boolean, groupId?: string) {
+      element: TabElement, index: number, pinned: boolean,
+      groupId: string|null) {
     // Remove the element if it already exists in the DOM. This simplifies
     // the way indices work as it does not have to count its old index in
     // the initial layout of the DOM.
