@@ -33,7 +33,7 @@ class AboutSigninInternalsFactory : public ProfileKeyedServiceFactory {
   ~AboutSigninInternalsFactory() override;
 
   // BrowserContextKeyedServiceFactory
-  KeyedService* BuildServiceInstanceFor(
+  std::unique_ptr<KeyedService> BuildServiceInstanceForBrowserContext(
       content::BrowserContext* context) const override;
 };
 
