@@ -18,6 +18,7 @@
 #include "components/signin/public/identity_manager/test_identity_manager_observer.h"
 #include "content/public/test/browser_test.h"
 #include "google_apis/gaia/fake_gaia.h"
+#include "google_apis/gaia/gaia_id.h"
 #include "google_apis/gaia/gaia_switches.h"
 #include "net/test/embedded_test_server/embedded_test_server.h"
 #include "net/test/embedded_test_server/http_response.h"
@@ -34,7 +35,7 @@ using testing::Contains;
 using testing::Not;
 
 MATCHER_P(ListedAccountMatchesGaiaId, gaia_id, "") {
-  return arg.gaia_id == std::string(gaia_id);
+  return arg.gaia_id == GaiaId(gaia_id);
 }
 
 const char kTestGaiaId[] = "123";
@@ -74,7 +75,7 @@ class RemoveLocalAccountTest : public MixinBasedInProcessBrowserTest {
     fake_gaia_.Initialize();
 
     FakeGaia::Configuration params;
-    params.signed_out_gaia_ids.push_back(kTestGaiaId);
+    params.signed_out_gaia_ids.push_back(GaiaId(kTestGaiaId));
     fake_gaia_.UpdateConfiguration(params);
 
     embedded_test_server_.StartAcceptingConnections();
@@ -103,24 +104,24 @@ IN_PROC_BROWSER_TEST_F(RemoveLocalAccountTest, ShouldNotifyObservers) {
   signin::SetFreshnessOfAccountsInGaiaCookie(identity_manager(),
                                              /*accounts_are_fresh=*/false);
 
-  ASSERT_FALSE(identity_manager()->GetAccountsInCookieJar().accounts_are_fresh);
+  ASSERT_FALSE(identity_manager()->GetAccountsInCookieJar().AreAccountsFresh());
   const signin::AccountsInCookieJarInfo
       cookie_jar_info_in_initial_notification =
           WaitUntilAccountsInCookieUpdated();
-  ASSERT_TRUE(cookie_jar_info_in_initial_notification.accounts_are_fresh);
-  ASSERT_THAT(cookie_jar_info_in_initial_notification.signed_out_accounts,
+  ASSERT_TRUE(cookie_jar_info_in_initial_notification.AreAccountsFresh());
+  ASSERT_THAT(cookie_jar_info_in_initial_notification.GetSignedOutAccounts(),
               Contains(ListedAccountMatchesGaiaId(kTestGaiaId)));
 
   const signin::AccountsInCookieJarInfo initial_cookie_jar_info =
       identity_manager()->GetAccountsInCookieJar();
-  ASSERT_TRUE(initial_cookie_jar_info.accounts_are_fresh);
-  ASSERT_THAT(initial_cookie_jar_info.signed_out_accounts,
+  ASSERT_TRUE(initial_cookie_jar_info.AreAccountsFresh());
+  ASSERT_THAT(initial_cookie_jar_info.GetSignedOutAccounts(),
               Contains(ListedAccountMatchesGaiaId(kTestGaiaId)));
 
   // Open a FakeGaia page that issues the desired HTTP response header with
   // Google-Accounts-RemoveLocalAccount.
   chrome::AddTabAt(browser(),
-                   fake_gaia_.GetFakeRemoveLocalAccountURL(kTestGaiaId),
+                   fake_gaia_.GetFakeRemoveLocalAccountURL(GaiaId(kTestGaiaId)),
                    /*index=*/0,
                    /*foreground=*/true);
 
@@ -129,14 +130,14 @@ IN_PROC_BROWSER_TEST_F(RemoveLocalAccountTest, ShouldNotifyObservers) {
       cookie_jar_info_in_updated_notification =
           WaitUntilAccountsInCookieUpdated();
 
-  EXPECT_TRUE(cookie_jar_info_in_updated_notification.accounts_are_fresh);
-  EXPECT_THAT(cookie_jar_info_in_updated_notification.signed_out_accounts,
+  EXPECT_TRUE(cookie_jar_info_in_updated_notification.AreAccountsFresh());
+  EXPECT_THAT(cookie_jar_info_in_updated_notification.GetSignedOutAccounts(),
               Not(Contains(ListedAccountMatchesGaiaId(kTestGaiaId))));
 
   const signin::AccountsInCookieJarInfo updated_cookie_jar_info =
       identity_manager()->GetAccountsInCookieJar();
-  EXPECT_TRUE(updated_cookie_jar_info.accounts_are_fresh);
-  EXPECT_THAT(updated_cookie_jar_info.signed_out_accounts,
+  EXPECT_TRUE(updated_cookie_jar_info.AreAccountsFresh());
+  EXPECT_THAT(updated_cookie_jar_info.GetSignedOutAccounts(),
               Not(Contains(ListedAccountMatchesGaiaId(kTestGaiaId))));
 }
 
