@@ -18,29 +18,24 @@ import org.robolectric.RuntimeEnvironment;
 import org.robolectric.annotation.LooperMode;
 
 import org.chromium.base.test.BaseRobolectricTestRunner;
-import org.chromium.base.test.util.JniMocker;
 import org.chromium.chrome.test.util.browser.signin.AccountManagerTestRule;
-import org.chromium.components.signin.base.AccountCapabilities;
 import org.chromium.components.signin.base.AccountInfo;
-import org.chromium.components.signin.base.CoreAccountId;
+import org.chromium.components.signin.base.GaiaId;
 import org.chromium.components.signin.identitymanager.AccountInfoServiceProvider;
 import org.chromium.components.signin.identitymanager.IdentityManager;
 import org.chromium.components.signin.identitymanager.IdentityManagerJni;
 
-import java.util.HashMap;
-
 /** Unit tests for {@link ProfileDataCache} */
 @RunWith(BaseRobolectricTestRunner.class)
 @LooperMode(LooperMode.Mode.LEGACY)
 public class ProfileDataCacheUnitTest {
     private static final long NATIVE_IDENTITY_MANAGER = 10001L;
-    private static final String ACCOUNT_EMAIL = "test@gmail.com";
+    private static final AccountInfo ACCOUNT =
+            new AccountInfo.Builder("test@gmail.com", new GaiaId("gaia-id")).build();
 
     @Rule
     public final MockitoRule mMockitoRule = MockitoJUnit.rule().strictness(Strictness.STRICT_STUBS);
 
-    @Rule public final JniMocker mocker = new JniMocker();
-
     @Rule
     public final AccountManagerTestRule mAccountManagerTestRule = new AccountManagerTestRule();
 
@@ -55,7 +50,7 @@ public class ProfileDataCacheUnitTest {
 
     @Before
     public void setUp() {
-        mocker.mock(IdentityManagerJni.TEST_HOOKS, mIdentityManagerNativeMock);
+        IdentityManagerJni.setInstanceForTesting(mIdentityManagerNativeMock);
         mProfileDataCache =
                 ProfileDataCache.createWithDefaultImageSizeAndNoBadge(
                         RuntimeEnvironment.application.getApplicationContext());
@@ -72,66 +67,51 @@ public class ProfileDataCacheUnitTest {
     @Test
     public void accountInfoIsUpdatedWithOnlyFullName() {
         final String fullName = "full name1";
-        final AccountInfo accountInfo =
-                new AccountInfo(
-                        new CoreAccountId("gaia-id-test"),
-                        ACCOUNT_EMAIL,
-                        "gaia-id-test",
-                        fullName,
-                        null,
-                        null,
-                        new AccountCapabilities(new HashMap<>()));
+        final AccountInfo accountWithFullName =
+                new AccountInfo.Builder(ACCOUNT).fullName(fullName).build();
         mProfileDataCache.addObserver(mObserverMock);
-        Assert.assertFalse(mProfileDataCache.hasProfileDataForTesting(ACCOUNT_EMAIL));
-        Assert.assertNull(mProfileDataCache.getProfileDataOrDefault(ACCOUNT_EMAIL).getFullName());
+        Assert.assertFalse(mProfileDataCache.hasProfileDataForTesting(ACCOUNT.getEmail()));
+        Assert.assertNull(
+                mProfileDataCache.getProfileDataOrDefault(ACCOUNT.getEmail()).getFullName());
 
-        mIdentityManager.onExtendedAccountInfoUpdated(accountInfo);
+        mIdentityManager.onExtendedAccountInfoUpdated(accountWithFullName);
 
-        Assert.assertTrue(mProfileDataCache.hasProfileDataForTesting(ACCOUNT_EMAIL));
+        Assert.assertTrue(mProfileDataCache.hasProfileDataForTesting(ACCOUNT.getEmail()));
         Assert.assertEquals(
-                fullName, mProfileDataCache.getProfileDataOrDefault(ACCOUNT_EMAIL).getFullName());
+                fullName,
+                mProfileDataCache.getProfileDataOrDefault(ACCOUNT.getEmail()).getFullName());
     }
 
     @Test
     public void accountInfoIsUpdatedWithOnlyGivenName() {
         final String givenName = "given name1";
-        final AccountInfo accountInfo =
-                new AccountInfo(
-                        new CoreAccountId("gaia-id-test"),
-                        ACCOUNT_EMAIL,
-                        "gaia-id-test",
-                        null,
-                        givenName,
-                        null,
-                        new AccountCapabilities(new HashMap<>()));
+        final AccountInfo accountWithGivenName =
+                new AccountInfo.Builder(ACCOUNT).givenName(givenName).build();
         mProfileDataCache.addObserver(mObserverMock);
-        Assert.assertFalse(mProfileDataCache.hasProfileDataForTesting(ACCOUNT_EMAIL));
-        Assert.assertNull(mProfileDataCache.getProfileDataOrDefault(ACCOUNT_EMAIL).getGivenName());
+        Assert.assertFalse(mProfileDataCache.hasProfileDataForTesting(ACCOUNT.getEmail()));
+        Assert.assertNull(
+                mProfileDataCache.getProfileDataOrDefault(ACCOUNT.getEmail()).getGivenName());
 
-        mIdentityManager.onExtendedAccountInfoUpdated(accountInfo);
+        mIdentityManager.onExtendedAccountInfoUpdated(accountWithGivenName);
 
-        Assert.assertTrue(mProfileDataCache.hasProfileDataForTesting(ACCOUNT_EMAIL));
+        Assert.assertTrue(mProfileDataCache.hasProfileDataForTesting(ACCOUNT.getEmail()));
         Assert.assertEquals(
-                givenName, mProfileDataCache.getProfileDataOrDefault(ACCOUNT_EMAIL).getGivenName());
+                givenName,
+                mProfileDataCache.getProfileDataOrDefault(ACCOUNT.getEmail()).getGivenName());
     }
 
     @Test
     public void accountInfoIsUpdatedWithOnlyBadgeConfig() {
-        mProfileDataCache.setBadge(R.drawable.ic_sync_badge_error_20dp);
-        final AccountInfo accountInfo =
-                new AccountInfo(
-                        new CoreAccountId("gaia-id-test"),
-                        ACCOUNT_EMAIL,
-                        "gaia-id-test",
-                        null,
-                        null,
-                        null,
-                        new AccountCapabilities(new HashMap<>()));
+        mProfileDataCache.setBadge(
+                ACCOUNT.getEmail(),
+                ProfileDataCache.createDefaultSizeChildAccountBadgeConfig(
+                        RuntimeEnvironment.application.getApplicationContext(),
+                        R.drawable.ic_sync_badge_error_20dp));
         mProfileDataCache.addObserver(mObserverMock);
-        Assert.assertFalse(mProfileDataCache.hasProfileDataForTesting(ACCOUNT_EMAIL));
+        Assert.assertFalse(mProfileDataCache.hasProfileDataForTesting(ACCOUNT.getEmail()));
 
-        mIdentityManager.onExtendedAccountInfoUpdated(accountInfo);
+        mIdentityManager.onExtendedAccountInfoUpdated(ACCOUNT);
 
-        Assert.assertTrue(mProfileDataCache.hasProfileDataForTesting(ACCOUNT_EMAIL));
+        Assert.assertTrue(mProfileDataCache.hasProfileDataForTesting(ACCOUNT.getEmail()));
     }
 }
