@@ -1,4 +1,4 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2012 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -11,10 +11,10 @@
 #include <utility>
 #include <vector>
 
-#include "base/bind.h"
 #include "base/files/file_util.h"
-#include "base/macros.h"
+#include "base/functional/bind.h"
 #include "base/memory/ptr_util.h"
+#include "base/memory/raw_ptr.h"
 #include "base/metrics/histogram_samples.h"
 #include "base/metrics/statistics_recorder.h"
 #include "base/strings/string_number_conversions.h"
@@ -28,10 +28,9 @@
 #include "components/sync/base/client_tag_hash.h"
 #include "components/sync/model/sync_change.h"
 #include "components/sync/model/sync_data.h"
-#include "components/sync/model/sync_error_factory.h"
-#include "components/sync/protocol/sync.pb.h"
-#include "components/sync/test/model/sync_change_processor_wrapper_for_test.h"
-#include "components/sync/test/model/sync_error_factory_mock.h"
+#include "components/sync/protocol/dictionary_specifics.pb.h"
+#include "components/sync/protocol/entity_specifics.pb.h"
+#include "components/sync/test/sync_change_processor_wrapper_for_test.h"
 #include "content/public/test/browser_task_environment.h"
 #include "content/public/test/test_utils.h"
 #include "net/test/embedded_test_server/default_handlers.h"
@@ -140,35 +139,16 @@ class SpellcheckCustomDictionaryTest : public testing::Test {
   std::list<TestingProfile> extra_profiles_;
 };
 
-// An implementation of SyncErrorFactory that does not upload the error message
-// and updates an outside error counter. This lets us know the number of error
-// messages in an instance of this class after that instance is deleted.
-class SyncErrorFactoryStub : public syncer::SyncErrorFactory {
- public:
-  explicit SyncErrorFactoryStub(int* error_counter)
-      : error_counter_(error_counter) {}
-  ~SyncErrorFactoryStub() override {}
-
-  // Overridden from syncer::SyncErrorFactory:
-  syncer::SyncError CreateAndUploadError(const base::Location& location,
-                                         const std::string& message) override {
-    (*error_counter_)++;
-    return syncer::SyncError(location,
-                             syncer::SyncError::DATATYPE_ERROR,
-                             message,
-                             syncer::DICTIONARY);
-  }
-
- private:
-  int* error_counter_;
-  DISALLOW_COPY_AND_ASSIGN(SyncErrorFactoryStub);
-};
-
 // Counts the number of notifications for dictionary load and change.
 class DictionaryObserverCounter : public SpellcheckCustomDictionary::Observer {
  public:
   DictionaryObserverCounter() : loads_(0), changes_(0) {}
-  virtual ~DictionaryObserverCounter() {}
+
+  DictionaryObserverCounter(const DictionaryObserverCounter&) = delete;
+  DictionaryObserverCounter& operator=(const DictionaryObserverCounter&) =
+      delete;
+
+  virtual ~DictionaryObserverCounter() = default;
 
   int loads() const { return loads_; }
   int changes() const { return changes_; }
@@ -183,7 +163,6 @@ class DictionaryObserverCounter : public SpellcheckCustomDictionary::Observer {
  private:
   int loads_;
   int changes_;
-  DISALLOW_COPY_AND_ASSIGN(DictionaryObserverCounter);
 };
 
 TEST_F(SpellcheckCustomDictionaryTest, SaveAndLoad) {
@@ -247,7 +226,7 @@ TEST_F(SpellcheckCustomDictionaryTest, LegacyEmptyDictionaryShouldBeConverted) {
       profile_.GetPath().Append(chrome::kCustomDictionaryFileName);
 
   std::string content;
-  base::WriteFile(path, content.c_str(), content.length());
+  base::WriteFile(path, content);
   EXPECT_TRUE(LoadDictionaryFile(path)->words.empty());
 }
 
@@ -259,7 +238,7 @@ TEST_F(SpellcheckCustomDictionaryTest,
       profile_.GetPath().Append(chrome::kCustomDictionaryFileName);
 
   std::string content = "foo\nbar\nfoo\n";
-  base::WriteFile(path, content.c_str(), content.length());
+  base::WriteFile(path, content);
   std::set<std::string> expected;
   expected.insert("bar");
   expected.insert("foo");
@@ -276,7 +255,7 @@ TEST_F(SpellcheckCustomDictionaryTest,
   std::string content = "foo\n foo bar \n\n \nbar\n"
       "01234567890123456789012345678901234567890123456789"
       "01234567890123456789012345678901234567890123456789";
-  base::WriteFile(path, content.c_str(), content.length());
+  base::WriteFile(path, content);
   std::set<std::string> expected;
   expected.insert("bar");
   expected.insert("foo");
@@ -292,7 +271,7 @@ TEST_F(SpellcheckCustomDictionaryTest, CorruptedWriteShouldBeRecovered) {
       profile_.GetPath().Append(chrome::kCustomDictionaryFileName);
 
   std::string content = "foo\nbar";
-  base::WriteFile(path, content.c_str(), content.length());
+  base::WriteFile(path, content);
   std::set<std::string> expected;
   expected.insert("bar");
   expected.insert("foo");
@@ -305,7 +284,7 @@ TEST_F(SpellcheckCustomDictionaryTest, CorruptedWriteShouldBeRecovered) {
   content.clear();
   base::ReadFileToString(path, &content);
   content.append("corruption");
-  base::WriteFile(path, content.c_str(), content.length());
+  base::WriteFile(path, content);
   EXPECT_EQ(expected, LoadDictionaryFile(path)->words);
 }
 
@@ -466,7 +445,6 @@ TEST_F(SpellcheckCustomDictionaryTest, MergeDataAndStartSyncing) {
   }
   Apply(*custom_dictionary2, change2);
 
-  int error_counter = 0;
   EXPECT_FALSE(
       custom_dictionary
           ->MergeDataAndStartSyncing(
@@ -474,11 +452,8 @@ TEST_F(SpellcheckCustomDictionaryTest, MergeDataAndStartSyncing) {
               custom_dictionary2->GetAllSyncDataForTesting(syncer::DICTIONARY),
               std::unique_ptr<syncer::SyncChangeProcessor>(
                   new syncer::SyncChangeProcessorWrapperForTest(
-                      custom_dictionary2)),
-              std::unique_ptr<syncer::SyncErrorFactory>(
-                  new SyncErrorFactoryStub(&error_counter)))
+                      custom_dictionary2)))
           .has_value());
-  EXPECT_EQ(0, error_counter);
   EXPECT_TRUE(custom_dictionary->IsSyncing());
 
   std::set<std::string> words = custom_dictionary->GetWords();
@@ -521,7 +496,6 @@ TEST_F(SpellcheckCustomDictionaryTest, SyncBeforeLoadDoesNotDuplicateWords) {
   UpdateDictionaryFile(std::move(change), path);
   EXPECT_TRUE(custom_dictionary->GetWords().empty());
 
-  int error_counter = 0;
   EXPECT_FALSE(
       custom_dictionary
           ->MergeDataAndStartSyncing(
@@ -529,11 +503,8 @@ TEST_F(SpellcheckCustomDictionaryTest, SyncBeforeLoadDoesNotDuplicateWords) {
               custom_dictionary2->GetAllSyncDataForTesting(syncer::DICTIONARY),
               std::unique_ptr<syncer::SyncChangeProcessor>(
                   new syncer::SyncChangeProcessorWrapperForTest(
-                      custom_dictionary2)),
-              std::unique_ptr<syncer::SyncErrorFactory>(
-                  new SyncErrorFactoryStub(&error_counter)))
+                      custom_dictionary2)))
           .has_value());
-  EXPECT_EQ(0, error_counter);
   EXPECT_TRUE(custom_dictionary->IsSyncing());
 
   std::set<std::string> expected_words_in_memory;
@@ -564,7 +535,6 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionaryTooBigBeforeSyncing) {
   }
   Apply(*custom_dictionary, change);
 
-  int error_counter = 0;
   EXPECT_FALSE(
       custom_dictionary
           ->MergeDataAndStartSyncing(
@@ -572,11 +542,8 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionaryTooBigBeforeSyncing) {
               custom_dictionary2->GetAllSyncDataForTesting(syncer::DICTIONARY),
               std::unique_ptr<syncer::SyncChangeProcessor>(
                   new syncer::SyncChangeProcessorWrapperForTest(
-                      custom_dictionary2)),
-              std::unique_ptr<syncer::SyncErrorFactory>(
-                  new SyncErrorFactoryStub(&error_counter)))
+                      custom_dictionary2)))
           .has_value());
-  EXPECT_EQ(0, error_counter);
   EXPECT_FALSE(custom_dictionary->IsSyncing());
 
   EXPECT_EQ(spellcheck::kMaxSyncableDictionaryWords + 1,
@@ -614,7 +581,6 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionaryTooBigAndServerFull) {
   EXPECT_EQ(spellcheck::kMaxSyncableDictionaryWords,
             custom_dictionary2->GetWords().size());
 
-  int error_counter = 0;
   EXPECT_FALSE(
       custom_dictionary
           ->MergeDataAndStartSyncing(
@@ -622,11 +588,8 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionaryTooBigAndServerFull) {
               custom_dictionary2->GetAllSyncDataForTesting(syncer::DICTIONARY),
               std::unique_ptr<syncer::SyncChangeProcessor>(
                   new syncer::SyncChangeProcessorWrapperForTest(
-                      custom_dictionary2)),
-              std::unique_ptr<syncer::SyncErrorFactory>(
-                  new SyncErrorFactoryStub(&error_counter)))
+                      custom_dictionary2)))
           .has_value());
-  EXPECT_EQ(0, error_counter);
   EXPECT_FALSE(custom_dictionary->IsSyncing());
 
   EXPECT_EQ(spellcheck::kMaxSyncableDictionaryWords * 2 + 1,
@@ -663,18 +626,14 @@ TEST_F(SpellcheckCustomDictionaryTest, ServerTooBig) {
   EXPECT_EQ(spellcheck::kMaxSyncableDictionaryWords + 1,
             custom_dictionary2->GetWords().size());
 
-  int error_counter = 0;
   EXPECT_FALSE(custom_dictionary
                    ->MergeDataAndStartSyncing(
                        syncer::DICTIONARY,
                        GetAllSyncDataNoLimit(custom_dictionary2),
                        std::unique_ptr<syncer::SyncChangeProcessor>(
                            new syncer::SyncChangeProcessorWrapperForTest(
-                               custom_dictionary2)),
-                       std::unique_ptr<syncer::SyncErrorFactory>(
-                           new SyncErrorFactoryStub(&error_counter)))
+                               custom_dictionary2)))
                    .has_value());
-  EXPECT_EQ(0, error_counter);
   EXPECT_FALSE(custom_dictionary->IsSyncing());
 
   EXPECT_EQ(spellcheck::kMaxSyncableDictionaryWords * 2 + 2,
@@ -706,7 +665,6 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionaryTooBigToStartSyncing) {
   custom_dictionary2->AddWord("bar");
   custom_dictionary2->AddWord("baz");
 
-  int error_counter = 0;
   EXPECT_FALSE(
       custom_dictionary
           ->MergeDataAndStartSyncing(
@@ -714,11 +672,8 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionaryTooBigToStartSyncing) {
               custom_dictionary2->GetAllSyncDataForTesting(syncer::DICTIONARY),
               std::unique_ptr<syncer::SyncChangeProcessor>(
                   new syncer::SyncChangeProcessorWrapperForTest(
-                      custom_dictionary2)),
-              std::unique_ptr<syncer::SyncErrorFactory>(
-                  new SyncErrorFactoryStub(&error_counter)))
+                      custom_dictionary2)))
           .has_value());
-  EXPECT_EQ(0, error_counter);
   EXPECT_FALSE(custom_dictionary->IsSyncing());
 
   EXPECT_EQ(spellcheck::kMaxSyncableDictionaryWords + 1,
@@ -747,7 +702,6 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionaryTooBigToContiueSyncing) {
   }
   Apply(*custom_dictionary, change);
 
-  int error_counter = 0;
   EXPECT_FALSE(
       custom_dictionary
           ->MergeDataAndStartSyncing(
@@ -755,19 +709,14 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionaryTooBigToContiueSyncing) {
               custom_dictionary2->GetAllSyncDataForTesting(syncer::DICTIONARY),
               std::unique_ptr<syncer::SyncChangeProcessor>(
                   new syncer::SyncChangeProcessorWrapperForTest(
-                      custom_dictionary2)),
-              std::unique_ptr<syncer::SyncErrorFactory>(
-                  new SyncErrorFactoryStub(&error_counter)))
+                      custom_dictionary2)))
           .has_value());
-  EXPECT_EQ(0, error_counter);
   EXPECT_TRUE(custom_dictionary->IsSyncing());
 
   custom_dictionary->AddWord("bar");
-  EXPECT_EQ(0, error_counter);
   EXPECT_TRUE(custom_dictionary->IsSyncing());
 
   custom_dictionary->AddWord("baz");
-  EXPECT_EQ(0, error_counter);
   EXPECT_FALSE(custom_dictionary->IsSyncing());
 
   EXPECT_EQ(spellcheck::kMaxSyncableDictionaryWords + 1,
@@ -792,7 +741,6 @@ TEST_F(SpellcheckCustomDictionaryTest, LoadAfterSyncStart) {
 
   custom_dictionary->AddWord("foo");
 
-  int error_counter = 0;
   EXPECT_FALSE(
       custom_dictionary
           ->MergeDataAndStartSyncing(
@@ -800,11 +748,8 @@ TEST_F(SpellcheckCustomDictionaryTest, LoadAfterSyncStart) {
               custom_dictionary2->GetAllSyncDataForTesting(syncer::DICTIONARY),
               std::unique_ptr<syncer::SyncChangeProcessor>(
                   new syncer::SyncChangeProcessorWrapperForTest(
-                      custom_dictionary2)),
-              std::unique_ptr<syncer::SyncErrorFactory>(
-                  new SyncErrorFactoryStub(&error_counter)))
+                      custom_dictionary2)))
           .has_value());
-  EXPECT_EQ(0, error_counter);
   EXPECT_TRUE(custom_dictionary->IsSyncing());
 
   std::unique_ptr<std::set<std::string>> custom_words(
@@ -833,7 +778,6 @@ TEST_F(SpellcheckCustomDictionaryTest, LoadAfterSyncStartTooBigToSync) {
 
   custom_dictionary->AddWord("foo");
 
-  int error_counter = 0;
   EXPECT_FALSE(
       custom_dictionary
           ->MergeDataAndStartSyncing(
@@ -841,11 +785,8 @@ TEST_F(SpellcheckCustomDictionaryTest, LoadAfterSyncStartTooBigToSync) {
               custom_dictionary2->GetAllSyncDataForTesting(syncer::DICTIONARY),
               std::unique_ptr<syncer::SyncChangeProcessor>(
                   new syncer::SyncChangeProcessorWrapperForTest(
-                      custom_dictionary2)),
-              std::unique_ptr<syncer::SyncErrorFactory>(
-                  new SyncErrorFactoryStub(&error_counter)))
+                      custom_dictionary2)))
           .has_value());
-  EXPECT_EQ(0, error_counter);
   EXPECT_TRUE(custom_dictionary->IsSyncing());
 
   std::unique_ptr<std::set<std::string>> custom_words(
@@ -854,7 +795,6 @@ TEST_F(SpellcheckCustomDictionaryTest, LoadAfterSyncStartTooBigToSync) {
     custom_words->insert(custom_words->end(), "foo" + base::NumberToString(i));
   }
   OnLoaded(*custom_dictionary, std::move(custom_words));
-  EXPECT_EQ(0, error_counter);
   EXPECT_FALSE(custom_dictionary->IsSyncing());
 
   EXPECT_EQ(spellcheck::kMaxSyncableDictionaryWords + 1,
@@ -883,7 +823,6 @@ TEST_F(SpellcheckCustomDictionaryTest, LoadDuplicatesAfterSync) {
   }
   Apply(*custom_dictionary, change);
 
-  int error_counter = 0;
   EXPECT_FALSE(
       custom_dictionary
           ->MergeDataAndStartSyncing(
@@ -891,16 +830,12 @@ TEST_F(SpellcheckCustomDictionaryTest, LoadDuplicatesAfterSync) {
               custom_dictionary2->GetAllSyncDataForTesting(syncer::DICTIONARY),
               std::unique_ptr<syncer::SyncChangeProcessor>(
                   new syncer::SyncChangeProcessorWrapperForTest(
-                      custom_dictionary2)),
-              std::unique_ptr<syncer::SyncErrorFactory>(
-                  new SyncErrorFactoryStub(&error_counter)))
+                      custom_dictionary2)))
           .has_value());
-  EXPECT_EQ(0, error_counter);
   EXPECT_TRUE(custom_dictionary->IsSyncing());
 
   OnLoaded(*custom_dictionary,
            std::make_unique<std::set<std::string>>(change.to_add()));
-  EXPECT_EQ(0, error_counter);
   EXPECT_TRUE(custom_dictionary->IsSyncing());
 
   EXPECT_EQ(spellcheck::kMaxSyncableDictionaryWords / 2,
@@ -1002,7 +937,6 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionarySyncNotification) {
   DictionaryObserverCounter observer2;
   custom_dictionary2->AddObserver(&observer2);
 
-  int error_counter = 0;
   EXPECT_FALSE(
       custom_dictionary
           ->MergeDataAndStartSyncing(
@@ -1010,11 +944,8 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionarySyncNotification) {
               custom_dictionary2->GetAllSyncDataForTesting(syncer::DICTIONARY),
               std::unique_ptr<syncer::SyncChangeProcessor>(
                   new syncer::SyncChangeProcessorWrapperForTest(
-                      custom_dictionary2)),
-              std::unique_ptr<syncer::SyncErrorFactory>(
-                  new SyncErrorFactoryStub(&error_counter)))
+                      custom_dictionary2)))
           .has_value());
-  EXPECT_EQ(0, error_counter);
   EXPECT_TRUE(custom_dictionary->IsSyncing());
 
   EXPECT_EQ(1, observer.changes());
@@ -1046,7 +977,6 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionarySyncLimit) {
     }
     Apply(*custom_dictionary, change);
 
-    int error_counter = 0;
     EXPECT_FALSE(custom_dictionary
                      ->MergeDataAndStartSyncing(
                          syncer::DICTIONARY,
@@ -1054,11 +984,8 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionarySyncLimit) {
                              syncer::DICTIONARY),
                          std::unique_ptr<syncer::SyncChangeProcessor>(
                              new syncer::SyncChangeProcessorWrapperForTest(
-                                 server_custom_dictionary)),
-                         std::unique_ptr<syncer::SyncErrorFactory>(
-                             new SyncErrorFactoryStub(&error_counter)))
+                                 server_custom_dictionary)))
                      .has_value());
-    EXPECT_EQ(0, error_counter);
     EXPECT_TRUE(custom_dictionary->IsSyncing());
     EXPECT_EQ(spellcheck::kMaxSyncableDictionaryWords,
               custom_dictionary->GetWords().size());
@@ -1085,7 +1012,6 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionarySyncLimit) {
     Apply(*client_custom_dictionary, change);
 
     // Associate the server and the client.
-    int error_counter = 0;
     EXPECT_FALSE(client_custom_dictionary
                      ->MergeDataAndStartSyncing(
                          syncer::DICTIONARY,
@@ -1093,11 +1019,8 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionarySyncLimit) {
                              syncer::DICTIONARY),
                          std::unique_ptr<syncer::SyncChangeProcessor>(
                              new syncer::SyncChangeProcessorWrapperForTest(
-                                 server_custom_dictionary)),
-                         std::unique_ptr<syncer::SyncErrorFactory>(
-                             new SyncErrorFactoryStub(&error_counter)))
+                                 server_custom_dictionary)))
                      .has_value());
-    EXPECT_EQ(0, error_counter);
     EXPECT_FALSE(client_custom_dictionary->IsSyncing());
     EXPECT_EQ(spellcheck::kMaxSyncableDictionaryWords * 2,
               client_custom_dictionary->GetWords().size());
@@ -1109,54 +1032,6 @@ TEST_F(SpellcheckCustomDictionaryTest, DictionarySyncLimit) {
             server_custom_dictionary->GetWords().size());
 }
 
-#if defined(OS_WIN)
-// Failing consistently on Win7+. See crbug.com/230534.
-#define MAYBE_RecordSizeStatsCorrectly DISABLED_RecordSizeStatsCorrectly
-#else
-#define MAYBE_RecordSizeStatsCorrectly RecordSizeStatsCorrectly
-#endif
-
-TEST_F(SpellcheckCustomDictionaryTest, MAYBE_RecordSizeStatsCorrectly) {
-  // Record a baseline.
-  SpellCheckHostMetrics::RecordCustomWordCountStats(123);
-
-  HistogramBase* histogram =
-      StatisticsRecorder::FindHistogram("SpellCheck.CustomWords");
-  ASSERT_TRUE(histogram != NULL);
-  std::unique_ptr<HistogramSamples> baseline = histogram->SnapshotSamples();
-
-  // Load the dictionary which should be empty.
-  base::FilePath path =
-      profile_.GetPath().Append(chrome::kCustomDictionaryFileName);
-  EXPECT_TRUE(LoadDictionaryFile(path)->words.empty());
-
-  // We expect there to be an entry with 0.
-  histogram =
-      StatisticsRecorder::FindHistogram("SpellCheck.CustomWords");
-  ASSERT_TRUE(histogram != NULL);
-  std::unique_ptr<HistogramSamples> samples = histogram->SnapshotSamples();
-
-  samples->Subtract(*baseline);
-  EXPECT_EQ(0,samples->sum());
-
-  std::unique_ptr<SpellcheckCustomDictionary::Change> change(
-      new SpellcheckCustomDictionary::Change);
-  change->AddWord("bar");
-  change->AddWord("foo");
-  UpdateDictionaryFile(std::move(change), path);
-
-  // Load the dictionary again and it should have 2 entries.
-  EXPECT_EQ(2u, LoadDictionaryFile(path)->words.size());
-
-  histogram =
-      StatisticsRecorder::FindHistogram("SpellCheck.CustomWords");
-  ASSERT_TRUE(histogram != NULL);
-  std::unique_ptr<HistogramSamples> samples2 = histogram->SnapshotSamples();
-
-  samples2->Subtract(*baseline);
-  EXPECT_EQ(2,samples2->sum());
-}
-
 TEST_F(SpellcheckCustomDictionaryTest, HasWord) {
   SpellcheckService* spellcheck_service =
       SpellcheckServiceFactory::GetForContext(&profile_);
