@@ -16,10 +16,12 @@
 #include "base/time/time.h"
 #include "base/timer/timer.h"
 #include "base/trace_event/trace_event.h"
+#include "base/types/expected.h"
 #include "chrome/browser/ui/webui/ash/emoji/emoji_ui.h"
 #include "chrome/browser/ui/webui/ash/emoji/seal_utils.h"
 #include "chrome/grit/generated_resources.h"
 #include "chromeos/ash/components/emoji/emoji_search.h"
+#include "chromeos/ash/components/emoji/gif_tenor_api_fetcher.h"
 #include "components/prefs/pref_service.h"
 #include "components/prefs/scoped_user_pref_update.h"
 #include "content/public/browser/storage_partition.h"
@@ -58,9 +60,9 @@ void LogInsertEmoji(bool is_variant, int16_t search_length) {
 }
 
 void LogInsertGif(bool is_inserted) {
-  EmojiVariantType insert_value = is_inserted
-                                      ? EmojiVariantType::kEmojiPickerGifInserted
-                                      : EmojiVariantType::kEmojiPickerGifCopied;
+  EmojiVariantType insert_value =
+      is_inserted ? EmojiVariantType::kEmojiPickerGifInserted
+                  : EmojiVariantType::kEmojiPickerGifCopied;
   base::UmaHistogramEnumeration("InputMethod.SystemEmojiPicker.TriggerType",
                                 insert_value);
 }
@@ -79,14 +81,6 @@ void LogInsertionLatency(base::TimeDelta delay) {
                           delay);
 }
 
-void CopyEmojiToClipboard(const std::string& emoji_to_copy) {
-  if (base::FeatureList::IsEnabled(features::kImeSystemEmojiPickerClipboard)) {
-    auto clipboard = std::make_unique<ui::ScopedClipboardWriter>(
-        ui::ClipboardBuffer::kCopyPaste, nullptr);
-    clipboard->WriteText(base::UTF8ToUTF16(emoji_to_copy));
-  }
-}
-
 std::string BuildGifHTML(const GURL& gif) {
   // Referrer-Policy is used to prevent Tenor from getting information about
   // where the GIFs are being used.
@@ -125,6 +119,15 @@ std::string ConvertCategoryToPrefString(
   }
 }
 
+tenor::mojom::Status ConvertErrorToStatus(GifTenorApiFetcher::Error error) {
+  switch (error) {
+    case GifTenorApiFetcher::Error::kNetError:
+      return tenor::mojom::Status::kNetError;
+    case GifTenorApiFetcher::Error::kHttpError:
+      return tenor::mojom::Status::kHttpError;
+  }
+}
+
 }  // namespace
 
 // Used to insert a gif / emoji after WebUI handler is destroyed, before
@@ -230,7 +233,7 @@ class EmojiObserver : public InsertObserver {
     MarkInserted();
   }
 
-  void PerformCopy() override { CopyEmojiToClipboard(emoji_to_insert_); }
+  void PerformCopy() override {}
 
  private:
   std::string emoji_to_insert_;
@@ -290,7 +293,7 @@ EmojiPageHandler::EmojiPageHandler(
                             ->GetURLLoaderFactoryForBrowserProcess();
 }
 
-EmojiPageHandler::~EmojiPageHandler() {}
+EmojiPageHandler::~EmojiPageHandler() = default;
 
 void EmojiPageHandler::ShowUI() {
   auto embedder = webui_controller_->embedder();
@@ -310,11 +313,6 @@ void EmojiPageHandler::IsIncognitoTextField(
 
 void EmojiPageHandler::GetFeatureList(GetFeatureListCallback callback) {
   std::vector<emoji_picker::mojom::Feature> enabled_features;
-  if (base::FeatureList::IsEnabled(
-          features::kImeSystemEmojiPickerSearchExtension)) {
-    enabled_features.push_back(
-        emoji_picker::mojom::Feature::EMOJI_PICKER_SEARCH_EXTENSION);
-  }
   if (gif_support_enabled_) {
     enabled_features.push_back(
         emoji_picker::mojom::Feature::EMOJI_PICKER_GIF_SUPPORT);
@@ -339,27 +337,84 @@ void EmojiPageHandler::GetFeatureList(GetFeatureListCallback callback) {
 }
 
 void EmojiPageHandler::GetCategories(GetCategoriesCallback callback) {
-  gif_tenor_api_fetcher_.FetchCategories(std::move(callback),
-                                         url_loader_factory_);
+  GifTenorApiFetcher::FetchCategories(
+      url_loader_factory_,
+      base::BindOnce(
+          [](GetCategoriesCallback callback,
+             base::expected<std::vector<std::string>, GifTenorApiFetcher::Error>
+                 response) {
+            if (response.has_value()) {
+              std::move(callback).Run(tenor::mojom::Status::kHttpOk,
+                                      std::move(*response));
+            } else {
+              std::move(callback).Run(ConvertErrorToStatus(response.error()),
+                                      {});
+            }
+          },
+          std::move(callback)));
 }
 
 void EmojiPageHandler::GetFeaturedGifs(const std::optional<std::string>& pos,
                                        GetFeaturedGifsCallback callback) {
-  gif_tenor_api_fetcher_.FetchFeaturedGifs(std::move(callback),
-                                           url_loader_factory_, pos);
+  GifTenorApiFetcher::FetchFeaturedGifs(
+      url_loader_factory_, pos,
+      base::BindOnce(
+          [](GetFeaturedGifsCallback callback,
+             base::expected<tenor::mojom::PaginatedGifResponsesPtr,
+                            GifTenorApiFetcher::Error> response) {
+            if (response.has_value()) {
+              std::move(callback).Run(tenor::mojom::Status::kHttpOk,
+                                      std::move(*response));
+            } else {
+              std::move(callback).Run(
+                  ConvertErrorToStatus(response.error()),
+                  tenor::mojom::PaginatedGifResponses::New(
+                      "", std::vector<tenor::mojom::GifResponsePtr>{}));
+            }
+          },
+          std::move(callback)));
 }
 
 void EmojiPageHandler::SearchGifs(const std::string& query,
                                   const std::optional<std::string>& pos,
                                   SearchGifsCallback callback) {
-  gif_tenor_api_fetcher_.FetchGifSearch(std::move(callback),
-                                        url_loader_factory_, query, pos);
+  GifTenorApiFetcher::FetchGifSearch(
+      url_loader_factory_, query, pos,
+      /*limit=*/std::nullopt,
+      base::BindOnce(
+          [](SearchGifsCallback callback,
+             base::expected<tenor::mojom::PaginatedGifResponsesPtr,
+                            GifTenorApiFetcher::Error> response) {
+            if (response.has_value()) {
+              std::move(callback).Run(tenor::mojom::Status::kHttpOk,
+                                      std::move(*response));
+            } else {
+              std::move(callback).Run(
+                  ConvertErrorToStatus(response.error()),
+                  tenor::mojom::PaginatedGifResponses::New(
+                      "", std::vector<tenor::mojom::GifResponsePtr>{}));
+            }
+          },
+          std::move(callback)));
 }
 
 void EmojiPageHandler::GetGifsByIds(const std::vector<std::string>& ids,
                                     GetGifsByIdsCallback callback) {
-  gif_tenor_api_fetcher_.FetchGifsByIds(std::move(callback),
-                                        url_loader_factory_, ids);
+  GifTenorApiFetcher::FetchGifsByIds(
+      url_loader_factory_, ids,
+      base::BindOnce(
+          [](GetGifsByIdsCallback callback,
+             base::expected<std::vector<tenor::mojom::GifResponsePtr>,
+                            GifTenorApiFetcher::Error> response) {
+            if (response.has_value()) {
+              std::move(callback).Run(tenor::mojom::Status::kHttpOk,
+                                      std::move(*response));
+            } else {
+              std::move(callback).Run(ConvertErrorToStatus(response.error()),
+                                      {});
+            }
+          },
+          std::move(callback)));
 }
 
 void EmojiPageHandler::InsertEmoji(const std::string& emoji_to_insert,
@@ -375,11 +430,9 @@ void EmojiPageHandler::InsertEmoji(const std::string& emoji_to_insert,
       IMEBridge::Get()->GetInputContextHandler()->GetInputMethod();
   if (!input_method) {
     DLOG(WARNING) << "no input_method found";
-    CopyEmojiToClipboard(emoji_to_insert);
     return;
   }
   if (no_text_field_) {
-    CopyEmojiToClipboard(emoji_to_insert);
     return;
   }
 
