@@ -26,4 +26,16 @@ const char kOrcaMagicBoostParamKey[] = "magic-boost";
 
 const char kOrcaHostLanguageParamKey[] = "hl";
 
+const char kChromeUILobsterURL[] = "chrome-untrusted://mako/lobster.html";
+
+const char kLobsterPromptParamKey[] = "prompt";
+
+const char kLobsterModeParamKey[] = "mode";
+
+const char kLobsterDownloadModeValue[] = "download";
+
+const char kLobsterInsertModeValue[] = "insert";
+
+const char kLobsterFeedbackEnabledParamKey[] = "feedback-enabled";
+
 }  // namespace ash
