@@ -4,8 +4,11 @@
 
 #include "chrome/browser/ui/webui/ash/settings/pages/about/about_section.h"
 
+#include <array>
+
 #include "ash/constants/ash_features.h"
 #include "base/command_line.h"
+#include "base/containers/span.h"
 #include "base/feature_list.h"
 #include "base/functional/callback_helpers.h"
 #include "base/i18n/message_formatter.h"
@@ -25,7 +28,6 @@
 #include "chrome/browser/ui/webui/management/management_ui.h"
 #include "chrome/browser/ui/webui/settings/about_handler.h"
 #include "chrome/browser/ui/webui/version/version_ui.h"
-#include "chrome/browser/ui/webui/webui_util.h"
 #include "chrome/common/channel_info.h"
 #include "chrome/common/pref_names.h"
 #include "chrome/common/url_constants.h"
@@ -38,11 +40,12 @@
 #include "components/signin/public/identity_manager/tribool.h"
 #include "components/strings/grit/components_branded_strings.h"
 #include "components/strings/grit/components_strings.h"
-#include "components/version_ui/version_ui_constants.h"
+#include "components/webui/version/version_ui_constants.h"
 #include "content/public/browser/web_ui_data_source.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/base/webui/web_ui_util.h"
 #include "ui/chromeos/devicetype_utils.h"
+#include "ui/webui/webui_util.h"
 
 namespace ash::settings {
 
@@ -56,15 +59,11 @@ using ::chromeos::settings::mojom::Subpage;
 
 namespace {
 
-const std::vector<SearchConcept>& GetAboutSearchConcepts() {
-  const bool kIsRevampEnabled =
-      ash::features::IsOsSettingsRevampWayfindingEnabled();
-
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetAboutSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_ABOUT_CHROME_OS_DETAILED_BUILD,
        mojom::kDetailedBuildInfoSubpagePath,
-       kIsRevampEnabled ? mojom::SearchResultIcon::kDetailedBuild
-                        : mojom::SearchResultIcon::kChrome,
+       mojom::SearchResultIcon::kDetailedBuild,
        mojom::SearchResultDefaultRank::kMedium,
        mojom::SearchResultType::kSubpage,
        {.subpage = mojom::Subpage::kDetailedBuildInfo}},
@@ -82,52 +81,45 @@ const std::vector<SearchConcept>& GetAboutSearchConcepts() {
        {.section = mojom::Section::kAboutChromeOs}},
       {IDS_OS_SETTINGS_TAG_ABOUT_CHROME_OS_CHANNEL,
        mojom::kDetailedBuildInfoSubpagePath,
-       kIsRevampEnabled ? mojom::SearchResultIcon::kDetailedBuild
-                        : mojom::SearchResultIcon::kChrome,
+       mojom::SearchResultIcon::kDetailedBuild,
        mojom::SearchResultDefaultRank::kMedium,
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kChangeChromeChannel}},
       {IDS_OS_SETTINGS_TAG_ABOUT_CHROME_OS_COPY_DETAILED_BUILD,
        mojom::kDetailedBuildInfoSubpagePath,
-       kIsRevampEnabled ? mojom::SearchResultIcon::kDetailedBuild
-                        : mojom::SearchResultIcon::kChrome,
+       mojom::SearchResultIcon::kDetailedBuild,
        mojom::SearchResultDefaultRank::kMedium,
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kCopyDetailedBuildInfo}},
       {IDS_OS_SETTINGS_TAG_ABOUT_OS_UPDATE,
        mojom::kAboutChromeOsSectionPath,
-       kIsRevampEnabled ? mojom::SearchResultIcon::kCheckForUpdate
-                        : mojom::SearchResultIcon::kChrome,
+       mojom::SearchResultIcon::kCheckForUpdate,
        mojom::SearchResultDefaultRank::kMedium,
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kCheckForOsUpdate}},
       {IDS_OS_SETTINGS_TAG_ABOUT_HELP,
        mojom::kAboutChromeOsSectionPath,
-       kIsRevampEnabled ? mojom::SearchResultIcon::kHelp
-                        : mojom::SearchResultIcon::kChrome,
+       mojom::SearchResultIcon::kHelp,
        mojom::SearchResultDefaultRank::kMedium,
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kGetHelpWithChromeOs}},
       {IDS_OS_SETTINGS_TAG_ABOUT_RELEASE_NOTES,
        mojom::kAboutChromeOsSectionPath,
-       kIsRevampEnabled ? mojom::SearchResultIcon::kReleaseNotes
-                        : mojom::SearchResultIcon::kChrome,
+       mojom::SearchResultIcon::kReleaseNotes,
        mojom::SearchResultDefaultRank::kMedium,
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kSeeWhatsNew},
        {IDS_OS_SETTINGS_TAG_ABOUT_RELEASE_NOTES_ALT1,
         SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetDiagnosticsAppSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetDiagnosticsAppSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_ABOUT_DIAGNOSTICS,
        mojom::kAboutChromeOsSectionPath,
-       ash::features::IsOsSettingsRevampWayfindingEnabled()
-           ? mojom::SearchResultIcon::kDiagnostics
-           : mojom::SearchResultIcon::kChrome,
+       mojom::SearchResultIcon::kDiagnostics,
        mojom::SearchResultDefaultRank::kMedium,
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kDiagnostics},
@@ -136,25 +128,23 @@ const std::vector<SearchConcept>& GetDiagnosticsAppSearchConcepts() {
         IDS_OS_SETTINGS_TAG_ABOUT_DIAGNOSTICS_ALT3,
         IDS_OS_SETTINGS_TAG_ABOUT_DIAGNOSTICS_ALT4, SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetFirmwareUpdatesAppSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetFirmwareUpdatesAppSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_ABOUT_FIRMWARE_UPDATES,
        mojom::kAboutChromeOsSectionPath,
-       ash::features::IsOsSettingsRevampWayfindingEnabled()
-           ? mojom::SearchResultIcon::kFirmwareUpdates
-           : mojom::SearchResultIcon::kChrome,
+       mojom::SearchResultIcon::kFirmwareUpdates,
        mojom::SearchResultDefaultRank::kMedium,
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kFirmwareUpdates}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetDeviceNameSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetDeviceNameSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_ABOUT_DEVICE_NAME,
        mojom::kDetailedBuildInfoSubpagePath,
        mojom::SearchResultIcon::kChrome,
@@ -163,12 +153,12 @@ const std::vector<SearchConcept>& GetDeviceNameSearchConcepts() {
        {.setting = mojom::Setting::kChangeDeviceName},
        {IDS_OS_SETTINGS_TAG_ABOUT_DEVICE_NAME_ALT1, SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
 #if BUILDFLAG(GOOGLE_CHROME_BRANDING)
-const std::vector<SearchConcept>& GetAboutTermsOfServiceSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetAboutTermsOfServiceSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_ABOUT_TERMS_OF_SERVICE,
        mojom::kAboutChromeOsSectionPath,
        mojom::SearchResultIcon::kChrome,
@@ -176,11 +166,11 @@ const std::vector<SearchConcept>& GetAboutTermsOfServiceSearchConcepts() {
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kTermsOfService}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetAboutReportIssueSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetAboutReportIssueSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_ABOUT_REPORT_ISSUE,
        mojom::kAboutChromeOsSectionPath,
        mojom::SearchResultIcon::kChrome,
@@ -190,15 +180,15 @@ const std::vector<SearchConcept>& GetAboutReportIssueSearchConcepts() {
        {IDS_OS_SETTINGS_TAG_ABOUT_REPORT_ISSUE_ALT1,
         IDS_SETTINGS_ABOUT_PAGE_SEND_FEEDBACK, SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 #endif  // BUILDFLAG(GOOGLE_CHROME_BRANDING)
 
 // Returns the link to the safety info for the device (if it exists).
 std::string GetSafetyInfoLink() {
-  const std::vector<std::string> board =
-      base::SplitString(base::SysInfo::GetLsbReleaseBoard(), "-",
-                        base::TRIM_WHITESPACE, base::SPLIT_WANT_NONEMPTY);
+  const std::vector<std::string_view> board =
+      base::SplitStringPiece(base::SysInfo::GetLsbReleaseBoard(), "-",
+                             base::TRIM_WHITESPACE, base::SPLIT_WANT_NONEMPTY);
   if (board[0] == "nocturne") {
     return chrome::kChromeUISafetyPixelSlateURL;
   }
@@ -223,12 +213,7 @@ AboutSection::AboutSection(Profile* profile,
                            PrefService* pref_service)
     : OsSettingsSection(profile, search_tag_registry),
       pref_service_(pref_service),
-      crostini_subsection_(
-          ash::features::IsOsSettingsRevampWayfindingEnabled()
-              ? std::make_optional<CrostiniSection>(profile,
-                                                    search_tag_registry,
-                                                    pref_service)
-              : std::nullopt) {
+      crostini_subsection_(profile, search_tag_registry, pref_service) {
   SearchTagRegistry::ScopedTagUpdater updater = registry()->StartUpdate();
   updater.AddSearchTags(GetAboutSearchConcepts());
 
@@ -258,9 +243,6 @@ AboutSection::AboutSection(Profile* profile,
 AboutSection::~AboutSection() = default;
 
 void AboutSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
-  const bool kIsRevampEnabled =
-      ash::features::IsOsSettingsRevampWayfindingEnabled();
-
   // Top level About page strings.
   webui::LocalizedString kLocalizedStrings[] = {
       {"aboutProductLogoAlt", IDS_SHORT_PRODUCT_LOGO_ALT_TEXT},
@@ -268,16 +250,15 @@ void AboutSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
       {"aboutReportAnIssue", IDS_SETTINGS_ABOUT_PAGE_REPORT_AN_ISSUE},
       {"aboutSendFeedback", IDS_SETTINGS_ABOUT_PAGE_SEND_FEEDBACK},
       {"aboutSendFeedbackDescription",
-       IDS_OS_SETTINGS_REVAMP_SEND_FEEDBACK_DESCRIPTION},
+       IDS_OS_SETTINGS_SEND_FEEDBACK_DESCRIPTION},
 #endif
       {"aboutDiagnostics", IDS_SETTINGS_ABOUT_PAGE_DIAGNOSTICS},
-      {"aboutDiagnosticseDescription",
-       IDS_OS_SETTINGS_REVAMP_DIAGNOSTICS_DESCRIPTION},
+      {"aboutDiagnosticseDescription", IDS_OS_SETTINGS_DIAGNOSTICS_DESCRIPTION},
       {"aboutFirmwareUpdates", IDS_SETTINGS_ABOUT_PAGE_FIRMWARE_UPDATES},
       {"aboutFirmwareUpToDateDescription",
-       IDS_OS_SETTINGS_REVAMP_FIRMWARE_UP_TO_DATE_DESCRIPTION},
+       IDS_OS_SETTINGS_FIRMWARE_UP_TO_DATE_DESCRIPTION},
       {"aboutFirmwareUpdateAvailableDescription",
-       IDS_OS_SETTINGS_REVAMP_FIRMWARE_UPDATE_AVAILABLE_DESCRIPTION},
+       IDS_OS_SETTINGS_FIRMWARE_UPDATE_AVAILABLE_DESCRIPTION},
       {"aboutRelaunch", IDS_SETTINGS_ABOUT_PAGE_RELAUNCH},
       {"aboutUpgradeCheckStarted", IDS_SETTINGS_ABOUT_UPGRADE_CHECK_STARTED},
       {"aboutUpgradeNotUpToDate", IDS_SETTINGS_UPGRADE_NOT_UP_TO_DATE},
@@ -383,16 +364,14 @@ void AboutSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
       {"aboutOsPageTitle", IDS_SETTINGS_ABOUT_OS},
       {"aboutChromeOsMenuItemDescription",
        IDS_OS_SETTINGS_ABOUT_CHROMEOS_MENU_ITEM_DESCRIPTION},
-      {"aboutGetHelpUsingChromeOs",
-       kIsRevampEnabled ? IDS_OS_SETTINGS_REVAMP_GET_HELP_USING_CHROME_OS
-                        : IDS_SETTINGS_GET_HELP_USING_CHROME_OS},
+      {"aboutGetHelpUsingChromeOs", IDS_OS_SETTINGS_GET_HELP_USING_CHROME_OS},
       {"aboutGetHelpDescription",
-       IDS_OS_SETTINGS_REVAMP_GET_HELP_USING_CHROME_OS_DESCRIPTION},
+       IDS_OS_SETTINGS_GET_HELP_USING_CHROME_OS_DESCRIPTION},
       {"aboutOsProductTitle", IDS_PRODUCT_OS_NAME},
       {"aboutReleaseNotesOffline", IDS_SETTINGS_ABOUT_PAGE_RELEASE_NOTES},
       {"aboutShowReleaseNotes", IDS_SETTINGS_ABOUT_PAGE_SHOW_RELEASE_NOTES},
       {"aboutShowReleaseNotesDescription",
-       IDS_OS_SETTINGS_REVAMP_ABOUT_PAGE_SHOW_RELEASE_NOTES_DESCRIPTION},
+       IDS_OS_SETTINGS_ABOUT_PAGE_SHOW_RELEASE_NOTES_DESCRIPTION},
       {"aboutManagedEndOfLifeSubtitle",
        IDS_SETTINGS_ABOUT_PAGE_MANAGED_END_OF_LIFE_SUBTITLE},
       {"aboutUpgradeTryAgain", IDS_SETTINGS_UPGRADE_TRY_AGAIN},
@@ -527,10 +506,7 @@ void AboutSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
                          base::UTF8ToUTF16(safetyInfoLink));
 #endif
 
-  // Crostini subsection exists only when OsSettingsRevampWayfinding is enabled.
-  if (crostini_subsection_) {
-    crostini_subsection_->AddLoadTimeData(html_source);
-  }
+  crostini_subsection_.AddLoadTimeData(html_source);
 }
 
 void AboutSection::AddHandlers(content::WebUI* web_ui) {
@@ -540,10 +516,7 @@ void AboutSection::AddHandlers(content::WebUI* web_ui) {
     web_ui->AddMessageHandler(std::make_unique<DeviceNameHandler>());
   }
 
-  // Crostini subsection exists only when OsSettingsRevampWayfinding is enabled.
-  if (crostini_subsection_) {
-    crostini_subsection_->AddHandlers(web_ui);
-  }
+  crostini_subsection_.AddHandlers(web_ui);
 }
 
 int AboutSection::GetSectionNameMessageId() const {
@@ -589,9 +562,7 @@ void AboutSection::RegisterHierarchy(HierarchyGenerator* generator) const {
   RegisterNestedSettingBulk(mojom::Subpage::kDetailedBuildInfo,
                             kDetailedBuildInfoSettings, generator);
 
-  if (crostini_subsection_) {
-    crostini_subsection_->RegisterHierarchy(generator);
-  }
+  crostini_subsection_.RegisterHierarchy(generator);
 }
 
 bool AboutSection::ShouldShowAUToggle(user_manager::User* active_user) {
@@ -612,13 +583,9 @@ bool AboutSection::ShouldShowAUToggle(user_manager::User* active_user) {
   const AccountInfo account_info =
       identity_manager->FindExtendedAccountInfoByGaiaId(account_id.GetGaiaId());
   // If the user falls under New Deal..
-  if (account_info.capabilities.can_toggle_auto_updates() ==
-      signin::Tribool::kTrue) {
-    // Show toggle based on user's capabilities.
-    return features::IsConsumerAutoUpdateToggleAllowed();
-  }
-
-  return false;
+  // Show toggle based on user's capabilities.
+  return account_info.capabilities.can_toggle_auto_updates() ==
+         signin::Tribool::kTrue;
 }
 
 #if BUILDFLAG(GOOGLE_CHROME_BRANDING)
