@@ -2,13 +2,10 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifdef UNSAFE_BUFFERS_BUILD
-// TODO(crbug.com/40285824): Remove this and convert code to safer constructs.
-#pragma allow_unsafe_buffers
-#endif
-
 #include "chrome/browser/ui/webui/ash/settings/pages/internet/internet_section.h"
 
+#include <array>
+
 #include "ash/constants/ash_features.h"
 #include "ash/public/cpp/hotspot_config_service.h"
 #include "ash/public/cpp/network_config_service.h"
@@ -16,15 +13,14 @@
 #include "ash/webui/network_ui/traffic_counters_resource_provider.h"
 #include "ash/webui/settings/public/constants/routes.mojom.h"
 #include "base/containers/contains.h"
+#include "base/containers/span.h"
 #include "base/functional/bind.h"
 #include "base/metrics/histogram_functions.h"
-#include "base/no_destructor.h"
 #include "base/strings/stringprintf.h"
 #include "chrome/browser/ui/webui/ash/cellular_setup/cellular_setup_localized_strings_provider.h"
 #include "chrome/browser/ui/webui/ash/settings/pages/internet/internet_handler.h"
 #include "chrome/browser/ui/webui/ash/settings/search/search_tag_registry.h"
 #include "chrome/browser/ui/webui/extension_control_handler.h"
-#include "chrome/browser/ui/webui/webui_util.h"
 #include "chrome/common/chrome_features.h"
 #include "chrome/common/url_constants.h"
 #include "chrome/common/webui_url_constants.h"
@@ -40,6 +36,7 @@
 #include "ui/chromeos/devicetype_utils.h"
 #include "ui/chromeos/strings/grit/ui_chromeos_strings.h"
 #include "ui/chromeos/strings/network/network_element_localized_strings_provider.h"
+#include "ui/webui/webui_util.h"
 
 namespace ash::network_config {
 namespace mojom = chromeos::network_config::mojom;
@@ -77,8 +74,8 @@ enum class NetworkDiscoveryState {
   kMaxValue = kNewNetwork,
 };
 
-const std::vector<SearchConcept>& GetNetworkSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetNetworkSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_NETWORK_SETTINGS,
        mojom::kNetworkSectionPath,
        mojom::SearchResultIcon::kWifi,
@@ -87,11 +84,11 @@ const std::vector<SearchConcept>& GetNetworkSearchConcepts() {
        {.section = mojom::Section::kNetwork},
        {IDS_OS_SETTINGS_TAG_NETWORK_SETTINGS_ALT1, SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetEthernetConnectedSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetEthernetConnectedSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_ETHERNET_CONFIGURE,
        mojom::kEthernetDetailsSubpagePath,
        mojom::SearchResultIcon::kEthernet,
@@ -131,11 +128,11 @@ const std::vector<SearchConcept>& GetEthernetConnectedSearchConcepts() {
         IDS_OS_SETTINGS_TAG_PROXY_ALT3, IDS_OS_SETTINGS_TAG_PROXY_ALT4,
         SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetEthernetNotConnectedSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetEthernetNotConnectedSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_ETHERNET,
        mojom::kNetworkSectionPath,
        mojom::SearchResultIcon::kEthernet,
@@ -143,11 +140,11 @@ const std::vector<SearchConcept>& GetEthernetNotConnectedSearchConcepts() {
        mojom::SearchResultType::kSection,
        {.section = mojom::Section::kNetwork}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetWifiSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetWifiSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_WIFI,
        mojom::kWifiNetworksSubpagePath,
        mojom::SearchResultIcon::kWifi,
@@ -164,11 +161,11 @@ const std::vector<SearchConcept>& GetWifiSearchConcepts() {
        {IDS_OS_SETTINGS_TAG_KNOWN_NETWORKS_ALT1,
         IDS_OS_SETTINGS_TAG_KNOWN_NETWORKS_ALT2, SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetWifiOnSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetWifiOnSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_WIFI_TURN_OFF,
        mojom::kWifiNetworksSubpagePath,
        mojom::SearchResultIcon::kWifi,
@@ -183,11 +180,11 @@ const std::vector<SearchConcept>& GetWifiOnSearchConcepts() {
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kWifiAddNetwork}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetWifiOffSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetWifiOffSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_WIFI_TURN_ON,
        mojom::kWifiNetworksSubpagePath,
        mojom::SearchResultIcon::kWifi,
@@ -196,11 +193,11 @@ const std::vector<SearchConcept>& GetWifiOffSearchConcepts() {
        {.setting = mojom::Setting::kWifiOnOff},
        {IDS_OS_SETTINGS_TAG_WIFI_TURN_ON_ALT1, SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetWifiConnectedSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetWifiConnectedSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_DISCONNECT_WIFI,
        mojom::kWifiDetailsSubpagePath,
        mojom::SearchResultIcon::kWifi,
@@ -256,11 +253,11 @@ const std::vector<SearchConcept>& GetWifiConnectedSearchConcepts() {
        {IDS_OS_SETTINGS_TAG_AUTO_CONNECT_NETWORK_ALT1,
         SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetWifiMeteredSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetWifiMeteredSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_SETTINGS_INTERNET_NETWORK_METERED,
        mojom::kWifiDetailsSubpagePath,
        mojom::SearchResultIcon::kWifi,
@@ -268,11 +265,11 @@ const std::vector<SearchConcept>& GetWifiMeteredSearchConcepts() {
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kWifiMetered}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetWifiHiddenSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetWifiHiddenSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_HIDDEN_NETWORK,
        mojom::kWifiDetailsSubpagePath,
        mojom::SearchResultIcon::kWifi,
@@ -281,11 +278,11 @@ const std::vector<SearchConcept>& GetWifiHiddenSearchConcepts() {
        {.setting = mojom::Setting::kWifiHidden},
        {IDS_OS_SETTINGS_TAG_HIDDEN_NETWORK_ALT1, SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetCellularSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetCellularSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_CELLULAR,
        mojom::kCellularNetworksSubpagePath,
        mojom::SearchResultIcon::kCellular,
@@ -308,11 +305,11 @@ const std::vector<SearchConcept>& GetCellularSearchConcepts() {
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kCellularRoaming}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetCellularOnSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetCellularOnSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_CELLULAR_TURN_OFF,
        mojom::kNetworkSectionPath,
        mojom::SearchResultIcon::kCellular,
@@ -321,11 +318,11 @@ const std::vector<SearchConcept>& GetCellularOnSearchConcepts() {
        {.setting = mojom::Setting::kMobileOnOff},
        {IDS_OS_SETTINGS_TAG_CELLULAR_TURN_OFF_ALT1, SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetCellularOffSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetCellularOffSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_CELLULAR_TURN_ON,
        mojom::kNetworkSectionPath,
        mojom::SearchResultIcon::kCellular,
@@ -334,11 +331,11 @@ const std::vector<SearchConcept>& GetCellularOffSearchConcepts() {
        {.setting = mojom::Setting::kMobileOnOff},
        {IDS_OS_SETTINGS_TAG_CELLULAR_TURN_ON_ALT1, SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetCellularConnectedSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetCellularConnectedSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_CELLULAR_DISCONNECT,
        mojom::kCellularDetailsSubpagePath,
        mojom::SearchResultIcon::kCellular,
@@ -380,11 +377,11 @@ const std::vector<SearchConcept>& GetCellularConnectedSearchConcepts() {
        {IDS_OS_SETTINGS_TAG_AUTO_CONNECT_NETWORK_ALT1,
         SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetCellularAddESimSearchTerms() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetCellularAddESimSearchTerms() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_ADD_ESIM,
        mojom::kMobileDataNetworksSubpagePath,
        mojom::SearchResultIcon::kCellular,
@@ -394,13 +391,13 @@ const std::vector<SearchConcept>& GetCellularAddESimSearchTerms() {
        {IDS_OS_SETTINGS_TAG_ADD_ESIM_ALT1, IDS_OS_SETTINGS_TAG_ADD_ESIM_ALT2,
         SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>&
+base::span<const SearchConcept>
 GeActiveCellularNetworkApnSettingsSearchConcepts() {
   if (ash::features::IsApnRevampEnabled()) {
-    static const base::NoDestructor<std::vector<SearchConcept>> tags(
+    static constexpr auto tags = std::to_array<SearchConcept>(
         {{IDS_OS_SETTINGS_TAG_CELLULAR_APN_SETTINGS,
           mojom::kApnSubpagePath,
           mojom::SearchResultIcon::kCellular,
@@ -416,10 +413,10 @@ GeActiveCellularNetworkApnSettingsSearchConcepts() {
           mojom::SearchResultType::kSetting,
           {.setting = mojom::Setting::kCellularAddApn},
           {IDS_OS_SETTINGS_TAG_ADD_APN_ALT1, SearchConcept::kAltTagEnd}}});
-    return *tags;
+    return tags;
   }
 
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_CELLULAR_APN,
        mojom::kCellularDetailsSubpagePath,
        mojom::SearchResultIcon::kCellular,
@@ -427,12 +424,12 @@ GeActiveCellularNetworkApnSettingsSearchConcepts() {
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kCellularApn}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>&
+base::span<const SearchConcept>
 GetCellularPrimaryIsNonPolicyESimSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_CELLULAR_REMOVE_PROFILE,
        mojom::kCellularDetailsSubpagePath,
        mojom::SearchResultIcon::kCellular,
@@ -450,11 +447,11 @@ GetCellularPrimaryIsNonPolicyESimSearchConcepts() {
        {IDS_OS_SETTINGS_TAG_CELLULAR_RENAME_PROFILE_ALT1,
         SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetCellularMeteredSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetCellularMeteredSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_SETTINGS_INTERNET_NETWORK_METERED,
        mojom::kCellularDetailsSubpagePath,
        mojom::SearchResultIcon::kCellular,
@@ -462,91 +459,102 @@ const std::vector<SearchConcept>& GetCellularMeteredSearchConcepts() {
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kCellularMetered}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetInstantTetheringSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags([] {
-    SearchConcept instant_tethering_concept{
-        IDS_OS_SETTINGS_TAG_INSTANT_MOBILE_NETWORKS,
-        mojom::kMobileDataNetworksSubpagePath,
-        mojom::SearchResultIcon::kInstantTethering,
-        mojom::SearchResultDefaultRank::kMedium,
-        mojom::SearchResultType::kSubpage,
-        {.subpage = mojom::Subpage::kMobileDataNetworks},
-    };
+base::span<const SearchConcept> GetInstantTetheringSearchConcepts() {
+  auto make_concepts = [](bool revamped) {
+    return std::to_array<SearchConcept>({
+        {IDS_OS_SETTINGS_TAG_INSTANT_MOBILE_NETWORKS,
+         mojom::kMobileDataNetworksSubpagePath,
+         mojom::SearchResultIcon::kInstantTethering,
+         mojom::SearchResultDefaultRank::kMedium,
+         mojom::SearchResultType::kSubpage,
+         {.subpage = mojom::Subpage::kMobileDataNetworks},
+         {revamped ? IDS_OS_SETTINGS_TAG_INSTANT_MOBILE_NETWORKS_ALT1
+                   : SearchConcept::kAltTagEnd,
+          SearchConcept::kAltTagEnd}},
+    });
+  };
 
-    if (ash::features::IsInstantHotspotRebrandEnabled()) {
-      instant_tethering_concept.alt_tag_ids[0] =
-          IDS_OS_SETTINGS_TAG_INSTANT_MOBILE_NETWORKS_ALT1;
-      instant_tethering_concept.alt_tag_ids[1] = SearchConcept::kAltTagEnd;
-    }
-
-    return std::vector<SearchConcept>{instant_tethering_concept};
-  }());
-  return *tags;
+  static constexpr auto revamped_tags = make_concepts(true);
+  static constexpr auto original_tags = make_concepts(false);
+  return ash::features::IsInstantHotspotRebrandEnabled() ? revamped_tags
+                                                         : original_tags;
 }
 
-const std::vector<SearchConcept>& GetInstantTetheringOnSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
-      {features::IsInstantHotspotRebrandEnabled()
-           ? IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_OFF
-           : IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_OFF_LEGACY,
-       mojom::kMobileDataNetworksSubpagePath,
-       mojom::SearchResultIcon::kInstantTethering,
-       mojom::SearchResultDefaultRank::kMedium,
-       mojom::SearchResultType::kSetting,
-       {.setting = mojom::Setting::kInstantTetheringOnOff},
-       {features::IsInstantHotspotRebrandEnabled()
-            ? IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_OFF_ALT1
-            : IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_OFF_ALT1_LEGACY,
-        SearchConcept::kAltTagEnd}},
-  });
-  return *tags;
+base::span<const SearchConcept> GetInstantTetheringOnSearchConcepts() {
+  auto make_concepts = [](bool revamped) {
+    return std::to_array<SearchConcept>({
+        {revamped ? IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_OFF
+                  : IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_OFF_LEGACY,
+         mojom::kMobileDataNetworksSubpagePath,
+         mojom::SearchResultIcon::kInstantTethering,
+         mojom::SearchResultDefaultRank::kMedium,
+         mojom::SearchResultType::kSetting,
+         {.setting = mojom::Setting::kInstantTetheringOnOff},
+         {revamped ? IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_OFF_ALT1
+                   : IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_OFF_ALT1_LEGACY,
+          SearchConcept::kAltTagEnd}},
+    });
+  };
+
+  static constexpr auto revamped_tags = make_concepts(true);
+  static constexpr auto original_tags = make_concepts(false);
+  return ash::features::IsInstantHotspotRebrandEnabled() ? revamped_tags
+                                                         : original_tags;
 }
 
-const std::vector<SearchConcept>& GetInstantTetheringOffSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
-      {features::IsInstantHotspotRebrandEnabled()
-           ? IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_ON
-           : IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_ON_LEGACY,
-       mojom::kMobileDataNetworksSubpagePath,
-       mojom::SearchResultIcon::kInstantTethering,
-       mojom::SearchResultDefaultRank::kMedium,
-       mojom::SearchResultType::kSetting,
-       {.setting = mojom::Setting::kInstantTetheringOnOff},
-       {features::IsInstantHotspotRebrandEnabled()
-            ? IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_ON_ALT1
-            : IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_ON_ALT1_LEGACY,
-        SearchConcept::kAltTagEnd}},
-  });
-  return *tags;
+base::span<const SearchConcept> GetInstantTetheringOffSearchConcepts() {
+  auto make_concepts = [](bool revamped) {
+    return std::to_array<SearchConcept>({
+        {revamped ? IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_ON
+                  : IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_ON_LEGACY,
+         mojom::kMobileDataNetworksSubpagePath,
+         mojom::SearchResultIcon::kInstantTethering,
+         mojom::SearchResultDefaultRank::kMedium,
+         mojom::SearchResultType::kSetting,
+         {.setting = mojom::Setting::kInstantTetheringOnOff},
+         {revamped ? IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_ON_ALT1
+                   : IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_TURN_ON_ALT1_LEGACY,
+          SearchConcept::kAltTagEnd}},
+    });
+  };
+
+  static constexpr auto revamped_tags = make_concepts(true);
+  static constexpr auto original_tags = make_concepts(false);
+  return ash::features::IsInstantHotspotRebrandEnabled() ? revamped_tags
+                                                         : original_tags;
 }
 
-const std::vector<SearchConcept>& GetInstantTetheringConnectedSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
-      {features::IsInstantHotspotRebrandEnabled()
-           ? IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_DISCONNECT
-           : IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_DISCONNECT_LEGACY,
-       mojom::kTetherDetailsSubpagePath,
-       mojom::SearchResultIcon::kInstantTethering,
-       mojom::SearchResultDefaultRank::kMedium,
-       mojom::SearchResultType::kSetting,
-       {.setting = mojom::Setting::kDisconnectTetherNetwork}},
-      {features::IsInstantHotspotRebrandEnabled()
-           ? IDS_OS_SETTINGS_TAG_INSTANT_TETHERING
-           : IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_LEGACY,
-       mojom::kTetherDetailsSubpagePath,
-       mojom::SearchResultIcon::kInstantTethering,
-       mojom::SearchResultDefaultRank::kMedium,
-       mojom::SearchResultType::kSubpage,
-       {.subpage = mojom::Subpage::kTetherDetails}},
-  });
-  return *tags;
+base::span<const SearchConcept> GetInstantTetheringConnectedSearchConcepts() {
+  auto make_concepts = [](bool revamped) {
+    return std::to_array<SearchConcept>({
+        {revamped ? IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_DISCONNECT
+                  : IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_DISCONNECT_LEGACY,
+         mojom::kTetherDetailsSubpagePath,
+         mojom::SearchResultIcon::kInstantTethering,
+         mojom::SearchResultDefaultRank::kMedium,
+         mojom::SearchResultType::kSetting,
+         {.setting = mojom::Setting::kDisconnectTetherNetwork}},
+        {revamped ? IDS_OS_SETTINGS_TAG_INSTANT_TETHERING
+                  : IDS_OS_SETTINGS_TAG_INSTANT_TETHERING_LEGACY,
+         mojom::kTetherDetailsSubpagePath,
+         mojom::SearchResultIcon::kInstantTethering,
+         mojom::SearchResultDefaultRank::kMedium,
+         mojom::SearchResultType::kSubpage,
+         {.subpage = mojom::Subpage::kTetherDetails}},
+    });
+  };
+
+  static constexpr auto revamped_tags = make_concepts(true);
+  static constexpr auto original_tags = make_concepts(false);
+  return ash::features::IsInstantHotspotRebrandEnabled() ? revamped_tags
+                                                         : original_tags;
 }
 
-const std::vector<SearchConcept>& GetVpnConnectedSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetVpnConnectedSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_VPN,
        mojom::kVpnDetailsSubpagePath,
        mojom::SearchResultIcon::kWifi,
@@ -554,11 +562,11 @@ const std::vector<SearchConcept>& GetVpnConnectedSearchConcepts() {
        mojom::SearchResultType::kSubpage,
        {.subpage = mojom::Subpage::kVpnDetails}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetHotspotSubpageSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetHotspotSubpageSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_HOTSPOT,
        mojom::kHotspotSubpagePath,
        mojom::SearchResultIcon::kHotspot,
@@ -566,11 +574,11 @@ const std::vector<SearchConcept>& GetHotspotSubpageSearchConcepts() {
        mojom::SearchResultType::kSubpage,
        {.subpage = mojom::Subpage::kHotspotDetails}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetHotspotOnSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetHotspotOnSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_HOTSPOT_TURN_OFF,
        mojom::kHotspotSubpagePath,
        mojom::SearchResultIcon::kHotspot,
@@ -578,11 +586,11 @@ const std::vector<SearchConcept>& GetHotspotOnSearchConcepts() {
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kHotspotOnOff}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetHotspotOffSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetHotspotOffSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_HOTSPOT_TURN_ON,
        mojom::kHotspotSubpagePath,
        mojom::SearchResultIcon::kHotspot,
@@ -590,11 +598,11 @@ const std::vector<SearchConcept>& GetHotspotOffSearchConcepts() {
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kHotspotOnOff}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetHotspotAutoDisabledSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetHotspotAutoDisabledSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_HOTSPOT_AUTO_DISABLED,
        mojom::kHotspotSubpagePath,
        mojom::SearchResultIcon::kHotspot,
@@ -605,21 +613,21 @@ const std::vector<SearchConcept>& GetHotspotAutoDisabledSearchConcepts() {
         IDS_OS_SETTINGS_TAG_HOTSPOT_AUTO_DISABLED_ALT2,
         SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<mojom::Setting>& GetEthernetDetailsSettings() {
-  static const base::NoDestructor<std::vector<mojom::Setting>> settings({
+base::span<const mojom::Setting> GetEthernetDetailsSettings() {
+  static constexpr auto settings = std::to_array({
       mojom::Setting::kConfigureEthernet,
       mojom::Setting::kEthernetAutoConfigureIp,
       mojom::Setting::kEthernetDns,
       mojom::Setting::kEthernetProxy,
   });
-  return *settings;
+  return settings;
 }
 
-const std::vector<mojom::Setting>& GetWifiDetailsSettings() {
-  static const base::NoDestructor<std::vector<mojom::Setting>> settings({
+base::span<const mojom::Setting> GetWifiDetailsSettings() {
+  static constexpr auto settings = std::to_array({
       mojom::Setting::kDisconnectWifiNetwork,
       mojom::Setting::kPreferWifiNetwork,
       mojom::Setting::kForgetWifiNetwork,
@@ -630,11 +638,11 @@ const std::vector<mojom::Setting>& GetWifiDetailsSettings() {
       mojom::Setting::kWifiMetered,
       mojom::Setting::kWifiHidden,
   });
-  return *settings;
+  return settings;
 }
 
-const std::vector<mojom::Setting>& GetCellularDetailsSettings() {
-  static const base::NoDestructor<std::vector<mojom::Setting>> settings({
+base::span<const mojom::Setting> GetCellularDetailsSettings() {
+  static constexpr auto settings = std::to_array({
       mojom::Setting::kCellularSimLock,
       mojom::Setting::kCellularRoaming,
       mojom::Setting::kCellularApn,
@@ -648,22 +656,22 @@ const std::vector<mojom::Setting>& GetCellularDetailsSettings() {
       mojom::Setting::kCellularRenameESimNetwork,
       mojom::Setting::kCellularAddApn,
   });
-  return *settings;
+  return settings;
 }
 
-const std::vector<mojom::Setting>& GetHotspotDetailsSettings() {
-  static const base::NoDestructor<std::vector<mojom::Setting>> settings({
+base::span<const mojom::Setting> GetHotspotDetailsSettings() {
+  static constexpr auto settings = std::to_array({
       mojom::Setting::kHotspotOnOff,
       mojom::Setting::kHotspotAutoDisabled,
   });
-  return *settings;
+  return settings;
 }
 
-const std::vector<mojom::Setting>& GetTetherDetailsSettings() {
-  static const base::NoDestructor<std::vector<mojom::Setting>> settings({
+base::span<const mojom::Setting> GetTetherDetailsSettings() {
+  static constexpr auto settings = std::to_array({
       mojom::Setting::kDisconnectTetherNetwork,
   });
-  return *settings;
+  return settings;
 }
 
 bool IsConnected(network_config::mojom::ConnectionStateType connection_state) {
@@ -768,9 +776,6 @@ InternetSection::InternetSection(Profile* profile,
 InternetSection::~InternetSection() = default;
 
 void InternetSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
-  const bool isRevampEnabled =
-      ash::features::IsOsSettingsRevampWayfindingEnabled();
-
   webui::LocalizedString kLocalizedStrings[] = {
       {"deviceInfoPopupMenuItemTitle",
        IDS_SETTINGS_DEVICE_INFO_POPUP_MENU_ITEM_TITLE},
@@ -830,9 +835,7 @@ void InternetSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
        IDS_SETTINGS_INTERNET_TOGGLE_WIFI_ACCESSIBILITY_LABEL},
       {"knownNetworksAll", IDS_SETTINGS_INTERNET_KNOWN_NETWORKS_ALL},
       {"knownNetworksButton", IDS_SETTINGS_INTERNET_KNOWN_NETWORKS_BUTTON},
-      {"knownNetworksMessage",
-       isRevampEnabled ? IDS_OS_SETTINGS_REVAMP_INTERNET_KNOWN_NETWORKS_MESSAGE
-                       : IDS_SETTINGS_INTERNET_KNOWN_NETWORKS_MESSAGE},
+      {"knownNetworksMessage", IDS_OS_SETTINGS_INTERNET_KNOWN_NETWORKS_MESSAGE},
       {"knownNetworksPreferred",
        IDS_SETTINGS_INTERNET_KNOWN_NETWORKS_PREFFERED},
       {"knownNetworksMenuAddPreferred",
@@ -891,7 +894,7 @@ void InternetSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
       {"networkNameserversLearnMore", IDS_LEARN_MORE},
       {"networkPrefer", IDS_SETTINGS_INTERNET_NETWORK_PREFER},
       {"networkPreferDescription",
-       IDS_OS_SETTINGS_REVAMP_INTERNET_NETWORK_PREFER_DESCRIPTION},
+       IDS_OS_SETTINGS_INTERNET_NETWORK_PREFER_DESCRIPTION},
       {"networkPrimaryUserControlled",
        IDS_SETTINGS_INTERNET_NETWORK_PRIMARY_USER_CONTROLLED},
       {"networkA11yManagedByAdministrator",
@@ -908,12 +911,6 @@ void InternetSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
       {"networkSectionNetwork", IDS_SETTINGS_INTERNET_NETWORK_SECTION_NETWORK},
       {"networkSectionNetworkExpandA11yLabel",
        IDS_SETTINGS_INTERNET_NETWORK_SECTION_NETWORK_ACCESSIBILITY_LABEL},
-      {"networkSectionPasspointRemovalTitle",
-       IDS_SETTINGS_INTERNET_NETWORK_SECTION_PASSPOINT_REMOVAL_TITLE},
-      {"networkSectionPasspointRemovalDescription",
-       IDS_SETTINGS_INTERNET_NETWORK_SECTION_PASSPOINT_REMOVAL_DESCRIPTION},
-      {"networkSectionPasspointRemovalInformation",
-       IDS_SETTINGS_INTERNET_NETWORK_SECTION_PASSPOINT_REMOVAL_INFORMATION},
       {"networkSectionPasspointGoToSubscriptionTitle",
        IDS_SETTINGS_INTERNET_NETWORK_SECTION_PASSPOINT_GO_TO_SUBSCRIPTION_TITLE},
       {"networkSectionPasspointGoToSubscriptionInformation",
@@ -927,9 +924,7 @@ void InternetSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
       {"networkSectionProxyExpandA11yLabel",
        IDS_SETTINGS_INTERNET_NETWORK_SECTION_PROXY_ACCESSIBILITY_LABEL},
       {"networkShared", IDS_SETTINGS_INTERNET_NETWORK_SHARED},
-      {"networkSharedOwner",
-       isRevampEnabled ? IDS_OS_SETTINGS_REVAMP_INTERNET_NETWORK_SHARED_OWNER
-                       : IDS_SETTINGS_INTERNET_NETWORK_SHARED_OWNER},
+      {"networkSharedOwner", IDS_OS_SETTINGS_INTERNET_NETWORK_SHARED_OWNER},
       {"networkSharedNotOwner", IDS_SETTINGS_INTERNET_NETWORK_SHARED_NOT_OWNER},
       {"networkVpnBuiltin", IDS_NETWORK_TYPE_VPN_BUILTIN},
       {"networkOutOfRange", IDS_SETTINGS_INTERNET_WIFI_NETWORK_OUT_OF_RANGE},
@@ -1132,8 +1127,6 @@ void InternetSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
        IDS_SETTINGS_INTERNET_PASSPOINT_LEARN_MORE_A11Y},
       {"passpointRemoveCancelA11yLabel",
        IDS_SETTINGS_INTERNET_PASSPOINT_REMOVE_CANCEL_A11Y},
-      {"passpointRemoveConfirmA11yLabel",
-       IDS_SETTINGS_INTERNET_PASSPOINT_REMOVE_CONFIRM_A11Y},
   };
   html_source->AddLocalizedStrings(kLocalizedStrings);
 
@@ -1153,9 +1146,6 @@ void InternetSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
           features::kCellularBypassESimInstallationConnectivityCheck));
   html_source->AddBoolean("showTechnologyBadge",
                           !ash::features::IsSeparateNetworkIconsEnabled());
-  html_source->AddBoolean(
-      "showMeteredToggle",
-      base::FeatureList::IsEnabled(::features::kMeteredShowToggle));
   html_source->AddBoolean(
       "trafficCountersForWifiTesting",
       ash::features::IsTrafficCountersForWiFiTestingEnabled());
@@ -1164,8 +1154,6 @@ void InternetSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
       base::FeatureList::IsEnabled(::features::kShowHiddenNetworkToggle));
   html_source->AddBoolean("isInstantHotspotRebrandEnabled",
                           ash::features::IsInstantHotspotRebrandEnabled());
-  html_source->AddBoolean("isPasspointSettingsEnabled",
-                          ash::features::IsPasspointSettingsEnabled());
 
   html_source->AddString("networkGoogleNameserversLearnMoreUrl",
                          chrome::kGoogleNameserversLearnMoreURL);
@@ -1403,27 +1391,29 @@ std::string InternetSection::ModifySearchResultUrl(
   std::string modified_url =
       OsSettingsSection::ModifySearchResultUrl(type, id, url_to_modify);
 
-  if (IsPartOfDetailsSubpage(type, id, mojom::Subpage::kEthernetDetails)) {
+  if (IsPartOfDetailsSubpage(type, id, mojom::Subpage::kEthernetDetails) &&
+      connected_ethernet_guid_.has_value()) {
     return GetDetailsSubpageUrl(modified_url, *connected_ethernet_guid_);
   }
 
-  if (IsPartOfDetailsSubpage(type, id, mojom::Subpage::kWifiDetails)) {
+  if (IsPartOfDetailsSubpage(type, id, mojom::Subpage::kWifiDetails) &&
+      connected_wifi_guid_.has_value()) {
     return GetDetailsSubpageUrl(modified_url, *connected_wifi_guid_);
   }
 
-  if (IsPartOfDetailsSubpage(type, id, mojom::Subpage::kCellularDetails)) {
+  if ((IsPartOfDetailsSubpage(type, id, mojom::Subpage::kCellularDetails) ||
+       IsPartOfDetailsSubpage(type, id, mojom::Subpage::kApn)) &&
+      active_cellular_guid_.has_value()) {
     return GetDetailsSubpageUrl(modified_url, *active_cellular_guid_);
   }
 
-  if (IsPartOfDetailsSubpage(type, id, mojom::Subpage::kApn)) {
-    return GetDetailsSubpageUrl(modified_url, *active_cellular_guid_);
-  }
-
-  if (IsPartOfDetailsSubpage(type, id, mojom::Subpage::kTetherDetails)) {
+  if (IsPartOfDetailsSubpage(type, id, mojom::Subpage::kTetherDetails) &&
+      connected_tether_guid_.has_value()) {
     return GetDetailsSubpageUrl(modified_url, *connected_tether_guid_);
   }
 
-  if (IsPartOfDetailsSubpage(type, id, mojom::Subpage::kVpnDetails)) {
+  if (IsPartOfDetailsSubpage(type, id, mojom::Subpage::kVpnDetails) &&
+      connected_vpn_guid_.has_value()) {
     return GetDetailsSubpageUrl(modified_url, *connected_vpn_guid_);
   }
 
@@ -1630,9 +1620,7 @@ void InternetSection::OnNetworkList(
       case NetworkType::kWiFi:
         connected_wifi_guid_ = network->guid;
         updater.AddSearchTags(GetWifiConnectedSearchConcepts());
-        if (base::FeatureList::IsEnabled(::features::kMeteredShowToggle)) {
-          updater.AddSearchTags(GetWifiMeteredSearchConcepts());
-        }
+        updater.AddSearchTags(GetWifiMeteredSearchConcepts());
         if (base::FeatureList::IsEnabled(
                 ::features::kShowHiddenNetworkToggle)) {
           updater.AddSearchTags(GetWifiHiddenSearchConcepts());
@@ -1641,9 +1629,7 @@ void InternetSection::OnNetworkList(
 
       case NetworkType::kCellular:
         updater.AddSearchTags(GetCellularConnectedSearchConcepts());
-        if (base::FeatureList::IsEnabled(::features::kMeteredShowToggle)) {
-          updater.AddSearchTags(GetCellularMeteredSearchConcepts());
-        }
+        updater.AddSearchTags(GetCellularMeteredSearchConcepts());
         break;
 
       case NetworkType::kTether:
