@@ -4,8 +4,13 @@
 
 #include "chrome/browser/ui/webui/ash/settings/pages/people/people_section.h"
 
+#include <array>
+#include <vector>
+
 #include "ash/constants/ash_features.h"
 #include "ash/constants/ash_pref_names.h"
+#include "ash/edusumer/graduation_utils.h"
+#include "base/containers/span.h"
 #include "base/feature_list.h"
 #include "base/functional/bind.h"
 #include "base/i18n/number_formatting.h"
@@ -17,7 +22,6 @@
 #include "chrome/browser/ash/account_manager/account_apps_availability.h"
 #include "chrome/browser/ash/account_manager/account_apps_availability_factory.h"
 #include "chrome/browser/ash/account_manager/account_manager_util.h"
-#include "chrome/browser/ash/crosapi/browser_util.h"
 #include "chrome/browser/ash/login/quick_unlock/quick_unlock_utils.h"
 #include "chrome/browser/ash/profiles/profile_helper.h"
 #include "chrome/browser/browser_process.h"
@@ -34,13 +38,13 @@
 #include "chrome/browser/ui/webui/settings/people_handler.h"
 #include "chrome/browser/ui/webui/settings/profile_info_handler.h"
 #include "chrome/browser/ui/webui/settings/shared_settings_localized_strings_provider.h"
-#include "chrome/browser/ui/webui/webui_util.h"
 #include "chrome/common/url_constants.h"
 #include "chrome/common/webui_url_constants.h"
 #include "chrome/grit/branded_strings.h"
 #include "chrome/grit/browser_resources.h"
 #include "chrome/grit/generated_resources.h"
 #include "chromeos/ash/components/account_manager/account_manager_factory.h"
+#include "chromeos/ash/components/browser_context_helper/browser_context_helper.h"
 #include "chromeos/ash/components/dbus/userdataauth/userdataauth_client.h"
 #include "components/account_manager_core/account_manager_facade.h"
 #include "components/account_manager_core/chromeos/account_manager_facade_factory.h"
@@ -52,16 +56,17 @@
 #include "components/user_manager/user_manager.h"
 #include "content/public/browser/web_ui.h"
 #include "content/public/browser/web_ui_data_source.h"
+#include "google_apis/gaia/gaia_id.h"
 #include "services/network/public/mojom/content_security_policy.mojom.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/base/webui/web_ui_util.h"
 #include "ui/chromeos/devicetype_utils.h"
 #include "ui/chromeos/resources/grit/ui_chromeos_resources.h"
+#include "ui/webui/webui_util.h"
 
 namespace ash::settings {
 
 namespace mojom {
-using ::chromeos::settings::mojom::kMyAccountsSubpagePath;
 using ::chromeos::settings::mojom::kPeopleSectionPath;
 using ::chromeos::settings::mojom::Section;
 using ::chromeos::settings::mojom::Setting;
@@ -70,53 +75,41 @@ using ::chromeos::settings::mojom::Subpage;
 
 namespace {
 
-const char* GetAccountsPath() {
-  return ash::features::IsOsSettingsRevampWayfindingEnabled()
-             ? mojom::kPeopleSectionPath
-             : mojom::kMyAccountsSubpagePath;
-}
-
-const std::vector<SearchConcept>& GetPeopleSearchConcepts() {
-  const char* kAccountsPath = GetAccountsPath();
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
-      {IDS_OS_SETTINGS_TAG_PEOPLE_ACCOUNTS,
-       kAccountsPath,
-       mojom::SearchResultIcon::kAvatar,
-       mojom::SearchResultDefaultRank::kMedium,
-       mojom::SearchResultType::kSubpage,
-       {.subpage = mojom::Subpage::kMyAccounts}},
+base::span<const SearchConcept> GetPeopleSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_PEOPLE_V2,
        mojom::kPeopleSectionPath,
        mojom::SearchResultIcon::kAvatar,
        mojom::SearchResultDefaultRank::kMedium,
        mojom::SearchResultType::kSection,
-       {.section = mojom::Section::kPeople}},
+       {.section = mojom::Section::kPeople},
+       {IDS_OS_SETTINGS_TAG_PEOPLE_ACCOUNTS, IDS_OS_SETTINGS_TAG_PEOPLE,
+        SearchConcept::kAltTagEnd}},
       {IDS_OS_SETTINGS_TAG_PEOPLE_ACCOUNTS_ADD_V2,
-       kAccountsPath,
+       mojom::kPeopleSectionPath,
        mojom::SearchResultIcon::kAvatar,
        mojom::SearchResultDefaultRank::kMedium,
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kAddAccount}},
   });
 
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetRemoveAccountSearchConcepts(
-    const char* accounts_path) {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetRemoveAccountSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_PEOPLE_ACCOUNTS_REMOVE,
-       accounts_path,
+       mojom::kPeopleSectionPath,
        mojom::SearchResultIcon::kAvatar,
        mojom::SearchResultDefaultRank::kMedium,
        mojom::SearchResultType::kSetting,
        {.setting = mojom::Setting::kRemoveAccount}},
   });
-  return *tags;
+  return tags;
 }
 
-const std::vector<SearchConcept>& GetParentalSearchConcepts() {
-  static const base::NoDestructor<std::vector<SearchConcept>> tags({
+base::span<const SearchConcept> GetParentalSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
       {IDS_OS_SETTINGS_TAG_PARENTAL_CONTROLS,
        mojom::kPeopleSectionPath,
        mojom::SearchResultIcon::kAvatar,
@@ -126,7 +119,19 @@ const std::vector<SearchConcept>& GetParentalSearchConcepts() {
        {IDS_OS_SETTINGS_TAG_PARENTAL_CONTROLS_ALT1,
         IDS_OS_SETTINGS_TAG_PARENTAL_CONTROLS_ALT2, SearchConcept::kAltTagEnd}},
   });
-  return *tags;
+  return tags;
+}
+
+base::span<const SearchConcept> GetGraduationSearchConcepts() {
+  static constexpr auto tags = std::to_array<SearchConcept>({
+      {IDS_OS_SETTINGS_TAG_GRADUATION,
+       mojom::kPeopleSectionPath,
+       mojom::SearchResultIcon::kGraduation,
+       mojom::SearchResultDefaultRank::kMedium,
+       mojom::SearchResultType::kSetting,
+       {.setting = mojom::Setting::kGraduation}},
+  });
+  return tags;
 }
 
 void AddAccountManagerPageStrings(content::WebUIDataSource* html_source,
@@ -165,16 +170,6 @@ void AddAccountManagerPageStrings(content::WebUIDataSource* html_source,
        IDS_SETTINGS_ACCOUNT_MANAGER_CHILD_DESCRIPTION_V2},
       {"accountManagerSecondaryAccountsDisabledText",
        IDS_SETTINGS_ACCOUNT_MANAGER_SECONDARY_ACCOUNTS_DISABLED_TEXT_V2},
-      {"removeLacrosAccountDialogTitle",
-       IDS_SETTINGS_ACCOUNT_MANAGER_REMOVE_LACROS_ACCOUNT_DIALOG_TITLE},
-      {"removeLacrosAccountDialogBody",
-       IDS_SETTINGS_ACCOUNT_MANAGER_REMOVE_LACROS_ACCOUNT_DIALOG_BODY},
-      {"removeLacrosAccountDialogRemove",
-       IDS_SETTINGS_ACCOUNT_MANAGER_REMOVE_LACROS_ACCOUNT_DIALOG_REMOVE},
-      {"removeLacrosAccountDialogCancel",
-       IDS_SETTINGS_ACCOUNT_MANAGER_REMOVE_LACROS_ACCOUNT_DIALOG_CANCEL},
-      {"accountNotUsedInArcLabel",
-       IDS_SETTINGS_ACCOUNT_MANAGER_NOT_USED_IN_ARC_LABEL},
       {"accountNotAllowedInArcLabel",
        IDS_SETTINGS_ACCOUNT_MANAGER_NOT_ALLOWED_IN_ARC_LABEL},
       {"accountUseInArcButtonLabel",
@@ -183,17 +178,8 @@ void AddAccountManagerPageStrings(content::WebUIDataSource* html_source,
        IDS_SETTINGS_ACCOUNT_MANAGER_STOP_USING_IN_ARC_BUTTON_LABEL},
   };
   html_source->AddLocalizedStrings(kLocalizedStrings);
-
-  if (AccountAppsAvailability::IsArcAccountRestrictionsEnabled()) {
-    html_source->AddString("accountListDescription",
-                           l10n_util::GetStringFUTF16(
-                               IDS_SETTINGS_ACCOUNT_MANAGER_LIST_DESCRIPTION_V2,
-                               ui::GetChromeOSDeviceName()));
-  } else {
-    html_source->AddLocalizedString(
-        "accountListDescription",
-        IDS_SETTINGS_ACCOUNT_MANAGER_LIST_DESCRIPTION);
-  }
+  html_source->AddLocalizedString(
+      "accountListDescription", IDS_SETTINGS_ACCOUNT_MANAGER_LIST_DESCRIPTION);
 
   user_manager::User* user = ProfileHelper::Get()->GetUserByProfile(profile);
   DCHECK(user);
@@ -215,18 +201,10 @@ void AddAccountManagerPageStrings(content::WebUIDataSource* html_source,
       "accountManagerDescription",
       l10n_util::GetStringFUTF16(IDS_SETTINGS_ACCOUNT_MANAGER_DESCRIPTION_V2,
                                  ui::GetChromeOSDeviceName()));
-  html_source->AddBoolean("lacrosEnabled",
-                          crosapi::browser_util::IsLacrosEnabled());
-  html_source->AddBoolean(
-      "arcAccountRestrictionsEnabled",
-      AccountAppsAvailability::IsArcAccountRestrictionsEnabled());
-  html_source->AddBoolean(
-      "arcManagedAccountRestrictionEnabled",
-      AccountAppsAvailability::IsArcManagedAccountRestrictionEnabled());
 }
 
 void AddLockScreenPageStrings(content::WebUIDataSource* html_source,
-                              PrefService* pref_service) {
+                              Profile* profile) {
   static constexpr webui::LocalizedString kLocalizedStrings[] = {
       {"lockScreenNotificationTitle",
        IDS_ASH_SETTINGS_LOCK_SCREEN_NOTIFICATION_TITLE},
@@ -262,12 +240,10 @@ void AddLockScreenPageStrings(content::WebUIDataSource* html_source,
       {"lockScreenOptionsLock", IDS_SETTINGS_PEOPLE_LOCK_SCREEN_OPTIONS_LOCK},
       {"lockScreenOptionsLoginLock",
        IDS_SETTINGS_PEOPLE_LOCK_SCREEN_OPTIONS_LOGIN_LOCK},
-      {"lockScreenRemovePinButton",
+      {"lockScreenRemoveButton",
        IDS_SETTINGS_PEOPLE_LOCK_SCREEN_REMOVE_PIN_BUTTON},
       {"lockScreenPasswordLabel",
        IDS_SETTINGS_PEOPLE_LOCK_SCREEN_PASSWORD_LABEL},
-      {"lockScreenPasswordDescription",
-       IDS_SETTINGS_PEOPLE_LOCK_SCREEN_PASSWORD_DESCRIPTION},
       {"lockScreenPinLabel", IDS_SETTINGS_PEOPLE_LOCK_SCREEN_PIN_LABEL},
       {"lockScreenSetupPasswordButton",
        IDS_SETTINGS_PEOPLE_LOCK_SCREEN_SETUP_PASSWORD_BUTTON},
@@ -302,6 +278,8 @@ void AddLockScreenPageStrings(content::WebUIDataSource* html_source,
        IDS_OS_SETTINGS_PEOPLE_SET_LOCAL_PASSWORD_DIALOG_INTERNAL_ERROR},
       {"showPassword", IDS_AUTH_SETUP_SHOW_PASSWORD},
       {"hidePassword", IDS_AUTH_SETUP_HIDE_PASSWORD},
+      {"showPin", IDS_AUTH_SETUP_SHOW_PIN},
+      {"hidePin", IDS_AUTH_SETUP_HIDE_PIN},
       {"setLocalPasswordPlaceholder",
        IDS_AUTH_SETUP_SET_LOCAL_PASSWORD_PLACEHOLDER},
       {"setLocalPasswordConfirmPlaceholder",
@@ -314,22 +292,25 @@ void AddLockScreenPageStrings(content::WebUIDataSource* html_source,
   html_source->AddLocalizedStrings(kLocalizedStrings);
 
   html_source->AddBoolean("quickUnlockEnabled", quick_unlock::IsPinEnabled());
-  html_source->AddBoolean("quickUnlockDisabledByPolicy",
-                          quick_unlock::IsPinDisabledByPolicy(
-                              pref_service, quick_unlock::Purpose::kAny));
+  html_source->AddBoolean(
+      "quickUnlockDisabledByPolicy",
+      quick_unlock::IsPinDisabledByPolicy(profile->GetPrefs(),
+                                          quick_unlock::Purpose::kAny));
   html_source->AddBoolean("lockScreenNotificationsEnabled",
                           ash::features::IsLockScreenNotificationsEnabled());
   html_source->AddBoolean(
       "lockScreenHideSensitiveNotificationsSupported",
       ash::features::IsLockScreenHideSensitiveNotificationsSupported());
-  html_source->AddBoolean("changePasswordFactorSetupEnabled",
-                          ash::features::IsChangePasswordFactorSetupEnabled());
-
   html_source->AddString(
       "lockScreenSwitchLocalPasswordDescription",
       l10n_util::GetStringFUTF16(
           IDS_SETTINGS_PEOPLE_LOCK_SCREEN_SWITCH_LOCAL_PASSWORD_DESCRIPTION,
           ui::GetChromeOSDeviceName()));
+  html_source->AddString(
+      "lockScreenSwitchSetLocalPasswordDescription",
+      l10n_util::GetStringFUTF16(
+          IDS_SETTINGS_PEOPLE_LOCK_SCREEN_PASSWORD_DESCRIPTION,
+          ui::GetChromeOSDeviceName()));
   html_source->AddString("lockScreenFingerprintNotice",
                          l10n_util::GetStringFUTF16(
                              IDS_SETTINGS_PEOPLE_LOCK_SCREEN_FINGERPRINT_NOTICE,
@@ -417,21 +398,14 @@ void AddSetupPinDialogStrings(content::WebUIDataSource* html_source) {
 }
 
 void AddUsersStrings(content::WebUIDataSource* html_source) {
-  const bool kIsRevampEnabled =
-      ash::features::IsOsSettingsRevampWayfindingEnabled();
-
   webui::LocalizedString kLocalizedStrings[] = {
       {"usersModifiedByOwnerLabel", IDS_SETTINGS_USERS_MODIFIED_BY_OWNER_LABEL},
-      {"guestBrowsingLabel",
-       kIsRevampEnabled ? IDS_OS_SETTINGS_REVAMP_USERS_GUEST_BROWSING_LABEL
-                        : IDS_SETTINGS_USERS_GUEST_BROWSING_LABEL},
+      {"guestBrowsingLabel", IDS_OS_SETTINGS_USERS_GUEST_BROWSING_LABEL},
       {"settingsManagedLabel", IDS_SETTINGS_USERS_MANAGED_LABEL},
       {"showOnSigninLabel", IDS_SETTINGS_USERS_SHOW_ON_SIGNIN_LABEL},
-      {"restrictSigninLabel",
-       kIsRevampEnabled ? IDS_OS_SETTINGS_REVAMP_USERS_RESTRICT_SIGNIN_LABEL
-                        : IDS_SETTINGS_USERS_RESTRICT_SIGNIN_LABEL},
+      {"restrictSigninLabel", IDS_OS_SETTINGS_USERS_RESTRICT_SIGNIN_LABEL},
       {"restrictSigninDescription",
-       IDS_OS_SETTINGS_REVAMP_USERS_RESTRICT_SIGNIN_DESCRIPTION},
+       IDS_OS_SETTINGS_USERS_RESTRICT_SIGNIN_DESCRIPTION},
       {"deviceOwnerLabel", IDS_SETTINGS_USERS_DEVICE_OWNER_LABEL},
       {"removeUserTooltip", IDS_SETTINGS_USERS_REMOVE_USER_TOOLTIP},
       {"userRemovedMessage", IDS_SETTINGS_USERS_USER_REMOVED_MESSAGE},
@@ -464,12 +438,27 @@ void AddParentalControlStrings(content::WebUIDataSource* html_source,
                           are_parental_control_settings_allowed);
 }
 
+void AddGraduationStrings(content::WebUIDataSource* html_source,
+                          Profile* profile) {
+  static constexpr webui::LocalizedString kLocalizedStrings[] = {
+      {"graduationSectionTitle", IDS_SETTINGS_GRADUATION_SECTION_TITLE},
+      {"graduationRowTitle", IDS_SETTINGS_GRADUATION_ROW_TITLE},
+      {"graduationRowSubtitle", IDS_SETTINGS_GRADUATION_ROW_SUBTITLE}};
+
+  html_source->AddLocalizedStrings(kLocalizedStrings);
+
+  html_source->AddBoolean("isGraduationAppEnabled",
+                          ShouldShowGraduationAppSetting(profile));
+  html_source->AddBoolean("isGraduationFlagEnabled",
+                          features::IsGraduationEnabled());
+}
+
 bool IsSameAccount(const ::account_manager::AccountKey& account_key,
                    const AccountId& account_id) {
   switch (account_key.account_type()) {
     case account_manager::AccountType::kGaia:
       return account_id.GetAccountType() == AccountType::GOOGLE &&
-             account_id.GetGaiaId() == account_key.id();
+             account_id.GetGaiaId() == GaiaId(account_key.id());
     case account_manager::AccountType::kActiveDirectory:
       return account_id.GetAccountType() == AccountType::ACTIVE_DIRECTORY &&
              account_id.GetObjGuid() == account_key.id();
@@ -483,23 +472,16 @@ PeopleSection::PeopleSection(Profile* profile,
                              signin::IdentityManager* identity_manager,
                              PrefService* pref_service)
     : OsSettingsSection(profile, search_tag_registry),
-      sync_subsection_(
-          !ash::features::IsOsSettingsRevampWayfindingEnabled()
-              ? std::make_optional<SyncSection>(profile, search_tag_registry)
-              : std::nullopt),
       identity_manager_(identity_manager),
       pref_service_(pref_service),
       auth_performer_(UserDataAuthClient::Get()),
       fp_engine_(&auth_performer_) {
   // No search tags are registered if in guest mode.
-  if (IsGuestModeActive()) {
+  auto* user = BrowserContextHelper::Get()->GetUserByBrowserContext(profile);
+  if (IsGuestModeActive(user)) {
     return;
   }
 
-  if (!ash::features::IsOsSettingsRevampWayfindingEnabled()) {
-    CHECK(sync_subsection_);
-  }
-
   SearchTagRegistry::ScopedTagUpdater updater = registry()->StartUpdate();
   updater.AddSearchTags(GetPeopleSearchConcepts());
 
@@ -525,6 +507,10 @@ PeopleSection::PeopleSection(Profile* profile,
   if (ShouldShowParentalControlSettings(profile)) {
     updater.AddSearchTags(GetParentalSearchConcepts());
   }
+  if (features::IsGraduationEnabled() &&
+      ShouldShowGraduationAppSetting(profile)) {
+    updater.AddSearchTags(GetGraduationSearchConcepts());
+  }
 }
 
 PeopleSection::~PeopleSection() = default;
@@ -570,7 +556,7 @@ void PeopleSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
       base::FeatureList::IsEnabled(omnibox::kDocumentProvider));
 
   AddAccountManagerPageStrings(html_source, profile());
-  AddLockScreenPageStrings(html_source, profile()->GetPrefs());
+  AddLockScreenPageStrings(html_source, profile());
   AddFingerprintListStrings(html_source);
   AddFingerprintResources(html_source, AreFingerprintSettingsAllowed());
   AddSetupFingerprintDialogStrings(html_source);
@@ -578,14 +564,9 @@ void PeopleSection::AddLoadTimeData(content::WebUIDataSource* html_source) {
   AddUsersStrings(html_source);
   AddParentalControlStrings(html_source,
                             ShouldShowParentalControlSettings(profile()));
+  AddGraduationStrings(html_source, profile());
 
   ::settings::AddPasswordPromptDialogStrings(html_source);
-
-  // `sync_subsection_` is initialized only if the feature revamp wayfinding is
-  // disabled.
-  if (sync_subsection_) {
-    sync_subsection_->AddLoadTimeData(html_source);
-  }
 }
 
 void PeopleSection::AddHandlers(content::WebUI* web_ui) {
@@ -610,12 +591,6 @@ void PeopleSection::AddHandlers(content::WebUI* web_ui) {
     web_ui->AddMessageHandler(
         std::make_unique<ParentalControlsHandler>(profile()));
   }
-
-  // `sync_subsection_` is initialized only if the feature revamp wayfinding is
-  // disabled.
-  if (sync_subsection_) {
-    sync_subsection_->AddHandlers(web_ui);
-  }
 }
 
 int PeopleSection::GetSectionNameMessageId() const {
@@ -648,37 +623,14 @@ bool PeopleSection::LogMetric(mojom::Setting setting,
 }
 
 void PeopleSection::RegisterHierarchy(HierarchyGenerator* generator) const {
+  generator->RegisterTopLevelSetting(mojom::Setting::kAddAccount);
+  generator->RegisterTopLevelSetting(mojom::Setting::kRemoveAccount);
   generator->RegisterTopLevelSetting(mojom::Setting::kSetUpParentalControls);
-
-  generator->RegisterTopLevelSubpage(
-      IDS_SETTINGS_ACCOUNT_MANAGER_PAGE_TITLE, mojom::Subpage::kMyAccounts,
-      mojom::SearchResultIcon::kAvatar, mojom::SearchResultDefaultRank::kMedium,
-      mojom::kMyAccountsSubpagePath);
-
-  // My accounts.
-  if (ash::features::IsOsSettingsRevampWayfindingEnabled()) {
-    // Accounts settings are up-leveled to the top level page if the revamp
-    // wayfind is enabled.
-    generator->RegisterTopLevelSetting(mojom::Setting::kAddAccount);
-    generator->RegisterTopLevelSetting(mojom::Setting::kRemoveAccount);
-  } else {
-    static constexpr mojom::Setting kMyAccountsSettings[] = {
-        mojom::Setting::kAddAccount,
-        mojom::Setting::kRemoveAccount,
-    };
-    RegisterNestedSettingBulk(mojom::Subpage::kMyAccounts, kMyAccountsSettings,
-                              generator);
-  }
+  generator->RegisterTopLevelSetting(mojom::Setting::kGraduation);
 
   // Smart Lock -- main setting is on multidevice page, but is mirrored here
   generator->RegisterNestedAltSetting(mojom::Setting::kSmartLockOnOff,
                                       mojom::Subpage::kSecurityAndSignInV2);
-
-  // `sync_subsection_` is initialized only if the feature revamp wayfinding is
-  // disabled.
-  if (sync_subsection_) {
-    sync_subsection_->RegisterHierarchy(generator);
-  }
 }
 
 void PeopleSection::FetchAccounts() {
@@ -709,7 +661,7 @@ void PeopleSection::UpdateAccountManagerSearchTags(
 
   // Start with no Account Manager search tags.
   SearchTagRegistry::ScopedTagUpdater updater = registry()->StartUpdate();
-  updater.RemoveSearchTags(GetRemoveAccountSearchConcepts(GetAccountsPath()));
+  updater.RemoveSearchTags(GetRemoveAccountSearchConcepts());
 
   user_manager::User* user = ProfileHelper::Get()->GetUserByProfile(profile());
   DCHECK(user);
@@ -720,7 +672,7 @@ void PeopleSection::UpdateAccountManagerSearchTags(
     }
 
     // If a non-device account exists, add the "Remove Account" search tag.
-    updater.AddSearchTags(GetRemoveAccountSearchConcepts(GetAccountsPath()));
+    updater.AddSearchTags(GetRemoveAccountSearchConcepts());
     return;
   }
 }
