@@ -4,12 +4,12 @@
 
 #include "chrome/browser/ui/webui/ash/settings/pages/privacy/privacy_hub_handler.h"
 
+#include <algorithm>
+
 #include "ash/constants/ash_features.h"
 #include "base/containers/adapters.h"
-#include "base/ranges/algorithm.h"
 #include "base/test/scoped_feature_list.h"
 #include "base/test/task_environment.h"
-#include "chrome/browser/ash/privacy_hub/privacy_hub_hats_trigger.h"
 #include "chrome/browser/ash/privacy_hub/privacy_hub_util.h"
 #include "chrome/common/chrome_features.h"
 #include "chromeos/ash/components/audio/cras_audio_handler.h"
@@ -25,8 +25,6 @@ class TestPrivacyHubHandler : public PrivacyHubHandler {
 
   using PrivacyHubHandler::HandleInitialCameraLedFallbackState;
   using PrivacyHubHandler::HandleInitialMicrophoneSwitchState;
-  using PrivacyHubHandler::HandlePrivacyPageClosed;
-  using PrivacyHubHandler::HandlePrivacyPageOpened;
 };
 
 using cps = cros::mojom::CameraPrivacySwitchState;
@@ -143,21 +141,6 @@ class PrivacyHubHandlerCameraLedFallbackTest
       scoped_camera_led_fallback_;
 };
 
-class PrivacyHubHandlerHatsTest : public PrivacyHubHandlerTest {
- public:
-  PrivacyHubHandlerHatsTest() {
-    feature_list_.InitAndEnableFeature(
-        ::features::kHappinessTrackingPrivacyHubPostLaunch);
-  }
-
-  bool IsTimerStarted() {
-    return PrivacyHubHatsTrigger::Get().GetTimerForTesting().IsRunning();
-  }
-
- private:
-  base::test::ScopedFeatureList feature_list_;
-};
-
 class PrivacyHubHandlerCameraSwitchTest
     : public PrivacyHubHandlerTest,
       public testing::WithParamInterface<bool> {
@@ -225,49 +208,6 @@ INSTANTIATE_TEST_SUITE_P(CameraLedFallback,
                          testing::Values(true, false),
                          testing::PrintToStringParamName());
 
-TEST_F(PrivacyHubHandlerHatsTest, OnlyTriggerHatsIfPageWasVisitedLongEnough) {
-  const base::Value::List args;
-
-  EXPECT_FALSE(IsTimerStarted());
-
-  // We trigger the HaTS survey on the leave event but the user hasn't visited
-  // the page yet.
-  privacy_hub_handler_.HandlePrivacyPageClosed(args);
-  EXPECT_FALSE(IsTimerStarted());
-
-  // User goes to the page.
-  privacy_hub_handler_.HandlePrivacyPageOpened(args);
-  EXPECT_FALSE(IsTimerStarted());
-
-  // Simulate the user stays on the page for 5 seconds.
-  privacy_hub_handler_.SetPrivacyPageOpenedTimeStampForTesting(
-      base::TimeTicks::Now() - base::Seconds(5));
-  EXPECT_FALSE(IsTimerStarted());
-
-  // And leaves it again, now the survey should be triggered.
-  privacy_hub_handler_.HandlePrivacyPageClosed(args);
-  EXPECT_TRUE(IsTimerStarted());
-}
-
-TEST_F(PrivacyHubHandlerHatsTest, DontTriggerHatsIfUserLeftEarly) {
-  const base::Value::List args;
-
-  EXPECT_FALSE(IsTimerStarted());
-
-  // We trigger the HaTS survey on the leave event but the user hasn't visited
-  // the page yet.
-  privacy_hub_handler_.HandlePrivacyPageClosed(args);
-  EXPECT_FALSE(IsTimerStarted());
-
-  // User goes to the page.
-  privacy_hub_handler_.HandlePrivacyPageOpened(args);
-  EXPECT_FALSE(IsTimerStarted());
-
-  // And leaves it again immediately, now the survey shouldn't be triggered.
-  privacy_hub_handler_.HandlePrivacyPageClosed(args);
-  EXPECT_FALSE(IsTimerStarted());
-}
-
 TEST_F(PrivacyHubHandlerTest, MicrophoneMutedBySecurityCurtainChanged) {
   privacy_hub_handler_.OnInputMutedBySecurityCurtainChanged(true);
 
@@ -302,33 +242,6 @@ TEST_F(PrivacyHubHandlerDeathTest, HandleInitialMicrophoneSwitchStateWithArgs) {
                ".*Did not expect arguments.*");
 }
 
-TEST_F(PrivacyHubHandlerDeathTest, HandlePrivacyPageOpened) {
-  base::Value::List args;
-  args.Append(this_test_name_);
-
-  EXPECT_DEATH(privacy_hub_handler_.HandlePrivacyPageOpened(args), ".*empty.*");
-}
-
-TEST_F(PrivacyHubHandlerDeathTest, HandlePrivacyPageClosed) {
-  base::Value::List args;
-  args.Append(this_test_name_);
-
-  EXPECT_DEATH(privacy_hub_handler_.HandlePrivacyPageClosed(args), ".*empty.*");
-}
-
-TEST_F(PrivacyHubHandlerDeathTest, OnlyTriggerHatsIfFeatureIsEnabled) {
-  const base::Value::List args;
-  base::test::ScopedFeatureList feature_list;
-  feature_list.InitAndDisableFeature(
-      ::features::kHappinessTrackingPrivacyHubPostLaunch);
-
-  // User goes to the page.
-  EXPECT_DEATH(privacy_hub_handler_.HandlePrivacyPageOpened(args),
-               "base::FeatureList::IsEnabled");
-  EXPECT_DEATH(privacy_hub_handler_.HandlePrivacyPageClosed(args),
-               "base::FeatureList::IsEnabled");
-}
-
 #endif
 
 }  // namespace ash::settings
