@@ -1,4 +1,4 @@
-// Copyright 2019 The Chromium Authors. All rights reserved.
+// Copyright 2019 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -6,11 +6,21 @@
 #define CHROME_BROWSER_UI_WEBUI_AUTOFILL_AND_PASSWORD_MANAGER_INTERNALS_AUTOFILL_INTERNALS_UI_H_
 
 #include "content/public/browser/web_ui_controller.h"
+#include "content/public/browser/webui_config.h"
 
 namespace content {
 class WebUI;
 }
 
+class AutofillInternalsUI;
+
+class AutofillInternalsUIConfig
+    : public content::DefaultWebUIConfig<AutofillInternalsUI> {
+ public:
+  AutofillInternalsUIConfig();
+  ~AutofillInternalsUIConfig() override;
+};
+
 class AutofillInternalsUI : public content::WebUIController {
  public:
   explicit AutofillInternalsUI(content::WebUI* web_ui);
