@@ -5,13 +5,25 @@
 #ifndef CHROME_BROWSER_UI_WEBUI_CONFLICTS_CONFLICTS_UI_H_
 #define CHROME_BROWSER_UI_WEBUI_CONFLICTS_CONFLICTS_UI_H_
 
+#include "chrome/common/webui_url_constants.h"
 #include "content/public/browser/web_ui_controller.h"
+#include "content/public/browser/webui_config.h"
+#include "content/public/common/url_constants.h"
 #include "ui/base/resource/resource_scale_factor.h"
 
 namespace base {
 class RefCountedMemory;
 }
 
+class ConflictsUI;
+
+class ConflictsUIConfig : public content::DefaultWebUIConfig<ConflictsUI> {
+ public:
+  ConflictsUIConfig()
+      : DefaultWebUIConfig(content::kChromeUIScheme,
+                           chrome::kChromeUIConflictsHost) {}
+};
+
 // The Web UI handler for about:conflicts.
 class ConflictsUI : public content::WebUIController {
  public:
