@@ -15,7 +15,8 @@
 #include "base/run_loop.h"
 #include "base/test/values_test_util.h"
 #include "base/values.h"
-#include "chrome/browser/ash/crosapi/test_crosapi_dependency_registry.h"
+#include "chrome/browser/ash/crosapi/crosapi_manager.h"
+#include "chrome/browser/ash/crosapi/idle_service_ash.h"
 #include "chrome/browser/printing/print_test_utils.h"
 #include "chrome/browser/ui/webui/print_preview/print_preview_handler.h"
 #include "chrome/browser/ui/webui/print_preview/print_preview_ui.h"
@@ -23,7 +24,9 @@
 #include "chrome/browser/ui/webui/print_preview/printer_handler.h"
 #include "chrome/test/base/testing_browser_process.h"
 #include "chrome/test/base/testing_profile.h"
+#include "chrome/test/base/testing_profile_manager.h"
 #include "chrome/test/chromeos/printing/fake_local_printer_chromeos.h"
+#include "chromeos/ash/components/login/login_state/login_state.h"
 #include "chromeos/crosapi/mojom/local_printer.mojom.h"
 #include "content/public/browser/web_contents.h"
 #include "content/public/test/browser_task_environment.h"
@@ -31,13 +34,6 @@
 #include "testing/gmock/include/gmock/gmock.h"
 #include "testing/gtest/include/gtest/gtest.h"
 
-#if BUILDFLAG(IS_CHROMEOS_ASH)
-#include "chrome/browser/ash/crosapi/crosapi_manager.h"
-#include "chrome/browser/ash/crosapi/idle_service_ash.h"
-#include "chrome/test/base/testing_profile_manager.h"
-#include "chromeos/ash/components/login/login_state/login_state.h"
-#endif
-
 namespace printing {
 
 namespace {
@@ -224,12 +220,10 @@ class PrintPreviewHandlerChromeOSTest : public testing::Test {
   ~PrintPreviewHandlerChromeOSTest() override = default;
 
   void SetUp() override {
-#if BUILDFLAG(IS_CHROMEOS_ASH)
     ASSERT_TRUE(testing_profile_manager_.SetUp());
     crosapi::IdleServiceAsh::DisableForTesting();
     ash::LoginState::Initialize();
-    manager_ = crosapi::CreateCrosapiManagerWithTestRegistry();
-#endif
+    manager_ = std::make_unique<crosapi::CrosapiManager>();
     preview_web_contents_ = content::WebContents::Create(
         content::WebContents::CreateParams(&profile_));
     web_ui_ = std::make_unique<content::TestWebUI>();
@@ -257,10 +251,8 @@ class PrintPreviewHandlerChromeOSTest : public testing::Test {
   }
 
   void TearDown() override {
-#if BUILDFLAG(IS_CHROMEOS_ASH)
     manager_.reset();
     ash::LoginState::Shutdown();
-#endif
   }
 
   void DisableAshChrome() {
@@ -299,19 +291,11 @@ class PrintPreviewHandlerChromeOSTest : public testing::Test {
         ConvertToLocalDestinationInfo(printer_ids));
   }
 
-#if BUILDFLAG(IS_CHROMEOS_LACROS)
-  int LocalPrinterVersion() {
-    return handler_->GetLocalPrinterVersionForTesting();
-  }
-#endif
-
  private:
   content::BrowserTaskEnvironment task_environment_;
-#if BUILDFLAG(IS_CHROMEOS_ASH)
   TestingProfileManager testing_profile_manager_{
       TestingBrowserProcess::GetGlobal()};
   std::unique_ptr<crosapi::CrosapiManager> manager_;
-#endif
   TestingProfile profile_;
   std::unique_ptr<TestLocalPrinter> local_printer_;
   std::unique_ptr<content::WebContents> preview_web_contents_;
@@ -477,14 +461,6 @@ TEST_F(PrintPreviewHandlerChromeOSTest, HandleGetCanShowManagePrinters) {
 
 // Verify 'observeLocalPrinters' can be called.
 TEST_F(PrintPreviewHandlerChromeOSTest, HandleObserveLocalPrinters) {
-#if BUILDFLAG(IS_CHROMEOS_LACROS)
-  if (int{crosapi::mojom::LocalPrinter::MethodMinVersions::
-              kAddLocalPrintersObserverMinVersion} > LocalPrinterVersion()) {
-    LOG(ERROR) << "Local printer version incompatible";
-    return;
-  }
-#endif
-
   const std::vector<std::string> printers{"Printer1", "Printer2", "Printer3"};
   SetLocalPrinters(printers);
 
