@@ -5,6 +5,7 @@
 #include "chrome/browser/ui/webui/settings/font_handler.h"
 
 #include <stddef.h>
+
 #include <string>
 #include <utility>
 #include <vector>
@@ -35,7 +36,7 @@ FontHandler::FontHandler(Profile* profile) {
 #endif
 }
 
-FontHandler::~FontHandler() {}
+FontHandler::~FontHandler() = default;
 
 void FontHandler::RegisterMessages() {
   web_ui()->RegisterMessageCallback(
