@@ -7,23 +7,23 @@
 #include <string>
 #include <utility>
 
+#include "chrome/app/chrome_command_ids.h"
 #include "chrome/browser/bookmarks/bookmark_model_factory.h"
 #include "chrome/browser/bookmarks/managed_bookmark_service_factory.h"
-#include "chrome/browser/browser_process.h"
+#include "chrome/browser/browser_features.h"
 #include "chrome/browser/commerce/shopping_service_factory.h"
 #include "chrome/browser/feature_engagement/tracker_factory.h"
-#include "chrome/browser/image_service/image_service_factory.h"
+#include "chrome/browser/page_image_service/image_service_factory.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/profiles/profiles_state.h"
 #include "chrome/browser/ui/ui_features.h"
 #include "chrome/browser/ui/webui/bookmarks/bookmark_prefs.h"
+#include "chrome/browser/ui/webui/commerce/price_tracking_handler.h"
 #include "chrome/browser/ui/webui/commerce/shopping_list_context_menu_controller.h"
 #include "chrome/browser/ui/webui/favicon_source.h"
 #include "chrome/browser/ui/webui/plural_string_handler.h"
 #include "chrome/browser/ui/webui/sanitized_image_source.h"
 #include "chrome/browser/ui/webui/side_panel/bookmarks/bookmarks_page_handler.h"
-#include "chrome/browser/ui/webui/webui_util.h"
-#include "chrome/common/webui_url_constants.h"
 #include "chrome/grit/generated_resources.h"
 #include "chrome/grit/side_panel_bookmarks_resources.h"
 #include "chrome/grit/side_panel_bookmarks_resources_map.h"
@@ -35,7 +35,7 @@
 #include "components/bookmarks/managed/managed_bookmark_service.h"
 #include "components/commerce/core/commerce_feature_list.h"
 #include "components/commerce/core/shopping_service.h"
-#include "components/commerce/core/webui/shopping_list_handler.h"
+#include "components/commerce/core/webui/shopping_service_handler.h"
 #include "components/favicon_base/favicon_url_parser.h"
 #include "components/page_image_service/features.h"
 #include "components/page_image_service/image_service.h"
@@ -43,6 +43,7 @@
 #include "components/policy/core/common/policy_pref_names.h"
 #include "components/prefs/pref_service.h"
 #include "components/strings/grit/components_strings.h"
+#include "components/sync/base/features.h"
 #include "content/public/browser/web_contents.h"
 #include "content/public/browser/web_ui.h"
 #include "content/public/browser/web_ui_data_source.h"
@@ -51,9 +52,26 @@
 #include "ui/base/webui/web_ui_util.h"
 #include "ui/views/style/platform_style.h"
 #include "ui/webui/color_change_listener/color_change_handler.h"
+#include "ui/webui/webui_util.h"
+
+BookmarksSidePanelUIConfig::BookmarksSidePanelUIConfig()
+    : DefaultTopChromeWebUIConfig(content::kChromeUIScheme,
+                                  chrome::kChromeUIBookmarksSidePanelHost) {}
+
+bool BookmarksSidePanelUIConfig::IsPreloadable() {
+  // TODO(crbug.com/373838921): re-enable preloading once the backend image
+  // service is no longer overwhelmed. This might be fixed by either adding a
+  // backend caching layer (crbug.com/379143109), or by us not requesting image
+  // during preloading.
+  return false;
+}
+
+std::optional<int> BookmarksSidePanelUIConfig::GetCommandIdForTesting() {
+  return IDC_SHOW_BOOKMARK_SIDE_PANEL;
+}
 
 BookmarksSidePanelUI::BookmarksSidePanelUI(content::WebUI* web_ui)
-    : ui::MojoBubbleWebUIController(web_ui, true) {
+    : TopChromeWebUIController(web_ui, true) {
   Profile* const profile = Profile::FromWebUI(web_ui);
   content::WebUIDataSource* source = content::WebUIDataSource::CreateAndAdd(
       profile, chrome::kChromeUIBookmarksSidePanelHost);
@@ -160,8 +178,9 @@ BookmarksSidePanelUI::BookmarksSidePanelUI(content::WebUI* web_ui)
       {"primaryFilterHeading", IDS_BOOKMARKS_PRIMARY_FILTER_HEADING},
       {"secondaryFilterHeading", IDS_BOOKMARKS_SECONDARY_FILTER_HEADING},
   };
-  for (const auto& str : kLocalizedStrings)
+  for (const auto& str : kLocalizedStrings) {
     webui::AddLocalizedString(source, str.name, str.id);
+  }
 
   source->AddBoolean("useRipples", views::PlatformStyle::kUseRipples);
 
@@ -181,6 +200,14 @@ BookmarksSidePanelUI::BookmarksSidePanelUI(content::WebUI* web_ui)
   source->AddBoolean("guestMode", profile->IsGuestSession());
   source->AddBoolean("incognitoMode", profile->IsIncognitoProfile());
   source->AddBoolean("isIncognitoModeAvailable", IsIncognitoModeAvailable());
+  source->AddBoolean(
+      "bookmarksTreeViewEnabled",
+      base::FeatureList::IsEnabled(features::kBookmarksTreeView));
+  // TODO(crbug.com/380818698): Replace this with the flag which will be used to
+  // launch account storage for bookmarks.
+  source->AddBoolean("isBookmarksInTransportModeEnabled",
+                     base::FeatureList::IsEnabled(
+                         syncer::kSyncEnableBookmarksInTransportMode));
   source->AddInteger(
       "sortOrder",
       prefs->GetInteger(bookmarks_webui::prefs::kBookmarksSortOrder));
@@ -192,16 +219,19 @@ BookmarksSidePanelUI::BookmarksSidePanelUI(content::WebUI* web_ui)
       BookmarkModelFactory::GetForBrowserContext(profile);
   source->AddString(
       "bookmarksBarId",
-      base::NumberToString(
-          bookmark_model ? bookmark_model->bookmark_bar_node()->id() : -1));
+      base::NumberToString(bookmark_model && bookmark_model->bookmark_bar_node()
+                               ? bookmark_model->bookmark_bar_node()->id()
+                               : -1));
   source->AddString(
       "otherBookmarksId",
-      base::NumberToString(bookmark_model ? bookmark_model->other_node()->id()
-                                          : -1));
+      base::NumberToString(bookmark_model && bookmark_model->other_node()
+                               ? bookmark_model->other_node()->id()
+                               : -1));
   source->AddString(
       "mobileBookmarksId",
-      base::NumberToString(bookmark_model ? bookmark_model->mobile_node()->id()
-                                          : -1));
+      base::NumberToString(bookmark_model && bookmark_model->mobile_node()
+                               ? bookmark_model->mobile_node()->id()
+                               : -1));
   bookmarks::ManagedBookmarkService* managed =
       ManagedBookmarkServiceFactory::GetForProfile(profile);
   source->AddString("managedBookmarksFolderId",
@@ -209,18 +239,12 @@ BookmarksSidePanelUI::BookmarksSidePanelUI(content::WebUI* web_ui)
                         ? base::NumberToString(managed->managed_node()->id())
                         : "");
 
-  webui::SetupChromeRefresh2023(source);
-
   content::URLDataSource::Add(
       profile, std::make_unique<FaviconSource>(
                    profile, chrome::FaviconUrlFormat::kFavicon2));
   const int resource = IDR_SIDE_PANEL_BOOKMARKS_POWER_BOOKMARKS_HTML;
-  webui::SetupWebUIDataSource(source,
-                              base::make_span(kSidePanelBookmarksResources,
-                                              kSidePanelBookmarksResourcesSize),
-                              resource);
-  source->AddResourcePaths(base::make_span(kSidePanelSharedResources,
-                                           kSidePanelSharedResourcesSize));
+  webui::SetupWebUIDataSource(source, kSidePanelBookmarksResources, resource);
+  source->AddResourcePaths(kSidePanelSharedResources);
 
   // Add a handler to provide pluralized strings.
   auto plural_string_handler = std::make_unique<PluralStringHandler>();
@@ -244,10 +268,18 @@ void BookmarksSidePanelUI::BindInterface(
 }
 
 void BookmarksSidePanelUI::BindInterface(
-    mojo::PendingReceiver<shopping_list::mojom::ShoppingListHandlerFactory>
+    mojo::PendingReceiver<
+        shopping_service::mojom::ShoppingServiceHandlerFactory> receiver) {
+  shopping_service_factory_receiver_.reset();
+  shopping_service_factory_receiver_.Bind(std::move(receiver));
+}
+
+void BookmarksSidePanelUI::BindInterface(
+    mojo::PendingReceiver<
+        commerce::price_tracking::mojom::PriceTrackingHandlerFactory>
         receiver) {
-  shopping_list_factory_receiver_.reset();
-  shopping_list_factory_receiver_.Bind(std::move(receiver));
+  price_tracking_factory_receiver_.reset();
+  price_tracking_factory_receiver_.Bind(std::move(receiver));
 }
 
 void BookmarksSidePanelUI::BindInterface(
@@ -282,9 +314,9 @@ void BookmarksSidePanelUI::CreateBookmarksPageHandler(
       std::make_unique<BookmarksPageHandler>(std::move(receiver), this);
 }
 
-void BookmarksSidePanelUI::CreateShoppingListHandler(
-    mojo::PendingRemote<shopping_list::mojom::Page> page,
-    mojo::PendingReceiver<shopping_list::mojom::ShoppingListHandler> receiver) {
+void BookmarksSidePanelUI::CreateShoppingServiceHandler(
+    mojo::PendingReceiver<shopping_service::mojom::ShoppingServiceHandler>
+        receiver) {
   Profile* const profile = Profile::FromWebUI(web_ui());
   bookmarks::BookmarkModel* bookmark_model =
       BookmarkModelFactory::GetForBrowserContext(profile);
@@ -292,13 +324,29 @@ void BookmarksSidePanelUI::CreateShoppingListHandler(
       commerce::ShoppingServiceFactory::GetForBrowserContext(profile);
   feature_engagement::Tracker* const tracker =
       feature_engagement::TrackerFactory::GetForBrowserContext(profile);
-  shopping_list_handler_ = std::make_unique<commerce::ShoppingListHandler>(
-      std::move(page), std::move(receiver), bookmark_model, shopping_service,
-      profile->GetPrefs(), tracker, g_browser_process->GetApplicationLocale(),
-      nullptr);
+  shopping_service_handler_ =
+      std::make_unique<commerce::ShoppingServiceHandler>(
+          std::move(receiver), bookmark_model, shopping_service,
+          profile->GetPrefs(), tracker, nullptr, nullptr);
+}
+
+void BookmarksSidePanelUI::CreatePriceTrackingHandler(
+    mojo::PendingRemote<commerce::price_tracking::mojom::Page> page,
+    mojo::PendingReceiver<commerce::price_tracking::mojom::PriceTrackingHandler>
+        receiver) {
+  Profile* const profile = Profile::FromWebUI(web_ui());
+  commerce::ShoppingService* shopping_service =
+      commerce::ShoppingServiceFactory::GetForBrowserContext(profile);
+  feature_engagement::Tracker* const tracker =
+      feature_engagement::TrackerFactory::GetForBrowserContext(profile);
+  bookmarks::BookmarkModel* bookmark_model =
+      BookmarkModelFactory::GetForBrowserContext(profile);
+  price_tracking_handler_ = std::make_unique<commerce::PriceTrackingHandler>(
+      std::move(page), std::move(receiver), web_ui(), shopping_service, tracker,
+      bookmark_model);
   shopping_list_context_menu_controller_ =
       std::make_unique<commerce::ShoppingListContextMenuController>(
-          bookmark_model, shopping_service, shopping_list_handler_.get());
+          bookmark_model, shopping_service, price_tracking_handler_.get());
 }
 
 bool BookmarksSidePanelUI::IsIncognitoModeAvailable() {
