@@ -15,9 +15,10 @@
 #include "chrome/browser/ui/views/frame/browser_view.h"
 #include "chrome/browser/ui/views/side_panel/read_anything/read_anything_side_panel_controller.h"
 #include "chrome/browser/ui/webui/side_panel/read_anything/read_anything_screenshotter.h"
-#include "chrome/common/accessibility/read_anything.mojom.h"
-#include "chrome/common/accessibility/read_anything_constants.h"
+#include "chrome/common/read_anything/read_anything.mojom.h"
+#include "chrome/common/read_anything/read_anything_constants.h"
 #include "components/translate/core/browser/translate_client.h"
+#include "content/public/browser/tts_controller.h"
 #include "mojo/public/cpp/bindings/pending_receiver.h"
 #include "mojo/public/cpp/bindings/pending_remote.h"
 #include "mojo/public/cpp/bindings/receiver.h"
@@ -25,8 +26,10 @@
 #include "ui/accessibility/ax_action_data.h"
 #include "ui/accessibility/ax_updates_and_events.h"
 
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
 #include "ash/public/cpp/session/session_observer.h"
+#else
+#include "extensions/browser/extension_registry_observer.h"
 #endif
 
 namespace content {
@@ -57,7 +60,8 @@ class ReadAnythingWebContentsObserver : public content::WebContentsObserver {
   void AccessibilityEventReceived(
       const ui::AXUpdatesAndEvents& details) override;
   void AccessibilityLocationChangesReceived(
-      const std::vector<ui::AXLocationChanges>& details) override;
+      const ui::AXTreeID& tree_id,
+      ui::AXLocationAndScrollUpdates& details) override;
   void PrimaryPageChanged(content::Page& page) override;
   void WebContentsDestroyed() override;
 
@@ -81,8 +85,11 @@ class ReadAnythingWebContentsObserver : public content::WebContentsObserver {
 //  lifetime as the Side Panel view.
 //
 class ReadAnythingUntrustedPageHandler :
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
     public ash::SessionObserver,
+#else
+    public content::UpdateLanguageStatusDelegate,
+    public extensions::ExtensionRegistryObserver,
 #endif
     public ui::AXActionHandlerObserver,
     public read_anything::mojom::UntrustedPageHandler,
@@ -93,7 +100,8 @@ class ReadAnythingUntrustedPageHandler :
       mojo::PendingRemote<read_anything::mojom::UntrustedPage> page,
       mojo::PendingReceiver<read_anything::mojom::UntrustedPageHandler>
           receiver,
-      content::WebUI* web_ui);
+      content::WebUI* web_ui,
+      bool use_screen_ai_service);
   ReadAnythingUntrustedPageHandler(const ReadAnythingUntrustedPageHandler&) =
       delete;
   ReadAnythingUntrustedPageHandler& operator=(
@@ -102,37 +110,19 @@ class ReadAnythingUntrustedPageHandler :
 
   void AccessibilityEventReceived(const ui::AXUpdatesAndEvents& details);
   void AccessibilityLocationChangesReceived(
-      const std::vector<ui::AXLocationChanges>& details);
+      const ui::AXTreeID& tree_id,
+      ui::AXLocationAndScrollUpdates& details);
   void PrimaryPageChanged();
   void WebContentsDestroyed();
+  void OnActiveAXTreeIDChanged();
 
   // read_anything::mojom::UntrustedPageHandler:
   void OnVoiceChange(const std::string& voice,
                      const std::string& lang) override;
   void OnLanguagePrefChange(const std::string& lang, bool enabled) override;
-
-  // ash::SessionObserver
-#if BUILDFLAG(IS_CHROMEOS_ASH)
-  void OnLockStateChanged(bool locked) override;
-#endif
-
- private:
-  // TranslateDriver::LanguageDetectionObserver:
-  void OnLanguageDetermined(
-      const translate::LanguageDetectionDetails& details) override;
-  void OnTranslateDriverDestroyed(translate::TranslateDriver* driver) override;
-
-  // ui::AXActionHandlerObserver:
-  void TreeRemoved(ui::AXTreeID ax_tree_id) override;
-
-  // read_anything::mojom::UntrustedPageHandler:
-  void GetDependencyParserModel(
-      GetDependencyParserModelCallback callback) override;
-  void GetVoicePackInfo(const std::string& language,
-                        GetVoicePackInfoCallback mojo_remote_callback) override;
-  void InstallVoicePack(const std::string& language,
-                        InstallVoicePackCallback mojo_remote_callback) override;
-  void OnCopy() override;
+  void OnSpeechRateChange(double rate) override;
+  void OnImageDataRequested(const ui::AXTreeID& target_tree_id,
+                            ui::AXNodeID target_node_id) override;
   void OnLineSpaceChange(
       read_anything::mojom::LineSpacing line_spacing) override;
   void OnLetterSpaceChange(
@@ -142,13 +132,23 @@ class ReadAnythingUntrustedPageHandler :
   void OnLinksEnabledChanged(bool enabled) override;
   void OnImagesEnabledChanged(bool enabled) override;
   void OnColorChange(read_anything::mojom::Colors color) override;
-  void OnSpeechRateChange(double rate) override;
   void OnHighlightGranularityChanged(
       read_anything::mojom::HighlightGranularity granularity) override;
-  void OnLinkClicked(const ui::AXTreeID& target_tree_id,
-                     ui::AXNodeID target_node_id) override;
-  void OnImageDataRequested(const ui::AXTreeID& target_tree_id,
-                            ui::AXNodeID target_node_id) override;
+  void GetVoicePackInfo(const std::string& language) override;
+  void InstallVoicePack(const std::string& language) override;
+  void UninstallVoice(const std::string& language) override;
+
+  // TranslateDriver::LanguageDetectionObserver:
+  void OnLanguageDetermined(
+      const translate::LanguageDetectionDetails& details) override;
+  void OnTranslateDriverDestroyed(translate::TranslateDriver* driver) override;
+
+  // ash::SessionObserver
+#if BUILDFLAG(IS_CHROMEOS)
+  void OnLockStateChanged(bool locked) override;
+#endif
+
+ protected:
   void OnImageDataDownloaded(const ui::AXTreeID& target_tree_id,
                              ui::AXNodeID,
                              int id,
@@ -156,6 +156,31 @@ class ReadAnythingUntrustedPageHandler :
                              const GURL& image_url,
                              const std::vector<SkBitmap>& bitmaps,
                              const std::vector<gfx::Size>& sizes);
+
+ private:
+#if !BUILDFLAG(IS_CHROMEOS)
+  // content::UpdateLanguageStatusDelegate:
+  void OnUpdateLanguageStatus(const std::string& lang,
+                              content::LanguageInstallStatus install_status,
+                              const std::string& error) override;
+  // extensions::ExtensionRegistryObserver implementation.
+
+  // OnExtensionReady is called even if the TTS engine was previously installed,
+  // which read anything needs to know about to access the new voices.
+  void OnExtensionReady(content::BrowserContext* browser_context,
+                        const extensions::Extension* extension) override;
+#endif
+
+  // ui::AXActionHandlerObserver:
+  void TreeRemoved(ui::AXTreeID ax_tree_id) override;
+
+  // read_anything::mojom::UntrustedPageHandler:
+  void GetDependencyParserModel(
+      GetDependencyParserModelCallback callback) override;
+  void OnCopy() override;
+
+  void OnLinkClicked(const ui::AXTreeID& target_tree_id,
+                     ui::AXNodeID target_node_id) override;
   void ScrollToTargetNode(const ui::AXTreeID& target_tree_id,
                           ui::AXNodeID target_node_id) override;
   void OnSelectionChange(const ui::AXTreeID& target_tree_id,
@@ -180,7 +205,7 @@ class ReadAnythingUntrustedPageHandler :
 
   void SetUpPdfObserver();
 
-  void OnActiveAXTreeIDChanged();
+  void OnGetVoicePackInfo(read_anything::mojom::VoicePackInfoPtr info);
 
   // Logs the current visual settings values.
   void LogTextStyle();
@@ -221,6 +246,8 @@ class ReadAnythingUntrustedPageHandler :
                           ui::AXActionHandlerObserver>
       ax_action_handler_observer_{this};
 
+  const bool use_screen_ai_service_;
+
   void OnScreenAIServiceInitialized(bool successful);
 
   // Observes LanguageDetectionObserver, which notifies us when the language of
