@@ -5,6 +5,7 @@
 #include "chrome/browser/ui/webui/signin/dice_web_signin_intercept_handler.h"
 
 #include <string>
+#include <string_view>
 
 #include "base/feature_list.h"
 #include "base/functional/bind.h"
@@ -29,6 +30,7 @@
 #include "components/signin/public/base/signin_switches.h"
 #include "components/signin/public/identity_manager/account_capabilities.h"
 #include "components/signin/public/identity_manager/account_info.h"
+#include "components/signin/public/identity_manager/signin_constants.h"
 #include "components/supervised_user/core/common/features.h"
 #include "content/public/browser/web_ui.h"
 #include "third_party/skia/include/core/SkBitmap.h"
@@ -39,10 +41,16 @@
 #include "ui/gfx/image/image.h"
 #include "url/gurl.h"
 
+using signin::constants::kNoHostedDomainFound;
+
 namespace {
 
+BASE_FEATURE(kSigninInterceptSimpleButtons,
+             "SigninInterceptSimpleButtons",
+             base::FEATURE_ENABLED_BY_DEFAULT);
+
 constexpr char kEnterprizeBadgeSource[] = "cr:domain";
-constexpr char kSupervisedBadgeSource[] = "cr20:kite";
+constexpr char kSupervisedBadgeSource[] = "cr:kite";
 
 // Returns true if the account is managed (aka Enterprise, or Dasher).
 bool IsManaged(const AccountInfo& info) {
@@ -65,23 +73,22 @@ SkColor GetProfileHighlightColor(Profile* profile) {
   return entry->GetProfileThemeColors().profile_highlight_color;
 }
 
-std::string GetAccountPictureUrl(const AccountInfo& info) {
-  return info.account_image.IsEmpty()
-             ? profiles::GetPlaceholderAvatarIconUrl()
-             : webui::GetBitmapDataUrl(info.account_image.AsBitmap());
-}
-
 base::Value::Dict GetAccountInfoValue(const AccountInfo& info) {
   base::Value::Dict account_info_value;
   std::string_view avatar_badge = "";
+  std::string avatar_badge_alt_text = "";
   if (IsManaged(info)) {
     avatar_badge = kEnterprizeBadgeSource;
-  } else if (IsSupervisedUser(info.capabilities) && base::FeatureList::IsEnabled(
-      supervised_user::kShowKiteForSupervisedUsers)) {
+  } else if (IsSupervisedUser(info.capabilities) &&
+             base::FeatureList::IsEnabled(
+                 supervised_user::kShowKiteForSupervisedUsers)) {
     avatar_badge = kSupervisedBadgeSource;
+    avatar_badge_alt_text =
+        l10n_util::GetStringUTF8(IDS_MANAGED_BY_PARENT_A11Y);
   }
   account_info_value.Set("avatarBadge", avatar_badge);
-  account_info_value.Set("pictureUrl", GetAccountPictureUrl(info));
+  account_info_value.Set("userBadgeAltText", avatar_badge_alt_text);
+  account_info_value.Set("pictureUrl", signin::GetAccountPictureUrl(info));
   return account_info_value;
 }
 
@@ -137,8 +144,9 @@ void DiceWebSigninInterceptHandler::OnJavascriptDisallowed() {
 
 void DiceWebSigninInterceptHandler::OnExtendedAccountInfoUpdated(
     const AccountInfo& info) {
-  if (!info.IsValid())
+  if (!info.IsValid()) {
     return;
+  }
 
   bool should_fire_event = false;
   if (info.account_id == intercepted_account().account_id) {
@@ -193,10 +201,12 @@ void DiceWebSigninInterceptHandler::HandlePageLoaded(
 
   // If there is no extended info for the primary account, populate with
   // reasonable defaults.
-  if (primary_account().hosted_domain.empty())
+  if (primary_account().hosted_domain.empty()) {
     bubble_parameters_.primary_account.hosted_domain = kNoHostedDomainFound;
-  if (primary_account().given_name.empty())
+  }
+  if (primary_account().given_name.empty()) {
     bubble_parameters_.primary_account.given_name = primary_account().email;
+  }
 
   DCHECK(!args.empty());
   const base::Value& callback_id = args[0];
@@ -254,15 +264,20 @@ DiceWebSigninInterceptHandler::GetInterceptionChromeSigninParametersValue() {
   parameters.Set("email", intercepted_account().email);
   parameters.Set("fullName", intercepted_account().full_name);
   parameters.Set("givenName", intercepted_account().given_name);
-  parameters.Set("pictureUrl", GetAccountPictureUrl(intercepted_account()));
+  parameters.Set("pictureUrl",
+                 signin::GetAccountPictureUrl(intercepted_account()));
 
-  std::string_view managed_user_badge = "";
+  std::string managed_user_badge;
+  std::string managed_user_badge_alt_text;
   if (IsSupervisedUser(intercepted_account().capabilities) &&
       base::FeatureList::IsEnabled(
           supervised_user::kShowKiteForSupervisedUsers)) {
     managed_user_badge = kSupervisedBadgeSource;
+    managed_user_badge_alt_text =
+        l10n_util::GetStringUTF8(IDS_MANAGED_BY_PARENT_A11Y);
   }
   parameters.Set("managedUserBadge", managed_user_badge);
+  parameters.Set("userBadgeAltText", managed_user_badge_alt_text);
   return parameters;
 }
 
@@ -291,6 +306,12 @@ DiceWebSigninInterceptHandler::GetInterceptionParametersValue() {
   parameters.Set("headerTextColor",
                  color_utils::SkColorToRgbaString(GetProfileForegroundTextColor(
                      bubble_parameters_.profile_highlight_color)));
+  parameters.Set("primaryProfileBadgeColor",
+                 color_utils::SkColorToRgbaString(GetProfileForegroundIconColor(
+                     GetProfileHighlightColor(Profile::FromWebUI(web_ui())))));
+  parameters.Set("interceptedProfileBadgeColor",
+                 color_utils::SkColorToRgbaString(GetProfileForegroundIconColor(
+                     bubble_parameters_.profile_highlight_color)));
   return parameters;
 }
 
@@ -323,7 +344,7 @@ std::string DiceWebSigninInterceptHandler::GetChromeSigninTitle() {
   // calling code waits for Account Capabilities to be fetched (with a timeout),
   // so Account Capabilities will be available for the vast majority of users.
   if (base::FeatureList::IsEnabled(
-          supervised_user::kCustomWebSignInInterceptForSupervisedUsersUi) &&
+          supervised_user::kCustomProfileStringsForSupervisedUsers) &&
       bubble_parameters_.intercepted_account.capabilities
               .is_subject_to_parental_controls() == signin::Tribool::kTrue) {
     return l10n_util::GetStringUTF8(
@@ -338,9 +359,9 @@ std::string DiceWebSigninInterceptHandler::GetChromeSigninSubtitle() {
   // calling code waits for Account Capabilities to be fetched (with a timeout),
   // so Account Capabilities will be available for the vast majority of users.
   if (base::FeatureList::IsEnabled(
-          supervised_user::kCustomWebSignInInterceptForSupervisedUsersUi) &&
-      bubble_parameters_.intercepted_account.capabilities
-              .is_subject_to_parental_controls() == signin::Tribool::kTrue) {
+          supervised_user::kCustomProfileStringsForSupervisedUsers) &&
+      intercepted_account().capabilities.is_subject_to_parental_controls() ==
+          signin::Tribool::kTrue) {
     return l10n_util::GetStringUTF8(
         IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_SUBTITLE_SUPERVISED);
   }
@@ -364,12 +385,21 @@ std::string DiceWebSigninInterceptHandler::GetBodyTitle() {
 std::string DiceWebSigninInterceptHandler::GetBodyText() {
   if (bubble_parameters_.interception_type ==
       WebSigninInterceptor::SigninInterceptionType::kProfileSwitch) {
-    return switches::IsExplicitBrowserSigninUIOnDesktopEnabled()
-               ? l10n_util::GetStringFUTF8(
-                     IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_DESC_V2,
-                     base::UTF8ToUTF16(intercepted_account().email))
-               : l10n_util::GetStringUTF8(
-                     IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_DESC);
+    if (!switches::IsExplicitBrowserSigninUIOnDesktopEnabled()) {
+      return l10n_util::GetStringUTF8(
+          IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_DESC);
+    }
+    if (base::FeatureList::IsEnabled(
+            supervised_user::kCustomProfileStringsForSupervisedUsers) &&
+        intercepted_account().capabilities.is_subject_to_parental_controls() ==
+            signin::Tribool::kTrue) {
+      return l10n_util::GetStringFUTF8(
+          IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_DESC_V2_SUPERVISED,
+          base::UTF8ToUTF16(intercepted_account().email));
+    }
+    return l10n_util::GetStringFUTF8(
+        IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_DESC_V2,
+        base::UTF8ToUTF16(intercepted_account().email));
   }
 
   CHECK(bubble_parameters_.interception_type ==
@@ -391,6 +421,14 @@ std::string DiceWebSigninInterceptHandler::GetBodyText() {
   }
 
   if (switches::IsExplicitBrowserSigninUIOnDesktopEnabled()) {
+    if (base::FeatureList::IsEnabled(
+            supervised_user::kCustomProfileStringsForSupervisedUsers) &&
+        intercepted_account().capabilities.is_subject_to_parental_controls() ==
+            signin::Tribool::kTrue) {
+      return l10n_util::GetStringFUTF8(
+          IDS_SIGNIN_DICE_WEB_INTERCEPT_CREATE_BUBBLE_DESC_SUPERVISED,
+          base::UTF8ToUTF16(intercepted_account().email));
+    }
     return l10n_util::GetStringFUTF8(
         IDS_SIGNIN_DICE_WEB_INTERCEPT_CREATE_BUBBLE_DESC,
         base::UTF8ToUTF16(primary_account().given_name),
@@ -427,10 +465,15 @@ std::string DiceWebSigninInterceptHandler::GetConfirmButtonLabel() {
             : IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CONFIRM_SWITCH_BUTTON_LABEL);
   }
 
-  return l10n_util::GetStringUTF8(
-      switches::IsExplicitBrowserSigninUIOnDesktopEnabled()
-          ? IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CREATE_PROFILE_BUTTON_LABEL
-          : IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_NEW_PROFILE_BUTTON_LABEL);
+  int button_label =
+      IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_NEW_PROFILE_BUTTON_LABEL;
+  if (switches::IsExplicitBrowserSigninUIOnDesktopEnabled() &&
+      !base::FeatureList::IsEnabled(kSigninInterceptSimpleButtons)) {
+    button_label =
+        IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CREATE_PROFILE_BUTTON_LABEL;
+  }
+
+  return l10n_util::GetStringUTF8(button_label);
 }
 
 std::string DiceWebSigninInterceptHandler::GetCancelButtonLabel() {
@@ -440,10 +483,13 @@ std::string DiceWebSigninInterceptHandler::GetCancelButtonLabel() {
         IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CANCEL_SWITCH_BUTTON_LABEL);
   }
 
-  return l10n_util::GetStringUTF8(
-      switches::IsExplicitBrowserSigninUIOnDesktopEnabled()
-          ? IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_STAY_HERE_BUTTON_LABEL
-          : IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CANCEL_BUTTON_LABEL);
+  int button_label = IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CANCEL_BUTTON_LABEL;
+  if (switches::IsExplicitBrowserSigninUIOnDesktopEnabled() &&
+      !base::FeatureList::IsEnabled(kSigninInterceptSimpleButtons)) {
+    button_label = IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_STAY_HERE_BUTTON_LABEL;
+  }
+
+  return l10n_util::GetStringUTF8(button_label);
 }
 
 std::string DiceWebSigninInterceptHandler::GetManagedDisclaimerText() {
@@ -462,8 +508,9 @@ std::string DiceWebSigninInterceptHandler::GetManagedDisclaimerText() {
   std::string manager_domain = intercepted_account().IsManaged()
                                    ? intercepted_account().hosted_domain
                                    : std::string();
-  if (manager_domain.empty())
-    manager_domain = chrome::GetDeviceManagerIdentity().value_or(std::string());
+  if (manager_domain.empty()) {
+    manager_domain = GetDeviceManagerIdentity().value_or(std::string());
+  }
 
   if (manager_domain.empty()) {
     return l10n_util::GetStringFUTF8(
@@ -478,5 +525,5 @@ std::string DiceWebSigninInterceptHandler::GetManagedDisclaimerText() {
 
 bool DiceWebSigninInterceptHandler::GetShouldUseV2Design() {
   return bubble_parameters_.interception_type !=
-             WebSigninInterceptor::SigninInterceptionType::kProfileSwitch;
+         WebSigninInterceptor::SigninInterceptionType::kProfileSwitch;
 }
