@@ -8,15 +8,15 @@
 #include <optional>
 #include <set>
 #include <string>
+#include <string_view>
 #include <vector>
 
 #include "base/base64url.h"
 #include "base/check.h"
 #include "base/containers/contains.h"
-#include "base/strings/string_piece.h"
+#include "base/containers/to_value_list.h"
 #include "base/strings/string_util.h"
 #include "base/values.h"
-#include "build/chromeos_buildflags.h"
 #include "chrome/browser/support_tool/data_collection_module.pb.h"
 #include "chrome/browser/support_tool/data_collector.h"
 #include "chrome/browser/support_tool/support_tool_util.h"
@@ -71,10 +71,6 @@ std::string GetDataCollectorName(
       return l10n_util::GetStringUTF8(IDS_SUPPORT_TOOL_INTEL_WIFI_DEBUG_DUMP);
     case support_tool::CHROMEOS_TOUCH_EVENTS:
       return l10n_util::GetStringUTF8(IDS_SUPPORT_TOOL_TOUCH_EVENTS);
-    case support_tool::CHROMEOS_CROS_API:
-      return l10n_util::GetStringUTF8(IDS_SUPPORT_TOOL_LACROS_SYSTEM_INFO);
-    case support_tool::CHROMEOS_LACROS:
-      return l10n_util::GetStringUTF8(IDS_SUPPORT_TOOL_LACROS);
     case support_tool::CHROMEOS_REVEN:
       return l10n_util::GetStringUTF8(IDS_SUPPORT_TOOL_CHROMEOS_FLEX_LOGS);
     case support_tool::CHROMEOS_DBUS:
@@ -232,34 +228,25 @@ std::string GetPIITypeDescription(redaction::PIIType type_enum) {
 // type PIIDataItem = {
 //   piiTypeDescription: string,
 //   piiType: number,
-//   detectedData: string,
+//   detectedData: List<string>,
 //   count: number,
 //   keep: boolean,
 // }
 base::Value::List GetDetectedPIIDataItems(const PIIMap& detected_pii) {
-  base::Value::List detected_pii_data_items;
-  for (const auto& pii_entry : detected_pii) {
-    base::Value::Dict pii_data_item;
-    pii_data_item.Set(support_tool_ui::kPiiItemDescriptionKey,
-                      GetPIITypeDescription(pii_entry.first));
-    pii_data_item.Set(support_tool_ui::kPiiItemPIITypeKey,
-                      static_cast<int>(pii_entry.first));
-    pii_data_item.Set(
-        support_tool_ui::kPiiItemDetectedDataKey,
-        base::JoinString(
-            std::vector<base::StringPiece>(pii_entry.second.begin(),
-                                           pii_entry.second.end()),
-            // Join the PII strings with a comma in between them when displaying
-            // to the user to make it more easily readable.
-            ", "));
-    pii_data_item.Set(support_tool_ui::kPiiItemCountKey,
-                      static_cast<int>(pii_entry.second.size()));
-    // TODO(b/200511640): Set `keep` field to the value we'll get from URL's
-    // pii_masking_on query if it exists.
-    pii_data_item.Set(support_tool_ui::kPiiItemKeepKey, true);
-    detected_pii_data_items.Append(std::move(pii_data_item));
-  }
-  return detected_pii_data_items;
+  return base::ToValueList(detected_pii, [](const auto& detected_pii_entry) {
+    const auto& [pii_key, pii_data] = detected_pii_entry;
+    return base::Value::Dict()
+        .Set(support_tool_ui::kPiiItemDescriptionKey,
+             GetPIITypeDescription(pii_key))
+        .Set(support_tool_ui::kPiiItemPIITypeKey, static_cast<int>(pii_key))
+        .Set(support_tool_ui::kPiiItemDetectedDataKey,
+             base::ToValueList(pii_data))
+        .Set(support_tool_ui::kPiiItemCountKey,
+             static_cast<int>(pii_data.size()))
+        // TODO(b/200511640): Set `keep` field to the value we'll get from
+        // URL's pii_masking_on query if it exists.
+        .Set(support_tool_ui::kPiiItemKeepKey, true);
+  });
 }
 
 std::set<redaction::PIIType> GetPIITypesToKeep(
