@@ -11,11 +11,15 @@
 #include "chrome/browser/ui/webui/metrics_reporter/metrics_reporter.h"
 #include "chrome/browser/ui/webui/tab_search/tab_search.mojom.h"
 #include "chrome/browser/ui/webui/tab_search/tab_search_page_handler.h"
+#include "chrome/browser/ui/webui/top_chrome/top_chrome_web_ui_controller.h"
+#include "chrome/browser/ui/webui/top_chrome/top_chrome_webui_config.h"
 #include "chrome/browser/ui/webui/webui_load_timer.h"
+#include "chrome/common/webui_url_constants.h"
+#include "content/public/browser/webui_config.h"
+#include "content/public/common/url_constants.h"
 #include "mojo/public/cpp/bindings/pending_receiver.h"
 #include "mojo/public/cpp/bindings/pending_remote.h"
 #include "mojo/public/cpp/bindings/receiver.h"
-#include "ui/webui/mojo_bubble_web_ui_controller.h"
 #include "ui/webui/resources/cr_components/color_change_listener/color_change_listener.mojom.h"
 #include "ui/webui/resources/js/metrics_reporter/metrics_reporter.mojom.h"
 
@@ -23,7 +27,19 @@ namespace ui {
 class ColorChangeHandler;
 }
 
-class TabSearchUI : public ui::MojoBubbleWebUIController,
+class TabSearchUI;
+
+class TabSearchUIConfig : public DefaultTopChromeWebUIConfig<TabSearchUI> {
+ public:
+  TabSearchUIConfig();
+
+  // DefaultTopChromeWebUIConfig:
+  bool ShouldAutoResizeHost() override;
+  bool IsPreloadable() override;
+  std::optional<int> GetCommandIdForTesting() override;
+};
+
+class TabSearchUI : public TopChromeWebUIController,
                     public tab_search::mojom::PageHandlerFactory {
  public:
   explicit TabSearchUI(content::WebUI* web_ui);
@@ -48,6 +64,11 @@ class TabSearchUI : public ui::MojoBubbleWebUIController,
 
   static constexpr std::string GetWebUIName() { return "TabSearch"; }
 
+  void set_page_handler_creation_callback_for_testing(
+      base::OnceClosure callback) {
+    page_handler_creation_callback_ = std::move(callback);
+  }
+
  private:
   // tab_search::mojom::PageHandlerFactory
   void CreatePageHandler(
@@ -66,6 +87,8 @@ class TabSearchUI : public ui::MojoBubbleWebUIController,
 
   WebuiLoadTimer webui_load_timer_;
 
+  base::OnceClosure page_handler_creation_callback_;
+
   // A timer used to track the duration between when the WebUI is constructed
   // and when the TabSearchPageHandler is constructed.
   std::optional<base::ElapsedTimer> page_handler_timer_;
