@@ -2,11 +2,6 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifdef UNSAFE_BUFFERS_BUILD
-// TODO(crbug.com/40285824): Remove this and convert code to safer constructs.
-#pragma allow_unsafe_buffers
-#endif
-
 #include "chrome/browser/ui/webui/version/version_ui.h"
 
 #include <memory>
@@ -21,11 +16,9 @@
 #include "base/strings/utf_string_conversions.h"
 #include "base/time/time.h"
 #include "build/build_config.h"
-#include "build/chromeos_buildflags.h"
 #include "chrome/browser/browser_process_impl.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/ui/webui/version/version_handler.h"
-#include "chrome/browser/ui/webui/webui_util.h"
 #include "chrome/common/channel_info.h"
 #include "chrome/common/url_constants.h"
 #include "chrome/grit/branded_strings.h"
@@ -38,14 +31,15 @@
 #include "components/strings/grit/components_strings.h"
 #include "components/variations/service/variations_service.h"
 #include "components/version_info/version_info.h"
-#include "components/version_ui/version_handler_helper.h"
-#include "components/version_ui/version_ui_constants.h"
+#include "components/webui/version/version_handler_helper.h"
+#include "components/webui/version/version_ui_constants.h"
 #include "content/public/browser/url_data_source.h"
 #include "content/public/browser/web_ui.h"
 #include "content/public/browser/web_ui_data_source.h"
 #include "content/public/common/user_agent.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/base/webui/web_ui_util.h"
+#include "ui/webui/webui_util.h"
 #include "v8/include/v8-version-string.h"
 
 #if BUILDFLAG(IS_ANDROID)
@@ -78,46 +72,40 @@ void CreateAndAddVersionUIDataSource(Profile* profile) {
       WebUIDataSource::CreateAndAdd(profile, chrome::kChromeUIVersionHost);
   // These localized strings are used to label version details.
   static constexpr webui::LocalizedString kStrings[] = {
-    {version_ui::kTitle, IDS_VERSION_UI_TITLE},
-    {version_ui::kLogoAltText, IDS_SHORT_PRODUCT_LOGO_ALT_TEXT},
-    {version_ui::kApplicationLabel, IDS_PRODUCT_NAME},
-    {version_ui::kCompany, IDS_ABOUT_VERSION_COMPANY_NAME},
-    {version_ui::kCopyLabel, IDS_VERSION_UI_COPY_LABEL},
-    {version_ui::kCopyNotice, IDS_VERSION_UI_COPY_NOTICE},
-    {version_ui::kRevision, IDS_VERSION_UI_REVISION},
-    {version_ui::kUserAgentName, IDS_VERSION_UI_USER_AGENT},
-    {version_ui::kCommandLineName, IDS_VERSION_UI_COMMAND_LINE},
-    {version_ui::kExecutablePathName, IDS_VERSION_UI_EXECUTABLE_PATH},
-    {version_ui::kProfilePathName, IDS_VERSION_UI_PROFILE_PATH},
-    {version_ui::kVariationsName, IDS_VERSION_UI_VARIATIONS},
-    {version_ui::kVariationsCmdName, IDS_VERSION_UI_VARIATIONS_CMD},
-    {version_ui::kVariationsSeedName, IDS_VERSION_UI_VARIATIONS_SEED_NAME},
+      {version_ui::kTitle, IDS_VERSION_UI_TITLE},
+      {version_ui::kLogoAltText, IDS_SHORT_PRODUCT_LOGO_ALT_TEXT},
+      {version_ui::kApplicationLabel, IDS_PRODUCT_NAME},
+      {version_ui::kCompany, IDS_ABOUT_VERSION_COMPANY_NAME},
+      {version_ui::kCopyLabel, IDS_VERSION_UI_COPY_LABEL},
+      {version_ui::kCopyNotice, IDS_VERSION_UI_COPY_NOTICE},
+      {version_ui::kRevision, IDS_VERSION_UI_REVISION},
+      {version_ui::kUserAgentName, IDS_VERSION_UI_USER_AGENT},
+      {version_ui::kCommandLineName, IDS_VERSION_UI_COMMAND_LINE},
+      {version_ui::kExecutablePathName, IDS_VERSION_UI_EXECUTABLE_PATH},
+      {version_ui::kProfilePathName, IDS_VERSION_UI_PROFILE_PATH},
+      {version_ui::kVariationsName, IDS_VERSION_UI_VARIATIONS},
+      {version_ui::kVariationsCmdName, IDS_VERSION_UI_VARIATIONS_CMD},
+      {version_ui::kCopyVariationsLabel, IDS_VERSION_UI_COPY_VARIATIONS_LABEL},
+      {version_ui::kCopyVariationsNotice,
+       IDS_VERSION_UI_COPY_VARIATIONS_NOTICE},
+      {version_ui::kVariationsSeedName, IDS_VERSION_UI_VARIATIONS_SEED_NAME},
 #if BUILDFLAG(IS_CHROMEOS)
-    {version_ui::kARC, IDS_ARC_LABEL},
-    {version_ui::kPlatform, IDS_PLATFORM_LABEL},
-    {version_ui::kCustomizationId, IDS_VERSION_UI_CUSTOMIZATION_ID},
-    {version_ui::kFirmwareVersion, IDS_VERSION_UI_FIRMWARE_VERSION},
-    {version_ui::kOsVersionHeaderText1, IDS_VERSION_UI_OS_TEXT1_LABEL},
-    {version_ui::kOsVersionHeaderText2, IDS_VERSION_UI_OS_TEXT2_LABEL},
+      {version_ui::kARC, IDS_ARC_LABEL},
+      {version_ui::kPlatform, IDS_PLATFORM_LABEL},
+      {version_ui::kCustomizationId, IDS_VERSION_UI_CUSTOMIZATION_ID},
+      {version_ui::kFirmwareVersion, IDS_VERSION_UI_FIRMWARE_VERSION},
+#else
+      {version_ui::kOSName, IDS_VERSION_UI_OS},
 #endif  // BUILDFLAG(IS_CHROMEOS)
-#if !BUILDFLAG(IS_CHROMEOS_ASH)
-    {version_ui::kOSName, IDS_VERSION_UI_OS},
-#endif  // !BUILDFLAG(IS_CHROMEOS)
 #if BUILDFLAG(IS_ANDROID)
-    {version_ui::kGmsName, IDS_VERSION_UI_GMS},
+      {version_ui::kGmsName, IDS_VERSION_UI_GMS},
 #endif  // BUILDFLAG(IS_ANDROID)
   };
   html_source->AddLocalizedStrings(kStrings);
 
-#if BUILDFLAG(IS_CHROMEOS)
-  auto os_link = l10n_util::GetStringUTF16(IDS_VERSION_UI_OS_LINK);
-  html_source->AddString(version_ui::kOsVersionHeaderLink, os_link);
-#endif  // BUILDFLAG(IS_CHROMEOS)
-
   VersionUI::AddVersionDetailStrings(html_source);
 
-  html_source->AddResourcePaths(
-      base::make_span(kVersionUiResources, kVersionUiResourcesSize));
+  html_source->AddResourcePaths(kVersionUiResources);
   html_source->UseStringsJs();
 
 #if BUILDFLAG(IS_ANDROID)
@@ -135,9 +123,6 @@ std::string GetProductModifier() {
       !channel_name.empty()) {
     modifier_parts.push_back(std::move(channel_name));
   }
-#if BUILDFLAG(IS_CHROMEOS_LACROS)
-  modifier_parts.emplace_back("lacros");
-#endif  // BUILDFLAG(IS_CHROMEOS_LACROS)
 #if BUILDFLAG(DCHECK_IS_CONFIGURABLE)
   modifier_parts.emplace_back("dcheck");
 #endif  // BUILDFLAG(DCHECK_IS_CONFIGURABLE)
@@ -166,7 +151,7 @@ VersionUI::VersionUI(content::WebUI* web_ui)
   CreateAndAddVersionUIDataSource(profile);
 }
 
-VersionUI::~VersionUI() {}
+VersionUI::~VersionUI() = default;
 
 // static
 int VersionUI::VersionProcessorVariation() {
@@ -249,7 +234,7 @@ void VersionUI::AddVersionDetailStrings(content::WebUIDataSource* html_source) {
 
 #if BUILDFLAG(IS_MAC)
   html_source->AddString(version_ui::kOSType, base::mac::GetOSDisplayName());
-#elif !BUILDFLAG(IS_CHROMEOS_ASH)
+#elif !BUILDFLAG(IS_CHROMEOS)
   html_source->AddString(version_ui::kOSType,
                          std::string(version_info::GetOSType()));
 #endif  // BUILDFLAG(IS_MAC)
@@ -283,8 +268,9 @@ void VersionUI::AddVersionDetailStrings(content::WebUIDataSource* html_source) {
   std::string command_line;
   typedef std::vector<std::string> ArgvList;
   const ArgvList& argv = base::CommandLine::ForCurrentProcess()->argv();
-  for (auto iter = argv.begin(); iter != argv.end(); iter++)
-    command_line += " " + *iter;
+  for (const auto& iter : argv) {
+    command_line += " " + iter;
+  }
   // TODO(viettrungluu): |command_line| could really have any encoding, whereas
   // below we assumes it's UTF-8.
   html_source->AddString(version_ui::kCommandLine, command_line);
