@@ -332,6 +332,14 @@ inline constexpr base::FilePath::CharType
     kReadingModeGDocsHelperManifestFilename[] =
         FILE_PATH_LITERAL("reading_mode_gdocs_helper_manifest.json");
 #endif  // !BUILDFLAG(IS_CHROMEOS_LACROS)
+#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC)
+// The extension id of the google tts engine extension to use on-device natural
+// Google voices.
+inline constexpr char kTTSEngineExtensionId[] =
+    "kfgdcmdikpmgdjhgfpbfgkomboamacbb";
+inline constexpr char kComponentUpdaterTTSEngineExtensionId[] =
+    "gjjabgpgjpampikjhjpfhneeoapjbjaf";
+#endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC)
 
 // What causes an extension to be installed? Used in histograms, so don't
 // change existing values.
